import os
import sys
from math import ceil

import numpy as np
import h5py

import TurTLE
import TurTLE.DNS

cpp_location = os.path.join(
         TurTLE.data_dir, 'collisions')

class ADNS_Stokes_test(TurTLE.DNS):
    def __init__(
            self,
            cylinders_on = False,
            NSVEcylinders_on = False,
            **kwargs):
        self.cylinders_on = cylinders_on
        self.NSVEcylinders_on = NSVEcylinders_on
        TurTLE.DNS.__init__(self, **kwargs)
        self.list_of_particle_codes.append('NSVE_Stokes_growing_subset')
        self.extra_parameters['NSVE_Stokes_growing_subset'] = {
            'stokes_number' : float(0.1),
            'stokes_number_evolving' : float(0.1),
            'relative_stokes_distr_width' : float(0),
            'nb_growing_particles' : int(0)}
        self.check_current_vorticity_exists = True
        self.check_current_velocity_exists = False
        return None
    def custom_parameter_update(self):
        self.extra_parameters['NSVE_Stokes_growing_subset']['tracers0_integration_steps'] = int(0)
        self.extra_parameters['NSVE_Stokes_growing_subset']['tracers0_neighbours'] = int(3)
        self.extra_parameters['NSVE_Stokes_growing_subset']['tracers0_smoothness'] = int(2)
        return None
    def write_src(
            self):
        self.version_message = (
                '/***********************************************************************\n' +
                '* this code automatically generated by TurTLE\n' +
                '* version {0}\n'.format(TurTLE.__version__) +
                '***********************************************************************/\n\n\n')
        self.include_list = [
                '"base.hpp"',
                '"scope_timer.hpp"',
                '"fftw_interface.hpp"',
                '"full_code/main_code.hpp"',
                '"full_code/NSVEparticles.hpp"',
                '<cmath>',
                '<iostream>',
                '<hdf5.h>',
                '<string>',
                '<cstring>',
                '<fftw3-mpi.h>',
                '<omp.h>',
                '<cfenv>',
                '<cstdlib>']
        self.main = """
            int main(int argc, char *argv[])
            {{
                bool fpe = (
                    (getenv("BFPS_FPE_OFF") == nullptr) ||
                    (getenv("BFPS_FPE_OFF") != std::string("TRUE")));
                return main_code< {0} >(argc, argv, fpe);
            }}
            """.format(self.dns_type + '<{0}>'.format(self.C_field_dtype))
        self.includes = '\n'.join(
                ['#include ' + hh
                 for hh in self.include_list])
        self.name = 'NSVEparticles_stokes_set'
        self.dns_type = 'NSVE_Stokes_growing_subset'
        self.definitions = open(
            os.path.join(
                cpp_location, 'p2p_stokes_collisions_growing_subset.hpp'), 'r').read()
        self.definitions += open(
            os.path.join(
                cpp_location, 'stokes_rhs.hpp'), 'r').read()
        self.definitions += open(
            os.path.join(
                cpp_location, 'stokes_collisions_with_background_rhs.hpp'), 'r').read()
        self.definitions += open(
            os.path.join(
                cpp_location, 'NSVE_Stokes_growing_subset.hpp'), 'r').read()
        self.definitions += open(
            os.path.join(
                cpp_location, 'stokes_rhs.cpp'), 'r').read()
        self.definitions += open(
            os.path.join(
                cpp_location, 'stokes_collisions_with_background_rhs.cpp'), 'r').read()
        self.definitions += open(
            os.path.join(
                cpp_location, 'NSVE_Stokes_growing_subset.cpp'), 'r').read()
        with open(self.name + '.cpp', 'w') as outfile:
            outfile.write(self.version_message + '\n\n')
            outfile.write(self.includes + '\n\n')
            outfile.write(self.definitions + '\n\n')
            outfile.write(self.main + '\n')
        return None
    def generate_tracer_state(
            self,
            rseed = None,
            species = 0,
            integration_steps = None,
            ncomponents = 3,
            opt = None):
        need_tracer_state = False

        try:
            source_file = 'not_a_file'
            source_cp = 0
            while True:
                src_file = os.path.join(
                    os.path.realpath(opt.src_work_dir),
                    opt.src_simname + '_checkpoint_{0}.h5'.format(source_cp))
                f0 = h5py.File(src_file, 'r')
                if '{0}'.format(opt.src_iteration) in f0['tracers{0}/state'.format(species)].keys():
                    f0.close()
                    break
                source_cp += 1
            with h5py.File(self.get_checkpoint_0_fname(), 'a') as data_file:

                self.copy_tracer_state(
                    src_file,
                    'tracer{0}/state/'.format(species)+'{0}'.format(opt.src_iteration),
                    data_file,
                    'tracer{0}/state/0'.format(species),
                    ncomponents = ncomponents)
                print('copy was successful')
        except: need_tracer_state = True

        if need_tracer_state:
            try:
                print('generate tracer state')
                if type(integration_steps) == type(None):
                    integration_steps = self.NSVEp_extra_parameters['tracers0_integration_steps']
                if 'tracers{0}_integration_steps'.format(species) in self.parameters.keys():
                    integration_steps = self.parameters['tracers{0}_integration_steps'.format(species)]
                with h5py.File(self.get_checkpoint_0_fname(), 'a') as data_file:
                    nn = self.parameters['nparticles']
                    if not 'tracers{0}'.format(species) in data_file.keys():
                        data_file.create_group('tracers{0}'.format(species))
                        data_file.create_group('tracers{0}/rhs'.format(species))
                        data_file.create_group('tracers{0}/state'.format(species))
                    data_file['tracers{0}/rhs'.format(species)].create_dataset(
                            '0',
                            shape = (integration_steps, nn, ncomponents,),
                            dtype = float)
                    dset = data_file['tracers{0}/state'.format(species)].create_dataset(
                            '0',
                            shape = (nn, ncomponents,),
                            dtype = float)
                    if not type(rseed) == type(None):
                        np.random.seed(rseed)
                    cc = int(0)
                    batch_size = int(1e6)
                    def get_random_phases(npoints):
                        return np.random.random(
                                    (npoints, 3))*2*np.pi
                    def get_random_versors(npoints):
                        bla = np.random.normal(
                                size = (npoints, 3))
                        bla  /= np.sum(bla**2, axis = 1)[:, None]**.5
                        return bla
                    position1 = np.zeros(shape=(nn//2,3))
                    position1[:,2]= np.linspace(0, 2*np.pi, nn//2, endpoint= False)
                    position2= np.copy(position1)
                    position2[:,2]+=  np.linspace(0, 0.01, nn//2, endpoint= False)
                    position2[:,0]+=  0.05
                    positions= np.zeros((nn,3))
                    positions[:nn//2]=position1
                    positions[nn//2:]=position2
                    vel1=  np.zeros((nn//2,3))
                    vel1[:,0] = 0.05/self.parameters['dt']
                    vel2=-vel1
                    vel= np.zeros((nn,3))
                    vel[:nn//2]=vel1
                    vel[nn//2:]=vel2



                    while nn > 0:
                        if nn>batch_size:
                            dset[cc*batch_size:(cc+1)*batch_size, :3] = positions[cc*batch_size:(cc+1)*batch_size]
                            dset[cc*batch_size:(cc+1)*batch_size, 3:6] = vel[cc*batch_size:(cc+1)*batch_size]
                            if (cc+1)*batch_size<self.parameters['nb_growing_particles']:
                                    dset[cc*batch_size:(cc+1)*batch_size, 6] = np.sqrt(self.parameters['injection_rate']/self.parameters['nu'])/self.parameters['stokes_number_evolving']
                            elif (cc)*batch_size<self.parameters['nb_growing_particles']:
                                    dset[cc*batch_size:self.parameters['nb_growing_particles'], 6] = np.sqrt(self.parameters['injection_rate']/self.parameters['nu'])/self.parameters['stokes_number_evolving']
                                    dset[self.parameters['nb_growing_particles']:(cc+1)*batch_size, 6] = np.sqrt(self.parameters['injection_rate']/self.parameters['nu'])/self.parameters['stokes_number']
                            else:
                                    dset[cc*batch_size:(cc+1)*batch_size, 6] = np.sqrt(self.parameters['injection_rate']/self.parameters['nu'])/self.parameters['stokes_number']

                            nn -= batch_size
                        else:
                            dset[cc*batch_size:cc*batch_size+nn, :3] = positions[cc*batch_size:cc*batch_size+nn]
                            dset[cc*batch_size:cc*batch_size+nn, 3:6] = vel[cc*batch_size:cc*batch_size+nn]
                            if (cc)*batch_size<self.parameters['nb_growing_particles']:
                                    dset[cc*batch_size:self.parameters['nb_growing_particles'], 6] = np.sqrt(self.parameters['injection_rate']/self.parameters['nu'])/self.parameters['stokes_number_evolving']
                                    dset[self.parameters['nb_growing_particles']:cc*batch_size + nn, 6] = np.sqrt(self.parameters['injection_rate']/self.parameters['nu'])/self.parameters['stokes_number']
                            else:
                                    dset[cc*batch_size:(cc+1)*batch_size, 6] = np.sqrt(self.parameters['injection_rate']/self.parameters['nu'])/self.parameters['stokes_number']


                            nn = 0
                        cc += 1
            except Exception as e:
                print('!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!WARNING')
                print(e)
                print('!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!WARNING')
        return None

    def generate_initial_condition(
            self,
            opt = None):
        f = h5py.File(self.get_checkpoint_0_fname(), 'a')
        f['vorticity/complex/0'] = self.generate_vector_field(
                write_to_file = False,
                rseed = self.parameters['field_random_seed'])
        f.close()
        return None

    def launch(
            self,
            args = [],
            **kwargs):
        opt = self.prepare_launch(
                args = args,
                extra_parameters = self.extra_parameters['NSVE_Stokes_growing_subset'])
        if not os.path.exists(self.get_data_file_name()):
            self.write_par()
            self.generate_initial_condition(opt = opt)
            with h5py.File(self.get_data_file_name(), 'a') as dfile:
                dfile.create_group('statistics/collisions')
            with h5py.File(self.get_particle_file_name(), 'w') as particle_file:
                particle_file.create_group('tracers0/position')
                particle_file.create_group('tracers0/velocity')
                particle_file.create_group('tracers0/velocity_gradient')
                particle_file.create_group('tracers0/pressure')
                particle_file.create_group('tracers0/pressure_gradient')
                particle_file.create_group('tracers0/pressure_Hessian')
                particle_file.create_group('tracers0/drag_coeff')
                particle_file.create_group('collisions0')
            self.generate_tracer_state(integration_steps = self.parameters['tracers0_integration_steps'],
                                       rseed = opt.particle_rand_seed,
                                       ncomponents = 7)
        self.run(
                nb_processes = opt.nb_processes,
                nb_threads_per_process = opt.nb_threads_per_process,
                njobs = opt.njobs,
                hours = opt.minutes // 60,
                minutes = opt.minutes % 60,
                no_submit = opt.no_submit,
                no_debug = not opt.debug)
        return None


niterations = 1
niter_out = 1
nparticles = 10
nb_growing_particles = int(nparticles//2)
n = 32
checkpoints_per_file = 1
stokes_number=0.1
niterations_eq = 10
def main():
    ####################################################################################
    ## run c++ test
    bla2 = ADNS_Stokes_test()
    bla2.launch([
                'NSVE_Stokes_growing_subset',
                '--simname', 'test_stokes',
                '-n', '{0}'.format(n),
                '--stokes_number', '{0}'.format(stokes_number),
                '--stokes_number_evolving', '{0}'.format(stokes_number),
                '--np', '4',
                '--ntpp', '2',
                '--kMeta', '3.0',
                '--niter_todo', '{0}'.format(niterations),
                '--niter_out', '{0}'.format(niter_out),
                '--niter_stat', '{0}'.format(niter_out),
                '--nparticles', '{0}'.format(nparticles),
                '--nb_growing_particles', '{0}'.format(nb_growing_particles),
                '--tracers0_cutoff', '0.5'] + sys.argv[1:])
    ####################################################################################
    return None

def check_results():
    ####################################################################################
    ## perform sanity check
    #reading files
    f = h5py.File('Stokes_alt.h5','r')
    checkpoint = h5py.File('Stokes_alt_checkpoint_0.h5', 'r')

    #computing droplet radius a
    drag_coeff = np.sqrt(np.array(f['parameters/injection_rate'])/np.array(f['parameters/nu']))/np.array(f['parameters/stokes_number'])
    a = np.sqrt((9/2)*0.001*np.array(f['parameters/nu'])/drag_coeff)

    #expected number of collisions where 0.01 is the max offset
    number_of_collisions = ceil(nparticles*a/0.01)
    #recorded number of colllisions
    actual_number_collisions = np.array(f['statistics/collisions/pair_list_1']).shape[0]
    #number of droplets growing according to collisions
    number_of_grown_droplets = np.sum(np.array(checkpoint['/tracers0/state/1'])[:,6]<drag_coeff)

    #checks that expected, recorded collisions and number of grown droplets coincides
    assert(number_of_collisions==actual_number_collisions and actual_number_collisions==number_of_grown_droplets)
    ####################################################################################
    return None

if __name__ == '__main__':
    main()
    check_results()
