/**********************************************************************
*                                                                     *
*  Copyright 2015 the TurTLE team                                     *
*                                                                     *
*  This file is part of TurTLE.                                       *
*                                                                     *
*  TurTLE is free software: you can redistribute it and/or modify     *
*  it under the terms of the GNU General Public License as published  *
*  by the Free Software Foundation, either version 3 of the License,  *
*  or (at your option) any later version.                             *
*                                                                     *
*  TurTLE is distributed in the hope that it will be useful,          *
*  but WITHOUT ANY WARRANTY; without even the implied warranty of     *
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      *
*  GNU General Public License for more details.                       *
*                                                                     *
*  You should have received a copy of the GNU General Public License  *
*  along with TurTLE.  If not, see <http://www.gnu.org/licenses/>     *
*                                                                     *
* Contact: Cristian.Lalescu@ds.mpg.de                                 *
*                                                                     *
**********************************************************************/



#include "spline_n10.hpp"
#include <cmath>

void beta_n10_m0(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = 0;
        poly_val[1] = 0;
        poly_val[2] = 0;
        poly_val[3] = 0;
        poly_val[4] = 0;
        poly_val[5] = 0;
        poly_val[6] = 0;
        poly_val[7] = 0;
        poly_val[8] = 0;
        poly_val[9] = 0;
        poly_val[10] = -x + 1;
        poly_val[11] = x;
        poly_val[12] = 0;
        poly_val[13] = 0;
        poly_val[14] = 0;
        poly_val[15] = 0;
        poly_val[16] = 0;
        poly_val[17] = 0;
        poly_val[18] = 0;
        poly_val[19] = 0;
        poly_val[20] = 0;
        poly_val[21] = 0;
        break;
    case 1:
        poly_val[0] = 0;
        poly_val[1] = 0;
        poly_val[2] = 0;
        poly_val[3] = 0;
        poly_val[4] = 0;
        poly_val[5] = 0;
        poly_val[6] = 0;
        poly_val[7] = 0;
        poly_val[8] = 0;
        poly_val[9] = 0;
        poly_val[10] = -1;
        poly_val[11] = 1;
        poly_val[12] = 0;
        poly_val[13] = 0;
        poly_val[14] = 0;
        poly_val[15] = 0;
        poly_val[16] = 0;
        poly_val[17] = 0;
        poly_val[18] = 0;
        poly_val[19] = 0;
        poly_val[20] = 0;
        poly_val[21] = 0;
        break;
    case 2:
        poly_val[0] = 0;
        poly_val[1] = 0;
        poly_val[2] = 0;
        poly_val[3] = 0;
        poly_val[4] = 0;
        poly_val[5] = 0;
        poly_val[6] = 0;
        poly_val[7] = 0;
        poly_val[8] = 0;
        poly_val[9] = 0;
        poly_val[10] = 0;
        poly_val[11] = 0;
        poly_val[12] = 0;
        poly_val[13] = 0;
        poly_val[14] = 0;
        poly_val[15] = 0;
        poly_val[16] = 0;
        poly_val[17] = 0;
        poly_val[18] = 0;
        poly_val[19] = 0;
        poly_val[20] = 0;
        poly_val[21] = 0;
        break;
    }
}
void beta_n10_m1(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = x*(x*((1.0L/1847560.0L)*x - 1.0L/923780.0L) + 1.0L/1847560.0L);
        poly_val[1] = x*(x*(-191.0L/16628040.0L*x + 23.0L/978120.0L) - 5.0L/415701.0L);
        poly_val[2] = x*(x*((775.0L/6651216.0L)*x - 815.0L/3325608.0L) + 5.0L/38896.0L);
        poly_val[3] = x*(x*(-205.0L/272272.0L*x + 445.0L/272272.0L) - 15.0L/17017.0L);
        poly_val[4] = x*(x*((475.0L/136136.0L)*x - 535.0L/68068.0L) + 5.0L/1144.0L);
        poly_val[5] = x*(x*(-71.0L/5720.0L*x + 167.0L/5720.0L) - 12.0L/715.0L);
        poly_val[6] = x*(x*((51.0L/1430.0L)*x - 63.0L/715.0L) + 15.0L/286.0L);
        poly_val[7] = x*(x*(-25.0L/286.0L*x + 5.0L/22.0L) - 20.0L/143.0L);
        poly_val[8] = x*(x*((115.0L/572.0L)*x - 155.0L/286.0L) + 15.0L/44.0L);
        poly_val[9] = x*(x*(-25.0L/44.0L*x + 65.0L/44.0L) - 10.0L/11.0L);
        poly_val[10] = pow(x, 2)*((12.0L/11.0L)*x - 23.0L/11.0L) + 1;
        poly_val[11] = x*(x*(-12.0L/11.0L*x + 13.0L/11.0L) + 10.0L/11.0L);
        poly_val[12] = x*(x*((25.0L/44.0L)*x - 5.0L/22.0L) - 15.0L/44.0L);
        poly_val[13] = x*(x*(-115.0L/572.0L*x + 35.0L/572.0L) + 20.0L/143.0L);
        poly_val[14] = x*(x*((25.0L/286.0L)*x - 5.0L/143.0L) - 15.0L/286.0L);
        poly_val[15] = x*(x*(-51.0L/1430.0L*x + 27.0L/1430.0L) + 12.0L/715.0L);
        poly_val[16] = x*(x*((71.0L/5720.0L)*x - 23.0L/2860.0L) - 5.0L/1144.0L);
        poly_val[17] = x*(x*(-475.0L/136136.0L*x + 355.0L/136136.0L) + 15.0L/17017.0L);
        poly_val[18] = x*(x*((205.0L/272272.0L)*x - 5.0L/8008.0L) - 5.0L/38896.0L);
        poly_val[19] = x*(x*(-775.0L/6651216.0L*x + 695.0L/6651216.0L) + 5.0L/415701.0L);
        poly_val[20] = x*(x*((191.0L/16628040.0L)*x - 7.0L/639540.0L) - 1.0L/1847560.0L);
        poly_val[21] = pow(x, 2)*(-1.0L/1847560.0L*x + 1.0L/1847560.0L);
        break;
    case 1:
        poly_val[0] = x*((3.0L/1847560.0L)*x - 1.0L/461890.0L) + 1.0L/1847560.0L;
        poly_val[1] = x*(-191.0L/5542680.0L*x + 23.0L/489060.0L) - 5.0L/415701.0L;
        poly_val[2] = x*((775.0L/2217072.0L)*x - 815.0L/1662804.0L) + 5.0L/38896.0L;
        poly_val[3] = x*(-615.0L/272272.0L*x + 445.0L/136136.0L) - 15.0L/17017.0L;
        poly_val[4] = x*((1425.0L/136136.0L)*x - 535.0L/34034.0L) + 5.0L/1144.0L;
        poly_val[5] = x*(-213.0L/5720.0L*x + 167.0L/2860.0L) - 12.0L/715.0L;
        poly_val[6] = x*((153.0L/1430.0L)*x - 126.0L/715.0L) + 15.0L/286.0L;
        poly_val[7] = x*(-75.0L/286.0L*x + 5.0L/11.0L) - 20.0L/143.0L;
        poly_val[8] = x*((345.0L/572.0L)*x - 155.0L/143.0L) + 15.0L/44.0L;
        poly_val[9] = x*(-75.0L/44.0L*x + 65.0L/22.0L) - 10.0L/11.0L;
        poly_val[10] = x*((36.0L/11.0L)*x - 46.0L/11.0L);
        poly_val[11] = x*(-36.0L/11.0L*x + 26.0L/11.0L) + 10.0L/11.0L;
        poly_val[12] = x*((75.0L/44.0L)*x - 5.0L/11.0L) - 15.0L/44.0L;
        poly_val[13] = x*(-345.0L/572.0L*x + 35.0L/286.0L) + 20.0L/143.0L;
        poly_val[14] = x*((75.0L/286.0L)*x - 10.0L/143.0L) - 15.0L/286.0L;
        poly_val[15] = x*(-153.0L/1430.0L*x + 27.0L/715.0L) + 12.0L/715.0L;
        poly_val[16] = x*((213.0L/5720.0L)*x - 23.0L/1430.0L) - 5.0L/1144.0L;
        poly_val[17] = x*(-1425.0L/136136.0L*x + 355.0L/68068.0L) + 15.0L/17017.0L;
        poly_val[18] = x*((615.0L/272272.0L)*x - 5.0L/4004.0L) - 5.0L/38896.0L;
        poly_val[19] = x*(-775.0L/2217072.0L*x + 695.0L/3325608.0L) + 5.0L/415701.0L;
        poly_val[20] = x*((191.0L/5542680.0L)*x - 7.0L/319770.0L) - 1.0L/1847560.0L;
        poly_val[21] = x*(-3.0L/1847560.0L*x + 1.0L/923780.0L);
        break;
    case 2:
        poly_val[0] = (3.0L/923780.0L)*x - 1.0L/461890.0L;
        poly_val[1] = -191.0L/2771340.0L*x + 23.0L/489060.0L;
        poly_val[2] = (775.0L/1108536.0L)*x - 815.0L/1662804.0L;
        poly_val[3] = -615.0L/136136.0L*x + 445.0L/136136.0L;
        poly_val[4] = (1425.0L/68068.0L)*x - 535.0L/34034.0L;
        poly_val[5] = -213.0L/2860.0L*x + 167.0L/2860.0L;
        poly_val[6] = (153.0L/715.0L)*x - 126.0L/715.0L;
        poly_val[7] = -75.0L/143.0L*x + 5.0L/11.0L;
        poly_val[8] = (345.0L/286.0L)*x - 155.0L/143.0L;
        poly_val[9] = -75.0L/22.0L*x + 65.0L/22.0L;
        poly_val[10] = (72.0L/11.0L)*x - 46.0L/11.0L;
        poly_val[11] = -72.0L/11.0L*x + 26.0L/11.0L;
        poly_val[12] = (75.0L/22.0L)*x - 5.0L/11.0L;
        poly_val[13] = -345.0L/286.0L*x + 35.0L/286.0L;
        poly_val[14] = (75.0L/143.0L)*x - 10.0L/143.0L;
        poly_val[15] = -153.0L/715.0L*x + 27.0L/715.0L;
        poly_val[16] = (213.0L/2860.0L)*x - 23.0L/1430.0L;
        poly_val[17] = -1425.0L/68068.0L*x + 355.0L/68068.0L;
        poly_val[18] = (615.0L/136136.0L)*x - 5.0L/4004.0L;
        poly_val[19] = -775.0L/1108536.0L*x + 695.0L/3325608.0L;
        poly_val[20] = (191.0L/2771340.0L)*x - 7.0L/319770.0L;
        poly_val[21] = -3.0L/923780.0L*x + 1.0L/923780.0L;
        break;
    }
}
void beta_n10_m2(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = x*(x*(x*(x*(-29.0L/18475600.0L*x + 7.0L/1679600.0L) - 3.0L/972400.0L) - 1.0L/18475600.0L) + 1.0L/1847560.0L);
        poly_val[1] = x*(x*(x*(x*((4499.0L/136047600.0L)*x - 5507.0L/62355150.0L) + 32893.0L/498841200.0L) + 5.0L/3741309.0L) - 5.0L/415701.0L);
        poly_val[2] = x*(x*(x*(x*(-159065.0L/478887552.0L*x + 427795.0L/478887552.0L) - 24815.0L/36837504.0L) - 5.0L/311168.0L) + 5.0L/38896.0L);
        poly_val[3] = x*(x*(x*(x*((32275.0L/15247232.0L)*x - 2575.0L/448448.0L) + 66795.0L/15247232.0L) + 15.0L/119119.0L) - 15.0L/17017.0L);
        poly_val[4] = x*(x*(x*(x*(-54965.0L/5717712.0L*x + 2955.0L/112112.0L) - 38855.0L/1905904.0L) - 5.0L/6864.0L) + 5.0L/1144.0L);
        poly_val[5] = x*(x*(x*(x*((5689.0L/171600.0L)*x - 3953.0L/42900.0L) + 12427.0L/171600.0L) + 12.0L/3575.0L) - 12.0L/715.0L);
        poly_val[6] = x*(x*(x*(x*(-2589.0L/28600.0L*x + 7323.0L/28600.0L) - 5859.0L/28600.0L) - 15.0L/1144.0L) + 15.0L/286.0L);
        poly_val[7] = x*(x*(x*(x*((695.0L/3432.0L)*x - 335.0L/572.0L) + 545.0L/1144.0L) + 20.0L/429.0L) - 20.0L/143.0L);
        poly_val[8] = x*(x*(x*(x*(-1325.0L/3432.0L*x + 3925.0L/3432.0L) - 245.0L/264.0L) - 15.0L/88.0L) + 15.0L/44.0L);
        poly_val[9] = x*(x*(x*(x*((5.0L/8.0L)*x - 20.0L/11.0L) + 105.0L/88.0L) + 10.0L/11.0L) - 10.0L/11.0L);
        poly_val[10] = pow(x, 2)*(x*(x*(-11370461.0L/13970880.0L*x + 10100381.0L/4656960.0L) - 3749981.0L/4656960.0L) - 1968329.0L/1270080.0L) + 1;
        poly_val[11] = x*(x*(x*(x*((11370461.0L/13970880.0L)*x - 1206871.0L/635040.0L) + 3749981.0L/13970880.0L) + 10.0L/11.0L) + 10.0L/11.0L);
        poly_val[12] = x*(x*(x*(x*(-5.0L/8.0L*x + 115.0L/88.0L) - 15.0L/88.0L) - 15.0L/88.0L) - 15.0L/44.0L);
        poly_val[13] = x*(x*(x*(x*((1325.0L/3432.0L)*x - 225.0L/286.0L) + 245.0L/1144.0L) + 20.0L/429.0L) + 20.0L/143.0L);
        poly_val[14] = x*(x*(x*(x*(-695.0L/3432.0L*x + 1465.0L/3432.0L) - 545.0L/3432.0L) - 15.0L/1144.0L) - 15.0L/286.0L);
        poly_val[15] = x*(x*(x*(x*((2589.0L/28600.0L)*x - 2811.0L/14300.0L) + 189.0L/2200.0L) + 12.0L/3575.0L) + 12.0L/715.0L);
        poly_val[16] = x*(x*(x*(x*(-5689.0L/171600.0L*x + 4211.0L/57200.0L) - 2023.0L/57200.0L) - 5.0L/6864.0L) - 5.0L/1144.0L);
        poly_val[17] = x*(x*(x*(x*((54965.0L/5717712.0L)*x - 15515.0L/714714.0L) + 63395.0L/5717712.0L) + 15.0L/119119.0L) + 15.0L/17017.0L);
        poly_val[18] = x*(x*(x*(x*(-32275.0L/15247232.0L*x + 73825.0L/15247232.0L) - 39345.0L/15247232.0L) - 5.0L/311168.0L) - 5.0L/38896.0L);
        poly_val[19] = x*(x*(x*(x*((159065.0L/478887552.0L)*x - 61255.0L/79814592.0L) + 3545.0L/8401536.0L) + 5.0L/3741309.0L) + 5.0L/415701.0L);
        poly_val[20] = x*(x*(x*(x*(-4499.0L/136047600.0L*x + 6781.0L/88030800.0L) - 64897.0L/1496523600.0L) - 1.0L/18475600.0L) - 1.0L/1847560.0L);
        poly_val[21] = pow(x, 3)*(x*((29.0L/18475600.0L)*x - 1.0L/271700.0L) + 3.0L/1421200.0L);
        break;
    case 1:
        poly_val[0] = x*(x*(x*(-29.0L/3695120.0L*x + 7.0L/419900.0L) - 9.0L/972400.0L) - 1.0L/9237800.0L) + 1.0L/1847560.0L;
        poly_val[1] = x*(x*(x*((4499.0L/27209520.0L)*x - 11014.0L/31177575.0L) + 32893.0L/166280400.0L) + 10.0L/3741309.0L) - 5.0L/415701.0L;
        poly_val[2] = x*(x*(x*(-795325.0L/478887552.0L*x + 427795.0L/119721888.0L) - 24815.0L/12279168.0L) - 5.0L/155584.0L) + 5.0L/38896.0L;
        poly_val[3] = x*(x*(x*((161375.0L/15247232.0L)*x - 2575.0L/112112.0L) + 200385.0L/15247232.0L) + 30.0L/119119.0L) - 15.0L/17017.0L;
        poly_val[4] = x*(x*(x*(-274825.0L/5717712.0L*x + 2955.0L/28028.0L) - 116565.0L/1905904.0L) - 5.0L/3432.0L) + 5.0L/1144.0L;
        poly_val[5] = x*(x*(x*((5689.0L/34320.0L)*x - 3953.0L/10725.0L) + 12427.0L/57200.0L) + 24.0L/3575.0L) - 12.0L/715.0L;
        poly_val[6] = x*(x*(x*(-2589.0L/5720.0L*x + 7323.0L/7150.0L) - 17577.0L/28600.0L) - 15.0L/572.0L) + 15.0L/286.0L;
        poly_val[7] = x*(x*(x*((3475.0L/3432.0L)*x - 335.0L/143.0L) + 1635.0L/1144.0L) + 40.0L/429.0L) - 20.0L/143.0L;
        poly_val[8] = x*(x*(x*(-6625.0L/3432.0L*x + 3925.0L/858.0L) - 245.0L/88.0L) - 15.0L/44.0L) + 15.0L/44.0L;
        poly_val[9] = x*(x*(x*((25.0L/8.0L)*x - 80.0L/11.0L) + 315.0L/88.0L) + 20.0L/11.0L) - 10.0L/11.0L;
        poly_val[10] = x*(x*(x*(-11370461.0L/2794176.0L*x + 10100381.0L/1164240.0L) - 3749981.0L/1552320.0L) - 1968329.0L/635040.0L);
        poly_val[11] = x*(x*(x*((11370461.0L/2794176.0L)*x - 1206871.0L/158760.0L) + 3749981.0L/4656960.0L) + 20.0L/11.0L) + 10.0L/11.0L;
        poly_val[12] = x*(x*(x*(-25.0L/8.0L*x + 115.0L/22.0L) - 45.0L/88.0L) - 15.0L/44.0L) - 15.0L/44.0L;
        poly_val[13] = x*(x*(x*((6625.0L/3432.0L)*x - 450.0L/143.0L) + 735.0L/1144.0L) + 40.0L/429.0L) + 20.0L/143.0L;
        poly_val[14] = x*(x*(x*(-3475.0L/3432.0L*x + 1465.0L/858.0L) - 545.0L/1144.0L) - 15.0L/572.0L) - 15.0L/286.0L;
        poly_val[15] = x*(x*(x*((2589.0L/5720.0L)*x - 2811.0L/3575.0L) + 567.0L/2200.0L) + 24.0L/3575.0L) + 12.0L/715.0L;
        poly_val[16] = x*(x*(x*(-5689.0L/34320.0L*x + 4211.0L/14300.0L) - 6069.0L/57200.0L) - 5.0L/3432.0L) - 5.0L/1144.0L;
        poly_val[17] = x*(x*(x*((274825.0L/5717712.0L)*x - 31030.0L/357357.0L) + 63395.0L/1905904.0L) + 30.0L/119119.0L) + 15.0L/17017.0L;
        poly_val[18] = x*(x*(x*(-161375.0L/15247232.0L*x + 73825.0L/3811808.0L) - 118035.0L/15247232.0L) - 5.0L/155584.0L) - 5.0L/38896.0L;
        poly_val[19] = x*(x*(x*((795325.0L/478887552.0L)*x - 61255.0L/19953648.0L) + 3545.0L/2800512.0L) + 10.0L/3741309.0L) + 5.0L/415701.0L;
        poly_val[20] = x*(x*(x*(-4499.0L/27209520.0L*x + 6781.0L/22007700.0L) - 64897.0L/498841200.0L) - 1.0L/9237800.0L) - 1.0L/1847560.0L;
        poly_val[21] = pow(x, 2)*(x*((29.0L/3695120.0L)*x - 1.0L/67925.0L) + 9.0L/1421200.0L);
        break;
    case 2:
        poly_val[0] = x*(x*(-29.0L/923780.0L*x + 21.0L/419900.0L) - 9.0L/486200.0L) - 1.0L/9237800.0L;
        poly_val[1] = x*(x*((4499.0L/6802380.0L)*x - 11014.0L/10392525.0L) + 32893.0L/83140200.0L) + 10.0L/3741309.0L;
        poly_val[2] = x*(x*(-795325.0L/119721888.0L*x + 427795.0L/39907296.0L) - 24815.0L/6139584.0L) - 5.0L/155584.0L;
        poly_val[3] = x*(x*((161375.0L/3811808.0L)*x - 7725.0L/112112.0L) + 200385.0L/7623616.0L) + 30.0L/119119.0L;
        poly_val[4] = x*(x*(-274825.0L/1429428.0L*x + 8865.0L/28028.0L) - 116565.0L/952952.0L) - 5.0L/3432.0L;
        poly_val[5] = x*(x*((5689.0L/8580.0L)*x - 3953.0L/3575.0L) + 12427.0L/28600.0L) + 24.0L/3575.0L;
        poly_val[6] = x*(x*(-2589.0L/1430.0L*x + 21969.0L/7150.0L) - 17577.0L/14300.0L) - 15.0L/572.0L;
        poly_val[7] = x*(x*((3475.0L/858.0L)*x - 1005.0L/143.0L) + 1635.0L/572.0L) + 40.0L/429.0L;
        poly_val[8] = x*(x*(-6625.0L/858.0L*x + 3925.0L/286.0L) - 245.0L/44.0L) - 15.0L/44.0L;
        poly_val[9] = x*(x*((25.0L/2.0L)*x - 240.0L/11.0L) + 315.0L/44.0L) + 20.0L/11.0L;
        poly_val[10] = x*(x*(-11370461.0L/698544.0L*x + 10100381.0L/388080.0L) - 3749981.0L/776160.0L) - 1968329.0L/635040.0L;
        poly_val[11] = x*(x*((11370461.0L/698544.0L)*x - 1206871.0L/52920.0L) + 3749981.0L/2328480.0L) + 20.0L/11.0L;
        poly_val[12] = x*(x*(-25.0L/2.0L*x + 345.0L/22.0L) - 45.0L/44.0L) - 15.0L/44.0L;
        poly_val[13] = x*(x*((6625.0L/858.0L)*x - 1350.0L/143.0L) + 735.0L/572.0L) + 40.0L/429.0L;
        poly_val[14] = x*(x*(-3475.0L/858.0L*x + 1465.0L/286.0L) - 545.0L/572.0L) - 15.0L/572.0L;
        poly_val[15] = x*(x*((2589.0L/1430.0L)*x - 8433.0L/3575.0L) + 567.0L/1100.0L) + 24.0L/3575.0L;
        poly_val[16] = x*(x*(-5689.0L/8580.0L*x + 12633.0L/14300.0L) - 6069.0L/28600.0L) - 5.0L/3432.0L;
        poly_val[17] = x*(x*((274825.0L/1429428.0L)*x - 31030.0L/119119.0L) + 63395.0L/952952.0L) + 30.0L/119119.0L;
        poly_val[18] = x*(x*(-161375.0L/3811808.0L*x + 221475.0L/3811808.0L) - 118035.0L/7623616.0L) - 5.0L/155584.0L;
        poly_val[19] = x*(x*((795325.0L/119721888.0L)*x - 61255.0L/6651216.0L) + 3545.0L/1400256.0L) + 10.0L/3741309.0L;
        poly_val[20] = x*(x*(-4499.0L/6802380.0L*x + 6781.0L/7335900.0L) - 64897.0L/249420600.0L) - 1.0L/9237800.0L;
        poly_val[21] = x*(x*((29.0L/923780.0L)*x - 3.0L/67925.0L) + 9.0L/710600.0L);
        break;
    }
}
void beta_n10_m3(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = x*(x*(x*(x*(x*(x*((51185699.0L/11732745024000.0L)*x - 4090369.0L/266653296000.0L) + 35733059.0L/1955457504000.0L) - 1072961.0L/154378224000.0L) - 514639.0L/617512896000.0L) - 1.0L/18475600.0L) + 1.0L/1847560.0L);
        poly_val[1] = x*(x*(x*(x*(x*(x*(-97750271.0L/1066613184000.0L*x + 3782441303.0L/11732745024000.0L) - 237253277.0L/617512896000.0L) + 18781351.0L/128931264000.0L) + 11419.0L/617512896.0L) + 5.0L/3741309.0L) - 5.0L/415701.0L);
        poly_val[2] = x*(x*(x*(x*(x*(x*((531225.0L/579394816.0L)*x - 75723343.0L/23465490048.0L) + 90288169.0L/23465490048.0L) - 1311199.0L/902518848.0L) - 487121.0L/2470051584.0L) - 5.0L/311168.0L) + 5.0L/38896.0L);
        poly_val[3] = x*(x*(x*(x*(x*(x*(-14351957.0L/2470051584.0L*x + 5616313.0L/274450176.0L) - 20100053.0L/823350528.0L) + 22641695.0L/2470051584.0L) + 5663.0L/4200768.0L) + 15.0L/119119.0L) - 15.0L/17017.0L);
        poly_val[4] = x*(x*(x*(x*(x*(x*((129283295.0L/4940103168.0L)*x - 10356823.0L/112275072.0L) + 90651851.0L/823350528.0L) - 50656289.0L/1235025792.0L) - 1933049.0L/290594304.0L) - 5.0L/6864.0L) + 5.0L/1144.0L);
        poly_val[5] = x*(x*(x*(x*(x*(x*(-294222911.0L/3302208000.0L*x + 346045183.0L/1100736000.0L) - 4545171157.0L/12108096000.0L) + 5019772789.0L/36324288000.0L) + 9587629.0L/378378000.0L) + 12.0L/3575.0L) - 12.0L/715.0L);
        poly_val[6] = x*(x*(x*(x*(x*(x*((720747847.0L/3027024000.0L)*x - 636560369.0L/756756000.0L) + 24128711.0L/24024000.0L) - 21109141.0L/58212000.0L) - 1888949.0L/24216192.0L) - 15.0L/1144.0L) + 15.0L/286.0L);
        poly_val[7] = x*(x*(x*(x*(x*(x*(-37195415.0L/72648576.0L*x + 131578253.0L/72648576.0L) - 52283503.0L/24216192.0L) + 54623759.0L/72648576.0L) + 1827209.0L/9081072.0L) + 20.0L/429.0L) - 20.0L/143.0L);
        poly_val[8] = x*(x*(x*(x*(x*(x*((130810913.0L/145297152.0L)*x - 1428677.0L/448448.0L) + 91285561.0L/24216192.0L) - 6286355.0L/5189184.0L) - 1650809.0L/3725568.0L) - 15.0L/88.0L) + 15.0L/44.0L);
        poly_val[9] = x*(x*(x*(x*(x*(x*(-1327945.0L/1016064.0L*x + 51572033.0L/11176704.0L) - 20028763.0L/3725568.0L) + 17535659.0L/11176704.0L) + 698249.0L/1397088.0L) + 10.0L/11.0L) - 10.0L/11.0L);
        poly_val[10] = pow(x, 2)*(pow(x, 2)*(x*(x*((10991207.0L/6985440.0L)*x - 571831.0L/103488.0L) + 8832661.0L/1397088.0L) - 1271555.0L/698544.0L) - 1968329.0L/1270080.0L) + 1;
        poly_val[11] = x*(x*(x*(x*(x*(x*(-10991207.0L/6985440.0L*x + 6970883.0L/1270080.0L) - 43387097.0L/6985440.0L) + 1841911.0L/931392.0L) - 698249.0L/1397088.0L) + 10.0L/11.0L) + 10.0L/11.0L);
        poly_val[12] = x*(x*(x*(x*(x*(x*((1327945.0L/1016064.0L)*x - 4223311.0L/931392.0L) + 9568231.0L/1862784.0L) - 5143529.0L/2794176.0L) + 1650809.0L/3725568.0L) - 15.0L/88.0L) - 15.0L/44.0L);
        poly_val[13] = x*(x*(x*(x*(x*(x*(-130810913.0L/145297152.0L*x + 452785043.0L/145297152.0L) - 24637831.0L/6918912.0L) + 197560625.0L/145297152.0L) - 1827209.0L/9081072.0L) + 20.0L/429.0L) + 20.0L/143.0L);
        poly_val[14] = x*(x*(x*(x*(x*(x*((37195415.0L/72648576.0L)*x - 10732471.0L/6054048.0L) + 24747451.0L/12108096.0L) - 1111433.0L/1397088.0L) + 1888949.0L/24216192.0L) - 15.0L/1144.0L) - 15.0L/286.0L);
        poly_val[15] = x*(x*(x*(x*(x*(x*(-720747847.0L/3027024000.0L*x + 227181223.0L/275184000.0L) - 107350871.0L/112112000.0L) + 12483133.0L/33264000.0L) - 9587629.0L/378378000.0L) + 12.0L/3575.0L) + 12.0L/715.0L);
        poly_val[16] = x*(x*(x*(x*(x*(x*((294222911.0L/3302208000.0L)*x - 255356207.0L/825552000.0L) + 2180676613.0L/6054048000.0L) - 1285312429.0L/9081072000.0L) + 1933049.0L/290594304.0L) - 5.0L/6864.0L) - 5.0L/1144.0L);
        poly_val[17] = x*(x*(x*(x*(x*(x*(-129283295.0L/4940103168.0L*x + 49920317.0L/548900352.0L) - 174886343.0L/1646701056.0L) + 206342519.0L/4940103168.0L) - 5663.0L/4200768.0L) + 15.0L/119119.0L) + 15.0L/17017.0L);
        poly_val[18] = x*(x*(x*(x*(x*(x*((14351957.0L/2470051584.0L)*x - 24958441.0L/1235025792.0L) + 9735059.0L/411675264.0L) - 5743835.0L/617512896.0L) + 487121.0L/2470051584.0L) - 5.0L/311168.0L) - 5.0L/38896.0L);
        poly_val[19] = x*(x*(x*(x*(x*(x*(-531225.0L/579394816.0L*x + 149757889.0L/46930980096.0L) - 175509947.0L/46930980096.0L) + 31049.0L/21111552.0L) - 11419.0L/617512896.0L) + 5.0L/3741309.0L) + 5.0L/415701.0L);
        poly_val[20] = x*(x*(x*(x*(x*(x*((97750271.0L/1066613184000.0L)*x - 936082391.0L/2933186256000.0L) + 16516831.0L/44108064000.0L) - 431798291.0L/2933186256000.0L) + 514639.0L/617512896000.0L) - 1.0L/18475600.0L) - 1.0L/1847560.0L);
        poly_val[21] = pow(x, 4)*(x*(x*(-51185699.0L/11732745024000.0L*x + 59441219.0L/3910915008000.0L) - 69813539.0L/3910915008000.0L) + 82302659.0L/11732745024000.0L);
        break;
    case 1:
        poly_val[0] = x*(x*(x*(x*(x*((51185699.0L/1676106432000.0L)*x - 4090369.0L/44442216000.0L) + 35733059.0L/391091500800.0L) - 1072961.0L/38594556000.0L) - 514639.0L/205837632000.0L) - 1.0L/9237800.0L) + 1.0L/1847560.0L;
        poly_val[1] = x*(x*(x*(x*(x*(-97750271.0L/152373312000.0L*x + 3782441303.0L/1955457504000.0L) - 237253277.0L/123502579200.0L) + 18781351.0L/32232816000.0L) + 11419.0L/205837632.0L) + 10.0L/3741309.0L) - 5.0L/415701.0L;
        poly_val[2] = x*(x*(x*(x*(x*((531225.0L/82770688.0L)*x - 75723343.0L/3910915008.0L) + 451440845.0L/23465490048.0L) - 1311199.0L/225629712.0L) - 487121.0L/823350528.0L) - 5.0L/155584.0L) + 5.0L/38896.0L;
        poly_val[3] = x*(x*(x*(x*(x*(-14351957.0L/352864512.0L*x + 5616313.0L/45741696.0L) - 100500265.0L/823350528.0L) + 22641695.0L/617512896.0L) + 5663.0L/1400256.0L) + 30.0L/119119.0L) - 15.0L/17017.0L;
        poly_val[4] = x*(x*(x*(x*(x*((129283295.0L/705729024.0L)*x - 10356823.0L/18712512.0L) + 453259255.0L/823350528.0L) - 50656289.0L/308756448.0L) - 1933049.0L/96864768.0L) - 5.0L/3432.0L) + 5.0L/1144.0L;
        poly_val[5] = x*(x*(x*(x*(x*(-294222911.0L/471744000.0L*x + 346045183.0L/183456000.0L) - 4545171157.0L/2421619200.0L) + 5019772789.0L/9081072000.0L) + 9587629.0L/126126000.0L) + 24.0L/3575.0L) - 12.0L/715.0L;
        poly_val[6] = x*(x*(x*(x*(x*((720747847.0L/432432000.0L)*x - 636560369.0L/126126000.0L) + 24128711.0L/4804800.0L) - 21109141.0L/14553000.0L) - 1888949.0L/8072064.0L) - 15.0L/572.0L) + 15.0L/286.0L;
        poly_val[7] = x*(x*(x*(x*(x*(-37195415.0L/10378368.0L*x + 131578253.0L/12108096.0L) - 261417515.0L/24216192.0L) + 54623759.0L/18162144.0L) + 1827209.0L/3027024.0L) + 40.0L/429.0L) - 20.0L/143.0L;
        poly_val[8] = x*(x*(x*(x*(x*((130810913.0L/20756736.0L)*x - 4286031.0L/224224.0L) + 456427805.0L/24216192.0L) - 6286355.0L/1297296.0L) - 1650809.0L/1241856.0L) - 15.0L/44.0L) + 15.0L/44.0L;
        poly_val[9] = x*(x*(x*(x*(x*(-1327945.0L/145152.0L*x + 51572033.0L/1862784.0L) - 100143815.0L/3725568.0L) + 17535659.0L/2794176.0L) + 698249.0L/465696.0L) + 20.0L/11.0L) - 10.0L/11.0L;
        poly_val[10] = x*(pow(x, 2)*(x*(x*((10991207.0L/997920.0L)*x - 571831.0L/17248.0L) + 44163305.0L/1397088.0L) - 1271555.0L/174636.0L) - 1968329.0L/635040.0L);
        poly_val[11] = x*(x*(x*(x*(x*(-10991207.0L/997920.0L*x + 6970883.0L/211680.0L) - 43387097.0L/1397088.0L) + 1841911.0L/232848.0L) - 698249.0L/465696.0L) + 20.0L/11.0L) + 10.0L/11.0L;
        poly_val[12] = x*(x*(x*(x*(x*((1327945.0L/145152.0L)*x - 4223311.0L/155232.0L) + 47841155.0L/1862784.0L) - 5143529.0L/698544.0L) + 1650809.0L/1241856.0L) - 15.0L/44.0L) - 15.0L/44.0L;
        poly_val[13] = x*(x*(x*(x*(x*(-130810913.0L/20756736.0L*x + 452785043.0L/24216192.0L) - 123189155.0L/6918912.0L) + 197560625.0L/36324288.0L) - 1827209.0L/3027024.0L) + 40.0L/429.0L) + 20.0L/143.0L;
        poly_val[14] = x*(x*(x*(x*(x*((37195415.0L/10378368.0L)*x - 10732471.0L/1009008.0L) + 123737255.0L/12108096.0L) - 1111433.0L/349272.0L) + 1888949.0L/8072064.0L) - 15.0L/572.0L) - 15.0L/286.0L;
        poly_val[15] = x*(x*(x*(x*(x*(-720747847.0L/432432000.0L*x + 227181223.0L/45864000.0L) - 107350871.0L/22422400.0L) + 12483133.0L/8316000.0L) - 9587629.0L/126126000.0L) + 24.0L/3575.0L) + 12.0L/715.0L;
        poly_val[16] = x*(x*(x*(x*(x*((294222911.0L/471744000.0L)*x - 255356207.0L/137592000.0L) + 2180676613.0L/1210809600.0L) - 1285312429.0L/2270268000.0L) + 1933049.0L/96864768.0L) - 5.0L/3432.0L) - 5.0L/1144.0L;
        poly_val[17] = x*(x*(x*(x*(x*(-129283295.0L/705729024.0L*x + 49920317.0L/91483392.0L) - 874431715.0L/1646701056.0L) + 206342519.0L/1235025792.0L) - 5663.0L/1400256.0L) + 30.0L/119119.0L) + 15.0L/17017.0L;
        poly_val[18] = x*(x*(x*(x*(x*((14351957.0L/352864512.0L)*x - 24958441.0L/205837632.0L) + 48675295.0L/411675264.0L) - 5743835.0L/154378224.0L) + 487121.0L/823350528.0L) - 5.0L/155584.0L) - 5.0L/38896.0L;
        poly_val[19] = x*(x*(x*(x*(x*(-531225.0L/82770688.0L*x + 149757889.0L/7821830016.0L) - 877549735.0L/46930980096.0L) + 31049.0L/5277888.0L) - 11419.0L/205837632.0L) + 10.0L/3741309.0L) + 5.0L/415701.0L;
        poly_val[20] = x*(x*(x*(x*(x*((97750271.0L/152373312000.0L)*x - 936082391.0L/488864376000.0L) + 16516831.0L/8821612800.0L) - 431798291.0L/733296564000.0L) + 514639.0L/205837632000.0L) - 1.0L/9237800.0L) - 1.0L/1847560.0L;
        poly_val[21] = pow(x, 3)*(x*(x*(-51185699.0L/1676106432000.0L*x + 59441219.0L/651819168000.0L) - 69813539.0L/782183001600.0L) + 82302659.0L/2933186256000.0L);
        break;
    case 2:
        poly_val[0] = x*(x*(x*(x*((51185699.0L/279351072000.0L)*x - 4090369.0L/8888443200.0L) + 35733059.0L/97772875200.0L) - 1072961.0L/12864852000.0L) - 514639.0L/102918816000.0L) - 1.0L/9237800.0L;
        poly_val[1] = x*(x*(x*(x*(-97750271.0L/25395552000.0L*x + 3782441303.0L/391091500800.0L) - 237253277.0L/30875644800.0L) + 18781351.0L/10744272000.0L) + 11419.0L/102918816.0L) + 10.0L/3741309.0L;
        poly_val[2] = x*(x*(x*(x*((1593675.0L/41385344.0L)*x - 378616715.0L/3910915008.0L) + 451440845.0L/5866372512.0L) - 1311199.0L/75209904.0L) - 487121.0L/411675264.0L) - 5.0L/155584.0L;
        poly_val[3] = x*(x*(x*(x*(-14351957.0L/58810752.0L*x + 28081565.0L/45741696.0L) - 100500265.0L/205837632.0L) + 22641695.0L/205837632.0L) + 5663.0L/700128.0L) + 30.0L/119119.0L;
        poly_val[4] = x*(x*(x*(x*((129283295.0L/117621504.0L)*x - 51784115.0L/18712512.0L) + 453259255.0L/205837632.0L) - 50656289.0L/102918816.0L) - 1933049.0L/48432384.0L) - 5.0L/3432.0L;
        poly_val[5] = x*(x*(x*(x*(-294222911.0L/78624000.0L*x + 346045183.0L/36691200.0L) - 4545171157.0L/605404800.0L) + 5019772789.0L/3027024000.0L) + 9587629.0L/63063000.0L) + 24.0L/3575.0L;
        poly_val[6] = x*(x*(x*(x*((720747847.0L/72072000.0L)*x - 636560369.0L/25225200.0L) + 24128711.0L/1201200.0L) - 21109141.0L/4851000.0L) - 1888949.0L/4036032.0L) - 15.0L/572.0L;
        poly_val[7] = x*(x*(x*(x*(-37195415.0L/1729728.0L*x + 657891265.0L/12108096.0L) - 261417515.0L/6054048.0L) + 54623759.0L/6054048.0L) + 1827209.0L/1513512.0L) + 40.0L/429.0L;
        poly_val[8] = x*(x*(x*(x*((130810913.0L/3459456.0L)*x - 21430155.0L/224224.0L) + 456427805.0L/6054048.0L) - 6286355.0L/432432.0L) - 1650809.0L/620928.0L) - 15.0L/44.0L;
        poly_val[9] = x*(x*(x*(x*(-1327945.0L/24192.0L*x + 257860165.0L/1862784.0L) - 100143815.0L/931392.0L) + 17535659.0L/931392.0L) + 698249.0L/232848.0L) + 20.0L/11.0L;
        poly_val[10] = pow(x, 2)*(x*(x*((10991207.0L/166320.0L)*x - 2859155.0L/17248.0L) + 44163305.0L/349272.0L) - 1271555.0L/58212.0L) - 1968329.0L/635040.0L;
        poly_val[11] = x*(x*(x*(x*(-10991207.0L/166320.0L*x + 6970883.0L/42336.0L) - 43387097.0L/349272.0L) + 1841911.0L/77616.0L) - 698249.0L/232848.0L) + 20.0L/11.0L;
        poly_val[12] = x*(x*(x*(x*((1327945.0L/24192.0L)*x - 21116555.0L/155232.0L) + 47841155.0L/465696.0L) - 5143529.0L/232848.0L) + 1650809.0L/620928.0L) - 15.0L/44.0L;
        poly_val[13] = x*(x*(x*(x*(-130810913.0L/3459456.0L*x + 2263925215.0L/24216192.0L) - 123189155.0L/1729728.0L) + 197560625.0L/12108096.0L) - 1827209.0L/1513512.0L) + 40.0L/429.0L;
        poly_val[14] = x*(x*(x*(x*((37195415.0L/1729728.0L)*x - 53662355.0L/1009008.0L) + 123737255.0L/3027024.0L) - 1111433.0L/116424.0L) + 1888949.0L/4036032.0L) - 15.0L/572.0L;
        poly_val[15] = x*(x*(x*(x*(-720747847.0L/72072000.0L*x + 227181223.0L/9172800.0L) - 107350871.0L/5605600.0L) + 12483133.0L/2772000.0L) - 9587629.0L/63063000.0L) + 24.0L/3575.0L;
        poly_val[16] = x*(x*(x*(x*((294222911.0L/78624000.0L)*x - 255356207.0L/27518400.0L) + 2180676613.0L/302702400.0L) - 1285312429.0L/756756000.0L) + 1933049.0L/48432384.0L) - 5.0L/3432.0L;
        poly_val[17] = x*(x*(x*(x*(-129283295.0L/117621504.0L*x + 249601585.0L/91483392.0L) - 874431715.0L/411675264.0L) + 206342519.0L/411675264.0L) - 5663.0L/700128.0L) + 30.0L/119119.0L;
        poly_val[18] = x*(x*(x*(x*((14351957.0L/58810752.0L)*x - 124792205.0L/205837632.0L) + 48675295.0L/102918816.0L) - 5743835.0L/51459408.0L) + 487121.0L/411675264.0L) - 5.0L/155584.0L;
        poly_val[19] = x*(x*(x*(x*(-1593675.0L/41385344.0L*x + 748789445.0L/7821830016.0L) - 877549735.0L/11732745024.0L) + 31049.0L/1759296.0L) - 11419.0L/102918816.0L) + 10.0L/3741309.0L;
        poly_val[20] = x*(x*(x*(x*((97750271.0L/25395552000.0L)*x - 936082391.0L/97772875200.0L) + 16516831.0L/2205403200.0L) - 431798291.0L/244432188000.0L) + 514639.0L/102918816000.0L) - 1.0L/9237800.0L;
        poly_val[21] = pow(x, 2)*(x*(x*(-51185699.0L/279351072000.0L*x + 59441219.0L/130363833600.0L) - 69813539.0L/195545750400.0L) + 82302659.0L/977728752000.0L);
        break;
    }
}
void beta_n10_m4(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(-33637859.0L/2394437760000.0L*x + 1483649773.0L/23465490048000.0L) - 316964689.0L/2933186256000.0L) + 324820967.0L/3910915008000.0L) - 1736957.0L/72648576000.0L) + 514639.0L/6175128960000.0L) - 514639.0L/617512896000.0L) - 1.0L/18475600.0L) + 1.0L/1847560.0L);
        poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*((311524262719.0L/1055947052160000.0L)*x - 701042962783.0L/527973526080000.0L) + 74885259587.0L/32998345380000.0L) - 70831176221.0L/40613348160000.0L) + 75682379687.0L/150849578880000.0L) - 11419.0L/5557616064.0L) + 11419.0L/617512896.0L) + 5.0L/3741309.0L) - 5.0L/415701.0L);
        poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(-9968948243.0L/3379030566912.0L*x + 44868219719.0L/3379030566912.0L) - 12780882041.0L/563171761152.0L) + 29463096031.0L/1689515283456.0L) - 16937158895.0L/3379030566912.0L) + 487121.0L/19760412672.0L) - 487121.0L/2470051584.0L) - 5.0L/311168.0L) + 5.0L/38896.0L);
        poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*((4795181.0L/256628736.0L)*x - 31958747.0L/380007936.0L) + 473385725.0L/3293402112.0L) - 41964919.0L/380007936.0L) + 6885539.0L/217147392.0L) - 809.0L/4200768.0L) + 5663.0L/4200768.0L) + 15.0L/119119.0L) - 15.0L/17017.0L);
        poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(-356053741.0L/4234374144.0L*x + 11218117517.0L/29640619008.0L) - 684750301.0L/1058593536.0L) + 7363490045.0L/14820309504.0L) - 4223360627.0L/29640619008.0L) + 1933049.0L/1743565824.0L) - 1933049.0L/290594304.0L) - 5.0L/6864.0L) + 5.0L/1144.0L);
        poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*((311561305079.0L/1089728640000.0L)*x - 140236087829.0L/108972864000.0L) + 39945615029.0L/18162144000.0L) - 184035443699.0L/108972864000.0L) + 105391706569.0L/217945728000.0L) - 9587629.0L/1891890000.0L) + 9587629.0L/378378000.0L) + 12.0L/3575.0L) - 12.0L/715.0L);
        poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(-46160205953.0L/60540480000.0L*x + 5327562143.0L/1552320000.0L) - 3623292631.0L/617760000.0L) + 136260296441.0L/30270240000.0L) - 25964084431.0L/20180160000.0L) + 1888949.0L/96864768.0L) - 1888949.0L/24216192.0L) - 15.0L/1144.0L) + 15.0L/286.0L);
        poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*((18499877.0L/11321856.0L)*x - 801489739.0L/108972864.0L) + 782601527.0L/62270208.0L) - 262586183.0L/27243216.0L) + 2398107605.0L/871782912.0L) - 1827209.0L/27243216.0L) + 1827209.0L/9081072.0L) + 20.0L/429.0L) - 20.0L/143.0L);
        poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(-2493086731.0L/871782912.0L*x + 11221599217.0L/871782912.0L) - 399388835.0L/18162144.0L) + 7345256297.0L/435891456.0L) - 46195777.0L/9580032.0L) + 1650809.0L/7451136.0L) - 1650809.0L/3725568.0L) - 15.0L/88.0L) + 15.0L/44.0L);
        poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*((92343961.0L/22353408.0L)*x - 207809573.0L/11176704.0L) + 88727773.0L/2794176.0L) - 90615265.0L/3725568.0L) + 157144591.0L/22353408.0L) - 698249.0L/1397088.0L) + 698249.0L/1397088.0L) + 10.0L/11.0L) - 10.0L/11.0L);
        poly_val[10] = pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(-178100340673.0L/35925120000.0L*x + 1122102226711.0L/50295168000.0L) - 957933723511.0L/25147584000.0L) + 733946977711.0L/25147584000.0L) - 61475136673.0L/7185024000.0L) + 307869749.0L/466560000.0L) - 1968329.0L/1270080.0L) + 1;
        poly_val[11] = x*(x*(x*(x*(x*(x*(x*(x*((178100340673.0L/35925120000.0L)*x - 1402452582211.0L/62868960000.0L) + 228012714673.0L/5987520000.0L) - 1836144861211.0L/62868960000.0L) + 2176770052711.0L/251475840000.0L) - 698249.0L/1397088.0L) - 698249.0L/1397088.0L) + 10.0L/11.0L) + 10.0L/11.0L);
        poly_val[12] = x*(x*(x*(x*(x*(x*(x*(x*(-92343961.0L/22353408.0L*x + 415476503.0L/22353408.0L) - 59104301.0L/1862784.0L) + 272310167.0L/11176704.0L) - 161927825.0L/22353408.0L) + 1650809.0L/7451136.0L) + 1650809.0L/3725568.0L) - 15.0L/88.0L) - 15.0L/44.0L);
        poly_val[13] = x*(x*(x*(x*(x*(x*(x*(x*((2493086731.0L/871782912.0L)*x - 5608090681.0L/435891456.0L) + 683892595.0L/31135104.0L) - 7359321647.0L/435891456.0L) + 4364057777.0L/871782912.0L) - 1827209.0L/27243216.0L) - 1827209.0L/9081072.0L) + 20.0L/429.0L) + 20.0L/143.0L);
        poly_val[14] = x*(x*(x*(x*(x*(x*(x*(x*(-18499877.0L/11321856.0L*x + 6408496849.0L/871782912.0L) - 1823789521.0L/145297152.0L) + 323680565.0L/33530112.0L) - 2484812989.0L/871782912.0L) + 1888949.0L/96864768.0L) + 1888949.0L/24216192.0L) - 15.0L/1144.0L) - 15.0L/286.0L);
        poly_val[15] = x*(x*(x*(x*(x*(x*(x*(x*((46160205953.0L/60540480000.0L)*x - 6922231.0L/2018016.0L) + 35465070353.0L/6054048000.0L) - 6820439797.0L/1513512000.0L) + 254905271.0L/192192000.0L) - 9587629.0L/1891890000.0L) - 9587629.0L/378378000.0L) + 12.0L/3575.0L) + 12.0L/715.0L);
        poly_val[16] = x*(x*(x*(x*(x*(x*(x*(x*(-311561305079.0L/1089728640000.0L*x + 107822374417.0L/83825280000.0L) - 299257107283.0L/136216080000.0L) + 70840342681.0L/41912640000.0L) - 41601700243.0L/83825280000.0L) + 1933049.0L/1743565824.0L) + 1933049.0L/290594304.0L) - 5.0L/6864.0L) - 5.0L/1144.0L);
        poly_val[17] = x*(x*(x*(x*(x*(x*(x*(x*((356053741.0L/4234374144.0L)*x - 5606634083.0L/14820309504.0L) + 399033563.0L/617512896.0L) - 7368194069.0L/14820309504.0L) + 5185445.0L/35582976.0L) - 809.0L/4200768.0L) - 5663.0L/4200768.0L) + 15.0L/119119.0L) + 15.0L/17017.0L);
        poly_val[18] = x*(x*(x*(x*(x*(x*(x*(x*(-4795181.0L/256628736.0L*x + 1661205589.0L/19760412672.0L) - 202694095.0L/1411458048.0L) + 40431847.0L/365933568.0L) - 639105469.0L/19760412672.0L) + 487121.0L/19760412672.0L) + 487121.0L/2470051584.0L) - 5.0L/311168.0L) - 5.0L/38896.0L);
        poly_val[19] = x*(x*(x*(x*(x*(x*(x*(x*((9968948243.0L/3379030566912.0L)*x - 862544509.0L/64981357056.0L) + 38310835621.0L/1689515283456.0L) - 14738088485.0L/844757641728.0L) + 907279897.0L/177843714048.0L) - 11419.0L/5557616064.0L) - 11419.0L/617512896.0L) + 5.0L/3741309.0L) + 5.0L/415701.0L);
        poly_val[20] = x*(x*(x*(x*(x*(x*(x*(x*(-311524262719.0L/1055947052160000.0L*x + 280326487781.0L/211189410432000.0L) - 5701224667.0L/2514159648000.0L) + 184231971829.0L/105594705216000.0L) - 107650576139.0L/211189410432000.0L) + 514639.0L/6175128960000.0L) + 514639.0L/617512896000.0L) - 1.0L/18475600.0L) - 1.0L/1847560.0L);
        poly_val[21] = pow(x, 5)*(x*(x*(x*((33637859.0L/2394437760000.0L)*x - 3708023477.0L/58663725120000.0L) + 39104259.0L/362121760000.0L) - 4873971667.0L/58663725120000.0L) + 218919637.0L/9025188480000.0L);
        break;
    case 1:
        poly_val[0] = x*(x*(x*(x*(x*(x*(x*(-33637859.0L/266048640000.0L*x + 1483649773.0L/2933186256000.0L) - 316964689.0L/419026608000.0L) + 324820967.0L/651819168000.0L) - 1736957.0L/14529715200.0L) + 514639.0L/1543782240000.0L) - 514639.0L/205837632000.0L) - 1.0L/9237800.0L) + 1.0L/1847560.0L;
        poly_val[1] = x*(x*(x*(x*(x*(x*(x*((311524262719.0L/117327450240000.0L)*x - 701042962783.0L/65996690760000.0L) + 74885259587.0L/4714049340000.0L) - 70831176221.0L/6768891360000.0L) + 75682379687.0L/30169915776000.0L) - 11419.0L/1389404016.0L) + 11419.0L/205837632.0L) + 10.0L/3741309.0L) - 5.0L/415701.0L;
        poly_val[2] = x*(x*(x*(x*(x*(x*(x*(-9968948243.0L/375447840768.0L*x + 44868219719.0L/422378820864.0L) - 12780882041.0L/80453108736.0L) + 29463096031.0L/281585880576.0L) - 84685794475.0L/3379030566912.0L) + 487121.0L/4940103168.0L) - 487121.0L/823350528.0L) - 5.0L/155584.0L) + 5.0L/38896.0L;
        poly_val[3] = x*(x*(x*(x*(x*(x*(x*((4795181.0L/28514304.0L)*x - 31958747.0L/47500992.0L) + 473385725.0L/470486016.0L) - 41964919.0L/63334656.0L) + 34427695.0L/217147392.0L) - 809.0L/1050192.0L) + 5663.0L/1400256.0L) + 30.0L/119119.0L) - 15.0L/17017.0L;
        poly_val[4] = x*(x*(x*(x*(x*(x*(x*(-356053741.0L/470486016.0L*x + 11218117517.0L/3705077376.0L) - 684750301.0L/151227648.0L) + 7363490045.0L/2470051584.0L) - 21116803135.0L/29640619008.0L) + 1933049.0L/435891456.0L) - 1933049.0L/96864768.0L) - 5.0L/3432.0L) + 5.0L/1144.0L;
        poly_val[5] = x*(x*(x*(x*(x*(x*(x*((311561305079.0L/121080960000.0L)*x - 140236087829.0L/13621608000.0L) + 39945615029.0L/2594592000.0L) - 184035443699.0L/18162144000.0L) + 105391706569.0L/43589145600.0L) - 9587629.0L/472972500.0L) + 9587629.0L/126126000.0L) + 24.0L/3575.0L) - 12.0L/715.0L;
        poly_val[6] = x*(x*(x*(x*(x*(x*(x*(-46160205953.0L/6726720000.0L*x + 5327562143.0L/194040000.0L) - 25363048417.0L/617760000.0L) + 136260296441.0L/5045040000.0L) - 25964084431.0L/4036032000.0L) + 1888949.0L/24216192.0L) - 1888949.0L/8072064.0L) - 15.0L/572.0L) + 15.0L/286.0L;
        poly_val[7] = x*(x*(x*(x*(x*(x*(x*((18499877.0L/1257984.0L)*x - 801489739.0L/13621608.0L) + 782601527.0L/8895744.0L) - 262586183.0L/4540536.0L) + 11990538025.0L/871782912.0L) - 1827209.0L/6810804.0L) + 1827209.0L/3027024.0L) + 40.0L/429.0L) - 20.0L/143.0L;
        poly_val[8] = x*(x*(x*(x*(x*(x*(x*(-2493086731.0L/96864768.0L*x + 11221599217.0L/108972864.0L) - 399388835.0L/2594592.0L) + 7345256297.0L/72648576.0L) - 230978885.0L/9580032.0L) + 1650809.0L/1862784.0L) - 1650809.0L/1241856.0L) - 15.0L/44.0L) + 15.0L/44.0L;
        poly_val[9] = x*(x*(x*(x*(x*(x*(x*((92343961.0L/2483712.0L)*x - 207809573.0L/1397088.0L) + 88727773.0L/399168.0L) - 90615265.0L/620928.0L) + 785722955.0L/22353408.0L) - 698249.0L/349272.0L) + 698249.0L/465696.0L) + 20.0L/11.0L) - 10.0L/11.0L;
        poly_val[10] = x*(pow(x, 2)*(x*(x*(x*(x*(-178100340673.0L/3991680000.0L*x + 1122102226711.0L/6286896000.0L) - 957933723511.0L/3592512000.0L) + 733946977711.0L/4191264000.0L) - 61475136673.0L/1437004800.0L) + 307869749.0L/116640000.0L) - 1968329.0L/635040.0L);
        poly_val[11] = x*(x*(x*(x*(x*(x*(x*((178100340673.0L/3991680000.0L)*x - 1402452582211.0L/7858620000.0L) + 228012714673.0L/855360000.0L) - 1836144861211.0L/10478160000.0L) + 2176770052711.0L/50295168000.0L) - 698249.0L/349272.0L) - 698249.0L/465696.0L) + 20.0L/11.0L) + 10.0L/11.0L;
        poly_val[12] = x*(x*(x*(x*(x*(x*(x*(-92343961.0L/2483712.0L*x + 415476503.0L/2794176.0L) - 59104301.0L/266112.0L) + 272310167.0L/1862784.0L) - 809639125.0L/22353408.0L) + 1650809.0L/1862784.0L) + 1650809.0L/1241856.0L) - 15.0L/44.0L) - 15.0L/44.0L;
        poly_val[13] = x*(x*(x*(x*(x*(x*(x*((2493086731.0L/96864768.0L)*x - 5608090681.0L/54486432.0L) + 683892595.0L/4447872.0L) - 7359321647.0L/72648576.0L) + 21820288885.0L/871782912.0L) - 1827209.0L/6810804.0L) - 1827209.0L/3027024.0L) + 40.0L/429.0L) + 20.0L/143.0L;
        poly_val[14] = x*(x*(x*(x*(x*(x*(x*(-18499877.0L/1257984.0L*x + 6408496849.0L/108972864.0L) - 1823789521.0L/20756736.0L) + 323680565.0L/5588352.0L) - 12424064945.0L/871782912.0L) + 1888949.0L/24216192.0L) + 1888949.0L/8072064.0L) - 15.0L/572.0L) - 15.0L/286.0L;
        poly_val[15] = x*(x*(x*(x*(x*(x*(x*((46160205953.0L/6726720000.0L)*x - 6922231.0L/252252.0L) + 35465070353.0L/864864000.0L) - 6820439797.0L/252252000.0L) + 254905271.0L/38438400.0L) - 9587629.0L/472972500.0L) - 9587629.0L/126126000.0L) + 24.0L/3575.0L) + 12.0L/715.0L;
        poly_val[16] = x*(x*(x*(x*(x*(x*(x*(-311561305079.0L/121080960000.0L*x + 107822374417.0L/10478160000.0L) - 299257107283.0L/19459440000.0L) + 70840342681.0L/6985440000.0L) - 41601700243.0L/16765056000.0L) + 1933049.0L/435891456.0L) + 1933049.0L/96864768.0L) - 5.0L/3432.0L) - 5.0L/1144.0L;
        poly_val[17] = x*(x*(x*(x*(x*(x*(x*((356053741.0L/470486016.0L)*x - 5606634083.0L/1852538688.0L) + 399033563.0L/88216128.0L) - 7368194069.0L/2470051584.0L) + 25927225.0L/35582976.0L) - 809.0L/1050192.0L) - 5663.0L/1400256.0L) + 30.0L/119119.0L) + 15.0L/17017.0L;
        poly_val[18] = x*(x*(x*(x*(x*(x*(x*(-4795181.0L/28514304.0L*x + 1661205589.0L/2470051584.0L) - 202694095.0L/201636864.0L) + 40431847.0L/60988928.0L) - 3195527345.0L/19760412672.0L) + 487121.0L/4940103168.0L) + 487121.0L/823350528.0L) - 5.0L/155584.0L) - 5.0L/38896.0L;
        poly_val[19] = x*(x*(x*(x*(x*(x*(x*((9968948243.0L/375447840768.0L)*x - 862544509.0L/8122669632.0L) + 38310835621.0L/241359326208.0L) - 14738088485.0L/140792940288.0L) + 4536399485.0L/177843714048.0L) - 11419.0L/1389404016.0L) - 11419.0L/205837632.0L) + 10.0L/3741309.0L) + 5.0L/415701.0L;
        poly_val[20] = x*(x*(x*(x*(x*(x*(x*(-311524262719.0L/117327450240000.0L*x + 280326487781.0L/26398676304000.0L) - 5701224667.0L/359165664000.0L) + 184231971829.0L/17599117536000.0L) - 107650576139.0L/42237882086400.0L) + 514639.0L/1543782240000.0L) + 514639.0L/205837632000.0L) - 1.0L/9237800.0L) - 1.0L/1847560.0L;
        poly_val[21] = pow(x, 4)*(x*(x*(x*((33637859.0L/266048640000.0L)*x - 3708023477.0L/7332965640000.0L) + 39104259.0L/51731680000.0L) - 4873971667.0L/9777287520000.0L) + 218919637.0L/1805037696000.0L);
        break;
    case 2:
        poly_val[0] = x*(x*(x*(x*(x*(x*(-33637859.0L/33256080000.0L*x + 1483649773.0L/419026608000.0L) - 316964689.0L/69837768000.0L) + 324820967.0L/130363833600.0L) - 1736957.0L/3632428800.0L) + 514639.0L/514594080000.0L) - 514639.0L/102918816000.0L) - 1.0L/9237800.0L;
        poly_val[1] = x*(x*(x*(x*(x*(x*((311524262719.0L/14665931280000.0L)*x - 701042962783.0L/9428098680000.0L) + 74885259587.0L/785674890000.0L) - 70831176221.0L/1353778272000.0L) + 75682379687.0L/7542478944000.0L) - 11419.0L/463134672.0L) + 11419.0L/102918816.0L) + 10.0L/3741309.0L;
        poly_val[2] = x*(x*(x*(x*(x*(x*(-9968948243.0L/46930980096.0L*x + 44868219719.0L/60339831552.0L) - 12780882041.0L/13408851456.0L) + 147315480155.0L/281585880576.0L) - 84685794475.0L/844757641728.0L) + 487121.0L/1646701056.0L) - 487121.0L/411675264.0L) - 5.0L/155584.0L;
        poly_val[3] = x*(x*(x*(x*(x*(x*((4795181.0L/3564288.0L)*x - 31958747.0L/6785856.0L) + 473385725.0L/78414336.0L) - 209824595.0L/63334656.0L) + 34427695.0L/54286848.0L) - 809.0L/350064.0L) + 5663.0L/700128.0L) + 30.0L/119119.0L;
        poly_val[4] = x*(x*(x*(x*(x*(x*(-356053741.0L/58810752.0L*x + 11218117517.0L/529296768.0L) - 684750301.0L/25204608.0L) + 36817450225.0L/2470051584.0L) - 21116803135.0L/7410154752.0L) + 1933049.0L/145297152.0L) - 1933049.0L/48432384.0L) - 5.0L/3432.0L;
        poly_val[5] = x*(x*(x*(x*(x*(x*((311561305079.0L/15135120000.0L)*x - 140236087829.0L/1945944000.0L) + 39945615029.0L/432432000.0L) - 184035443699.0L/3632428800.0L) + 105391706569.0L/10897286400.0L) - 9587629.0L/157657500.0L) + 9587629.0L/63063000.0L) + 24.0L/3575.0L;
        poly_val[6] = x*(x*(x*(x*(x*(x*(-46160205953.0L/840840000.0L*x + 5327562143.0L/27720000.0L) - 25363048417.0L/102960000.0L) + 136260296441.0L/1009008000.0L) - 25964084431.0L/1009008000.0L) + 1888949.0L/8072064.0L) - 1888949.0L/4036032.0L) - 15.0L/572.0L;
        poly_val[7] = x*(x*(x*(x*(x*(x*((18499877.0L/157248.0L)*x - 801489739.0L/1945944.0L) + 782601527.0L/1482624.0L) - 1312930915.0L/4540536.0L) + 11990538025.0L/217945728.0L) - 1827209.0L/2270268.0L) + 1827209.0L/1513512.0L) + 40.0L/429.0L;
        poly_val[8] = x*(x*(x*(x*(x*(x*(-2493086731.0L/12108096.0L*x + 11221599217.0L/15567552.0L) - 399388835.0L/432432.0L) + 36726281485.0L/72648576.0L) - 230978885.0L/2395008.0L) + 1650809.0L/620928.0L) - 1650809.0L/620928.0L) - 15.0L/44.0L;
        poly_val[9] = x*(x*(x*(x*(x*(x*((92343961.0L/310464.0L)*x - 207809573.0L/199584.0L) + 88727773.0L/66528.0L) - 453076325.0L/620928.0L) + 785722955.0L/5588352.0L) - 698249.0L/116424.0L) + 698249.0L/232848.0L) + 20.0L/11.0L;
        poly_val[10] = pow(x, 2)*(x*(x*(x*(x*(-178100340673.0L/498960000.0L*x + 1122102226711.0L/898128000.0L) - 957933723511.0L/598752000.0L) + 733946977711.0L/838252800.0L) - 61475136673.0L/359251200.0L) + 307869749.0L/38880000.0L) - 1968329.0L/635040.0L;
        poly_val[11] = x*(x*(x*(x*(x*(x*((178100340673.0L/498960000.0L)*x - 1402452582211.0L/1122660000.0L) + 228012714673.0L/142560000.0L) - 1836144861211.0L/2095632000.0L) + 2176770052711.0L/12573792000.0L) - 698249.0L/116424.0L) - 698249.0L/232848.0L) + 20.0L/11.0L;
        poly_val[12] = x*(x*(x*(x*(x*(x*(-92343961.0L/310464.0L*x + 415476503.0L/399168.0L) - 59104301.0L/44352.0L) + 1361550835.0L/1862784.0L) - 809639125.0L/5588352.0L) + 1650809.0L/620928.0L) + 1650809.0L/620928.0L) - 15.0L/44.0L;
        poly_val[13] = x*(x*(x*(x*(x*(x*((2493086731.0L/12108096.0L)*x - 5608090681.0L/7783776.0L) + 683892595.0L/741312.0L) - 36796608235.0L/72648576.0L) + 21820288885.0L/217945728.0L) - 1827209.0L/2270268.0L) - 1827209.0L/1513512.0L) + 40.0L/429.0L;
        poly_val[14] = x*(x*(x*(x*(x*(x*(-18499877.0L/157248.0L*x + 6408496849.0L/15567552.0L) - 1823789521.0L/3459456.0L) + 1618402825.0L/5588352.0L) - 12424064945.0L/217945728.0L) + 1888949.0L/8072064.0L) + 1888949.0L/4036032.0L) - 15.0L/572.0L;
        poly_val[15] = x*(x*(x*(x*(x*(x*((46160205953.0L/840840000.0L)*x - 6922231.0L/36036.0L) + 35465070353.0L/144144000.0L) - 6820439797.0L/50450400.0L) + 254905271.0L/9609600.0L) - 9587629.0L/157657500.0L) - 9587629.0L/63063000.0L) + 24.0L/3575.0L;
        poly_val[16] = x*(x*(x*(x*(x*(x*(-311561305079.0L/15135120000.0L*x + 107822374417.0L/1496880000.0L) - 299257107283.0L/3243240000.0L) + 70840342681.0L/1397088000.0L) - 41601700243.0L/4191264000.0L) + 1933049.0L/145297152.0L) + 1933049.0L/48432384.0L) - 5.0L/3432.0L;
        poly_val[17] = x*(x*(x*(x*(x*(x*((356053741.0L/58810752.0L)*x - 5606634083.0L/264648384.0L) + 399033563.0L/14702688.0L) - 36840970345.0L/2470051584.0L) + 25927225.0L/8895744.0L) - 809.0L/350064.0L) - 5663.0L/700128.0L) + 30.0L/119119.0L;
        poly_val[18] = x*(x*(x*(x*(x*(x*(-4795181.0L/3564288.0L*x + 1661205589.0L/352864512.0L) - 202694095.0L/33606144.0L) + 202159235.0L/60988928.0L) - 3195527345.0L/4940103168.0L) + 487121.0L/1646701056.0L) + 487121.0L/411675264.0L) - 5.0L/155584.0L;
        poly_val[19] = x*(x*(x*(x*(x*(x*((9968948243.0L/46930980096.0L)*x - 862544509.0L/1160381376.0L) + 38310835621.0L/40226554368.0L) - 73690442425.0L/140792940288.0L) + 4536399485.0L/44460928512.0L) - 11419.0L/463134672.0L) - 11419.0L/102918816.0L) + 10.0L/3741309.0L;
        poly_val[20] = x*(x*(x*(x*(x*(x*(-311524262719.0L/14665931280000.0L*x + 280326487781.0L/3771239472000.0L) - 5701224667.0L/59860944000.0L) + 184231971829.0L/3519823507200.0L) - 107650576139.0L/10559470521600.0L) + 514639.0L/514594080000.0L) + 514639.0L/102918816000.0L) - 1.0L/9237800.0L;
        poly_val[21] = pow(x, 3)*(x*(x*(x*((33637859.0L/33256080000.0L)*x - 3708023477.0L/1047566520000.0L) + 117312777.0L/25865840000.0L) - 4873971667.0L/1955457504000.0L) + 218919637.0L/451259424000.0L);
        break;
    }
}
