/**********************************************************************
*                                                                     *
*  Copyright 2015 the TurTLE team                                     *
*                                                                     *
*  This file is part of TurTLE.                                       *
*                                                                     *
*  TurTLE is free software: you can redistribute it and/or modify     *
*  it under the terms of the GNU General Public License as published  *
*  by the Free Software Foundation, either version 3 of the License,  *
*  or (at your option) any later version.                             *
*                                                                     *
*  TurTLE is distributed in the hope that it will be useful,          *
*  but WITHOUT ANY WARRANTY; without even the implied warranty of     *
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      *
*  GNU General Public License for more details.                       *
*                                                                     *
*  You should have received a copy of the GNU General Public License  *
*  along with TurTLE.  If not, see <http://www.gnu.org/licenses/>     *
*                                                                     *
* Contact: Cristian.Lalescu@ds.mpg.de                                 *
*                                                                     *
**********************************************************************/



#include "spline_n4.hpp"
#include <cmath>
void beta_n4_m0(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = 0;
poly_val[1] = 0;
poly_val[2] = 0;
poly_val[3] = 0;
poly_val[4] = -x + 1;
poly_val[5] = x;
poly_val[6] = 0;
poly_val[7] = 0;
poly_val[8] = 0;
poly_val[9] = 0;
break;
case 1:
poly_val[0] = 0;
poly_val[1] = 0;
poly_val[2] = 0;
poly_val[3] = 0;
poly_val[4] = -1;
poly_val[5] = 1;
poly_val[6] = 0;
poly_val[7] = 0;
poly_val[8] = 0;
poly_val[9] = 0;
break;
case 2:
poly_val[0] = 0;
poly_val[1] = 0;
poly_val[2] = 0;
poly_val[3] = 0;
poly_val[4] = 0;
poly_val[5] = 0;
poly_val[6] = 0;
poly_val[7] = 0;
poly_val[8] = 0;
poly_val[9] = 0;
break;
}
}
void beta_n4_m1(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*((1.0L/280.0L)*x - 1.0L/140.0L) + 1.0L/280.0L);
poly_val[1] = x*(x*(-29.0L/840.0L*x + 61.0L/840.0L) - 4.0L/105.0L);
poly_val[2] = x*(x*((17.0L/105.0L)*x - 38.0L/105.0L) + 1.0L/5.0L);
poly_val[3] = x*(x*(-3.0L/5.0L*x + 7.0L/5.0L) - 4.0L/5.0L);
poly_val[4] = pow(x, 2)*((6.0L/5.0L)*x - 11.0L/5.0L) + 1;
poly_val[5] = x*(x*(-6.0L/5.0L*x + 7.0L/5.0L) + 4.0L/5.0L);
poly_val[6] = x*(x*((3.0L/5.0L)*x - 2.0L/5.0L) - 1.0L/5.0L);
poly_val[7] = x*(x*(-17.0L/105.0L*x + 13.0L/105.0L) + 4.0L/105.0L);
poly_val[8] = x*(x*((29.0L/840.0L)*x - 13.0L/420.0L) - 1.0L/280.0L);
poly_val[9] = pow(x, 2)*(-1.0L/280.0L*x + 1.0L/280.0L);
break;
case 1:
poly_val[0] = x*((3.0L/280.0L)*x - 1.0L/70.0L) + 1.0L/280.0L;
poly_val[1] = x*(-29.0L/280.0L*x + 61.0L/420.0L) - 4.0L/105.0L;
poly_val[2] = x*((17.0L/35.0L)*x - 76.0L/105.0L) + 1.0L/5.0L;
poly_val[3] = x*(-9.0L/5.0L*x + 14.0L/5.0L) - 4.0L/5.0L;
poly_val[4] = x*((18.0L/5.0L)*x - 22.0L/5.0L);
poly_val[5] = x*(-18.0L/5.0L*x + 14.0L/5.0L) + 4.0L/5.0L;
poly_val[6] = x*((9.0L/5.0L)*x - 4.0L/5.0L) - 1.0L/5.0L;
poly_val[7] = x*(-17.0L/35.0L*x + 26.0L/105.0L) + 4.0L/105.0L;
poly_val[8] = x*((29.0L/280.0L)*x - 13.0L/210.0L) - 1.0L/280.0L;
poly_val[9] = x*(-3.0L/280.0L*x + 1.0L/140.0L);
break;
case 2:
poly_val[0] = (3.0L/140.0L)*x - 1.0L/70.0L;
poly_val[1] = -29.0L/140.0L*x + 61.0L/420.0L;
poly_val[2] = (34.0L/35.0L)*x - 76.0L/105.0L;
poly_val[3] = -18.0L/5.0L*x + 14.0L/5.0L;
poly_val[4] = (36.0L/5.0L)*x - 22.0L/5.0L;
poly_val[5] = -36.0L/5.0L*x + 14.0L/5.0L;
poly_val[6] = (18.0L/5.0L)*x - 4.0L/5.0L;
poly_val[7] = -34.0L/35.0L*x + 26.0L/105.0L;
poly_val[8] = (29.0L/140.0L)*x - 13.0L/210.0L;
poly_val[9] = -3.0L/140.0L*x + 1.0L/140.0L;
break;
}
}
void beta_n4_m2(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(-11.0L/1120.0L*x + 29.0L/1120.0L) - 3.0L/160.0L) - 1.0L/1120.0L) + 1.0L/280.0L);
poly_val[1] = x*(x*(x*(x*((907.0L/10080.0L)*x - 403.0L/1680.0L) + 589.0L/3360.0L) + 4.0L/315.0L) - 4.0L/105.0L);
poly_val[2] = x*(x*(x*(x*(-47.0L/126.0L*x + 127.0L/126.0L) - 463.0L/630.0L) - 1.0L/10.0L) + 1.0L/5.0L);
poly_val[3] = x*(x*(x*(x*((9.0L/10.0L)*x - 12.0L/5.0L) + 3.0L/2.0L) + 4.0L/5.0L) - 4.0L/5.0L);
poly_val[4] = pow(x, 2)*(x*(x*(-991.0L/720.0L*x + 847.0L/240.0L) - 83.0L/48.0L) - 205.0L/144.0L) + 1;
poly_val[5] = x*(x*(x*(x*((991.0L/720.0L)*x - 1207.0L/360.0L) + 991.0L/720.0L) + 4.0L/5.0L) + 4.0L/5.0L);
poly_val[6] = x*(x*(x*(x*(-9.0L/10.0L*x + 21.0L/10.0L) - 9.0L/10.0L) - 1.0L/10.0L) - 1.0L/5.0L);
poly_val[7] = x*(x*(x*(x*((47.0L/126.0L)*x - 6.0L/7.0L) + 13.0L/30.0L) + 4.0L/315.0L) + 4.0L/105.0L);
poly_val[8] = x*(x*(x*(x*(-907.0L/10080.0L*x + 2117.0L/10080.0L) - 233.0L/2016.0L) - 1.0L/1120.0L) - 1.0L/280.0L);
poly_val[9] = pow(x, 3)*(x*((11.0L/1120.0L)*x - 13.0L/560.0L) + 3.0L/224.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(-11.0L/224.0L*x + 29.0L/280.0L) - 9.0L/160.0L) - 1.0L/560.0L) + 1.0L/280.0L;
poly_val[1] = x*(x*(x*((907.0L/2016.0L)*x - 403.0L/420.0L) + 589.0L/1120.0L) + 8.0L/315.0L) - 4.0L/105.0L;
poly_val[2] = x*(x*(x*(-235.0L/126.0L*x + 254.0L/63.0L) - 463.0L/210.0L) - 1.0L/5.0L) + 1.0L/5.0L;
poly_val[3] = x*(x*(x*((9.0L/2.0L)*x - 48.0L/5.0L) + 9.0L/2.0L) + 8.0L/5.0L) - 4.0L/5.0L;
poly_val[4] = x*(x*(x*(-991.0L/144.0L*x + 847.0L/60.0L) - 83.0L/16.0L) - 205.0L/72.0L);
poly_val[5] = x*(x*(x*((991.0L/144.0L)*x - 1207.0L/90.0L) + 991.0L/240.0L) + 8.0L/5.0L) + 4.0L/5.0L;
poly_val[6] = x*(x*(x*(-9.0L/2.0L*x + 42.0L/5.0L) - 27.0L/10.0L) - 1.0L/5.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*(x*((235.0L/126.0L)*x - 24.0L/7.0L) + 13.0L/10.0L) + 8.0L/315.0L) + 4.0L/105.0L;
poly_val[8] = x*(x*(x*(-907.0L/2016.0L*x + 2117.0L/2520.0L) - 233.0L/672.0L) - 1.0L/560.0L) - 1.0L/280.0L;
poly_val[9] = pow(x, 2)*(x*((11.0L/224.0L)*x - 13.0L/140.0L) + 9.0L/224.0L);
break;
case 2:
poly_val[0] = x*(x*(-11.0L/56.0L*x + 87.0L/280.0L) - 9.0L/80.0L) - 1.0L/560.0L;
poly_val[1] = x*(x*((907.0L/504.0L)*x - 403.0L/140.0L) + 589.0L/560.0L) + 8.0L/315.0L;
poly_val[2] = x*(x*(-470.0L/63.0L*x + 254.0L/21.0L) - 463.0L/105.0L) - 1.0L/5.0L;
poly_val[3] = x*(x*(18*x - 144.0L/5.0L) + 9) + 8.0L/5.0L;
poly_val[4] = x*(x*(-991.0L/36.0L*x + 847.0L/20.0L) - 83.0L/8.0L) - 205.0L/72.0L;
poly_val[5] = x*(x*((991.0L/36.0L)*x - 1207.0L/30.0L) + 991.0L/120.0L) + 8.0L/5.0L;
poly_val[6] = x*(x*(-18*x + 126.0L/5.0L) - 27.0L/5.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*((470.0L/63.0L)*x - 72.0L/7.0L) + 13.0L/5.0L) + 8.0L/315.0L;
poly_val[8] = x*(x*(-907.0L/504.0L*x + 2117.0L/840.0L) - 233.0L/336.0L) - 1.0L/560.0L;
poly_val[9] = x*(x*((11.0L/56.0L)*x - 39.0L/140.0L) + 9.0L/112.0L);
break;
}
}
void beta_n4_m3(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*((55.0L/2016.0L)*x - 193.0L/2016.0L) + 191.0L/1680.0L) - 31.0L/720.0L) - 7.0L/1440.0L) - 1.0L/1120.0L) + 1.0L/280.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*(-2477.0L/10080.0L*x + 69.0L/80.0L) - 10313.0L/10080.0L) + 481.0L/1260.0L) + 1.0L/20.0L) + 4.0L/315.0L) - 4.0L/105.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*((4957.0L/5040.0L)*x - 1087.0L/315.0L) + 10277.0L/2520.0L) - 31.0L/21.0L) - 169.0L/720.0L) - 1.0L/10.0L) + 1.0L/5.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*(-551.0L/240.0L*x + 1159.0L/144.0L) - 2273.0L/240.0L) + 811.0L/240.0L) + 61.0L/180.0L) + 4.0L/5.0L) - 4.0L/5.0L);
poly_val[4] = pow(x, 2)*(pow(x, 2)*(x*(x*((31.0L/9.0L)*x - 193.0L/16.0L) + 1273.0L/90.0L) - 1837.0L/360.0L) - 205.0L/144.0L) + 1;
poly_val[5] = x*(x*(x*(x*(x*(x*(-31.0L/9.0L*x + 1735.0L/144.0L) - 5077.0L/360.0L) + 419.0L/80.0L) - 61.0L/180.0L) + 4.0L/5.0L) + 4.0L/5.0L);
poly_val[6] = x*(x*(x*(x*(x*(x*((551.0L/240.0L)*x - 361.0L/45.0L) + 1127.0L/120.0L) - 18.0L/5.0L) + 169.0L/720.0L) - 1.0L/10.0L) - 1.0L/5.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*(-4957.0L/5040.0L*x + 1923.0L/560.0L) - 20299.0L/5040.0L) + 227.0L/144.0L) - 1.0L/20.0L) + 4.0L/315.0L) + 4.0L/105.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*((2477.0L/10080.0L)*x - 247.0L/288.0L) + 5083.0L/5040.0L) - 667.0L/1680.0L) + 7.0L/1440.0L) - 1.0L/1120.0L) - 1.0L/280.0L);
poly_val[9] = pow(x, 4)*(x*(x*(-55.0L/2016.0L*x + 2.0L/21.0L) - 377.0L/3360.0L) + 223.0L/5040.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*((55.0L/288.0L)*x - 193.0L/336.0L) + 191.0L/336.0L) - 31.0L/180.0L) - 7.0L/480.0L) - 1.0L/560.0L) + 1.0L/280.0L;
poly_val[1] = x*(x*(x*(x*(x*(-2477.0L/1440.0L*x + 207.0L/40.0L) - 10313.0L/2016.0L) + 481.0L/315.0L) + 3.0L/20.0L) + 8.0L/315.0L) - 4.0L/105.0L;
poly_val[2] = x*(x*(x*(x*(x*((4957.0L/720.0L)*x - 2174.0L/105.0L) + 10277.0L/504.0L) - 124.0L/21.0L) - 169.0L/240.0L) - 1.0L/5.0L) + 1.0L/5.0L;
poly_val[3] = x*(x*(x*(x*(x*(-3857.0L/240.0L*x + 1159.0L/24.0L) - 2273.0L/48.0L) + 811.0L/60.0L) + 61.0L/60.0L) + 8.0L/5.0L) - 4.0L/5.0L;
poly_val[4] = x*(pow(x, 2)*(x*(x*((217.0L/9.0L)*x - 579.0L/8.0L) + 1273.0L/18.0L) - 1837.0L/90.0L) - 205.0L/72.0L);
poly_val[5] = x*(x*(x*(x*(x*(-217.0L/9.0L*x + 1735.0L/24.0L) - 5077.0L/72.0L) + 419.0L/20.0L) - 61.0L/60.0L) + 8.0L/5.0L) + 4.0L/5.0L;
poly_val[6] = x*(x*(x*(x*(x*((3857.0L/240.0L)*x - 722.0L/15.0L) + 1127.0L/24.0L) - 72.0L/5.0L) + 169.0L/240.0L) - 1.0L/5.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*(x*(x*(x*(-4957.0L/720.0L*x + 5769.0L/280.0L) - 20299.0L/1008.0L) + 227.0L/36.0L) - 3.0L/20.0L) + 8.0L/315.0L) + 4.0L/105.0L;
poly_val[8] = x*(x*(x*(x*(x*((2477.0L/1440.0L)*x - 247.0L/48.0L) + 5083.0L/1008.0L) - 667.0L/420.0L) + 7.0L/480.0L) - 1.0L/560.0L) - 1.0L/280.0L;
poly_val[9] = pow(x, 3)*(x*(x*(-55.0L/288.0L*x + 4.0L/7.0L) - 377.0L/672.0L) + 223.0L/1260.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*((55.0L/48.0L)*x - 965.0L/336.0L) + 191.0L/84.0L) - 31.0L/60.0L) - 7.0L/240.0L) - 1.0L/560.0L;
poly_val[1] = x*(x*(x*(x*(-2477.0L/240.0L*x + 207.0L/8.0L) - 10313.0L/504.0L) + 481.0L/105.0L) + 3.0L/10.0L) + 8.0L/315.0L;
poly_val[2] = x*(x*(x*(x*((4957.0L/120.0L)*x - 2174.0L/21.0L) + 10277.0L/126.0L) - 124.0L/7.0L) - 169.0L/120.0L) - 1.0L/5.0L;
poly_val[3] = x*(x*(x*(x*(-3857.0L/40.0L*x + 5795.0L/24.0L) - 2273.0L/12.0L) + 811.0L/20.0L) + 61.0L/30.0L) + 8.0L/5.0L;
poly_val[4] = pow(x, 2)*(x*(x*((434.0L/3.0L)*x - 2895.0L/8.0L) + 2546.0L/9.0L) - 1837.0L/30.0L) - 205.0L/72.0L;
poly_val[5] = x*(x*(x*(x*(-434.0L/3.0L*x + 8675.0L/24.0L) - 5077.0L/18.0L) + 1257.0L/20.0L) - 61.0L/30.0L) + 8.0L/5.0L;
poly_val[6] = x*(x*(x*(x*((3857.0L/40.0L)*x - 722.0L/3.0L) + 1127.0L/6.0L) - 216.0L/5.0L) + 169.0L/120.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*(x*(x*(-4957.0L/120.0L*x + 5769.0L/56.0L) - 20299.0L/252.0L) + 227.0L/12.0L) - 3.0L/10.0L) + 8.0L/315.0L;
poly_val[8] = x*(x*(x*(x*((2477.0L/240.0L)*x - 1235.0L/48.0L) + 5083.0L/252.0L) - 667.0L/140.0L) + 7.0L/240.0L) - 1.0L/560.0L;
poly_val[9] = pow(x, 2)*(x*(x*(-55.0L/48.0L*x + 20.0L/7.0L) - 377.0L/168.0L) + 223.0L/420.0L);
break;
}
}
void beta_n4_m4(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(-3569.0L/40320.0L*x + 16061.0L/40320.0L) - 1961.0L/2880.0L) + 503.0L/960.0L) - 175.0L/1152.0L) + 7.0L/5760.0L) - 7.0L/1440.0L) - 1.0L/1120.0L) + 1.0L/280.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*((3569.0L/4480.0L)*x - 36137.0L/10080.0L) + 41179.0L/6720.0L) - 2263.0L/480.0L) + 175.0L/128.0L) - 1.0L/60.0L) + 1.0L/20.0L) + 4.0L/315.0L) - 4.0L/105.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(-3569.0L/1120.0L*x + 144547.0L/10080.0L) - 30883.0L/1260.0L) + 13577.0L/720.0L) - 1579.0L/288.0L) + 169.0L/1440.0L) - 169.0L/720.0L) - 1.0L/10.0L) + 1.0L/5.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*((3569.0L/480.0L)*x - 24091.0L/720.0L) + 5147.0L/90.0L) - 31681.0L/720.0L) + 3697.0L/288.0L) - 61.0L/180.0L) + 61.0L/180.0L) + 4.0L/5.0L) - 4.0L/5.0L);
poly_val[4] = pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(-3569.0L/320.0L*x + 28909.0L/576.0L) - 2745.0L/32.0L) + 6337.0L/96.0L) - 6181.0L/320.0L) + 91.0L/192.0L) - 205.0L/144.0L) + 1;
poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*((3569.0L/320.0L)*x - 4517.0L/90.0L) + 123523.0L/1440.0L) - 2971.0L/45.0L) + 11149.0L/576.0L) - 61.0L/180.0L) - 61.0L/180.0L) + 4.0L/5.0L) + 4.0L/5.0L);
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(-3569.0L/480.0L*x + 48181.0L/1440.0L) - 20587.0L/360.0L) + 31697.0L/720.0L) - 3719.0L/288.0L) + 169.0L/1440.0L) + 169.0L/720.0L) - 1.0L/10.0L) - 1.0L/5.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*((3569.0L/1120.0L)*x - 72271.0L/5040.0L) + 2941.0L/120.0L) - 4529.0L/240.0L) + 177.0L/32.0L) - 1.0L/60.0L) - 1.0L/20.0L) + 4.0L/315.0L) + 4.0L/105.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(-3569.0L/4480.0L*x + 144541.0L/40320.0L) - 123523.0L/20160.0L) + 13589.0L/2880.0L) - 1591.0L/1152.0L) + 7.0L/5760.0L) + 7.0L/1440.0L) - 1.0L/1120.0L) - 1.0L/280.0L);
poly_val[9] = pow(x, 5)*(x*(x*(x*((3569.0L/40320.0L)*x - 803.0L/2016.0L) + 305.0L/448.0L) - 151.0L/288.0L) + 883.0L/5760.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(-3569.0L/4480.0L*x + 16061.0L/5040.0L) - 13727.0L/2880.0L) + 503.0L/160.0L) - 875.0L/1152.0L) + 7.0L/1440.0L) - 7.0L/480.0L) - 1.0L/560.0L) + 1.0L/280.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*((32121.0L/4480.0L)*x - 36137.0L/1260.0L) + 41179.0L/960.0L) - 2263.0L/80.0L) + 875.0L/128.0L) - 1.0L/15.0L) + 3.0L/20.0L) + 8.0L/315.0L) - 4.0L/105.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(-32121.0L/1120.0L*x + 144547.0L/1260.0L) - 30883.0L/180.0L) + 13577.0L/120.0L) - 7895.0L/288.0L) + 169.0L/360.0L) - 169.0L/240.0L) - 1.0L/5.0L) + 1.0L/5.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*((10707.0L/160.0L)*x - 24091.0L/90.0L) + 36029.0L/90.0L) - 31681.0L/120.0L) + 18485.0L/288.0L) - 61.0L/45.0L) + 61.0L/60.0L) + 8.0L/5.0L) - 4.0L/5.0L;
poly_val[4] = x*(pow(x, 2)*(x*(x*(x*(x*(-32121.0L/320.0L*x + 28909.0L/72.0L) - 19215.0L/32.0L) + 6337.0L/16.0L) - 6181.0L/64.0L) + 91.0L/48.0L) - 205.0L/72.0L);
poly_val[5] = x*(x*(x*(x*(x*(x*(x*((32121.0L/320.0L)*x - 18068.0L/45.0L) + 864661.0L/1440.0L) - 5942.0L/15.0L) + 55745.0L/576.0L) - 61.0L/45.0L) - 61.0L/60.0L) + 8.0L/5.0L) + 4.0L/5.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(-10707.0L/160.0L*x + 48181.0L/180.0L) - 144109.0L/360.0L) + 31697.0L/120.0L) - 18595.0L/288.0L) + 169.0L/360.0L) + 169.0L/240.0L) - 1.0L/5.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*((32121.0L/1120.0L)*x - 72271.0L/630.0L) + 20587.0L/120.0L) - 4529.0L/40.0L) + 885.0L/32.0L) - 1.0L/15.0L) - 3.0L/20.0L) + 8.0L/315.0L) + 4.0L/105.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(-32121.0L/4480.0L*x + 144541.0L/5040.0L) - 123523.0L/2880.0L) + 13589.0L/480.0L) - 7955.0L/1152.0L) + 7.0L/1440.0L) + 7.0L/480.0L) - 1.0L/560.0L) - 1.0L/280.0L;
poly_val[9] = pow(x, 4)*(x*(x*(x*((3569.0L/4480.0L)*x - 803.0L/252.0L) + 305.0L/64.0L) - 151.0L/48.0L) + 883.0L/1152.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*(x*(x*(-3569.0L/560.0L*x + 16061.0L/720.0L) - 13727.0L/480.0L) + 503.0L/32.0L) - 875.0L/288.0L) + 7.0L/480.0L) - 7.0L/240.0L) - 1.0L/560.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*((32121.0L/560.0L)*x - 36137.0L/180.0L) + 41179.0L/160.0L) - 2263.0L/16.0L) + 875.0L/32.0L) - 1.0L/5.0L) + 3.0L/10.0L) + 8.0L/315.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(-32121.0L/140.0L*x + 144547.0L/180.0L) - 30883.0L/30.0L) + 13577.0L/24.0L) - 7895.0L/72.0L) + 169.0L/120.0L) - 169.0L/120.0L) - 1.0L/5.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*((10707.0L/20.0L)*x - 168637.0L/90.0L) + 36029.0L/15.0L) - 31681.0L/24.0L) + 18485.0L/72.0L) - 61.0L/15.0L) + 61.0L/30.0L) + 8.0L/5.0L;
poly_val[4] = pow(x, 2)*(x*(x*(x*(x*(-32121.0L/40.0L*x + 202363.0L/72.0L) - 57645.0L/16.0L) + 31685.0L/16.0L) - 6181.0L/16.0L) + 91.0L/16.0L) - 205.0L/72.0L;
poly_val[5] = x*(x*(x*(x*(x*(x*((32121.0L/40.0L)*x - 126476.0L/45.0L) + 864661.0L/240.0L) - 5942.0L/3.0L) + 55745.0L/144.0L) - 61.0L/15.0L) - 61.0L/30.0L) + 8.0L/5.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(-10707.0L/20.0L*x + 337267.0L/180.0L) - 144109.0L/60.0L) + 31697.0L/24.0L) - 18595.0L/72.0L) + 169.0L/120.0L) + 169.0L/120.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*((32121.0L/140.0L)*x - 72271.0L/90.0L) + 20587.0L/20.0L) - 4529.0L/8.0L) + 885.0L/8.0L) - 1.0L/5.0L) - 3.0L/10.0L) + 8.0L/315.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(-32121.0L/560.0L*x + 144541.0L/720.0L) - 123523.0L/480.0L) + 13589.0L/96.0L) - 7955.0L/288.0L) + 7.0L/480.0L) + 7.0L/240.0L) - 1.0L/560.0L;
poly_val[9] = pow(x, 3)*(x*(x*(x*((3569.0L/560.0L)*x - 803.0L/36.0L) + 915.0L/32.0L) - 755.0L/48.0L) + 883.0L/288.0L);
break;
}
}
void beta_n4_m5(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((883.0L/2880.0L)*x - 9713.0L/5760.0L) + 37739.0L/10080.0L) - 169369.0L/40320.0L) + 6869.0L/2880.0L) - 3163.0L/5760.0L) + 1.0L/720.0L) + 7.0L/5760.0L) - 7.0L/1440.0L) - 1.0L/1120.0L) + 1.0L/280.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-883.0L/320.0L*x + 9713.0L/640.0L) - 37739.0L/1120.0L) + 762161.0L/20160.0L) - 144251.0L/6720.0L) + 9491.0L/1920.0L) - 1.0L/80.0L) - 1.0L/60.0L) + 1.0L/20.0L) + 4.0L/315.0L) - 4.0L/105.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((883.0L/80.0L)*x - 9713.0L/160.0L) + 37739.0L/280.0L) - 1524323.0L/10080.0L) + 216379.0L/2520.0L) - 5695.0L/288.0L) + 13.0L/360.0L) + 169.0L/1440.0L) - 169.0L/720.0L) - 1.0L/10.0L) + 1.0L/5.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6181.0L/240.0L*x + 67991.0L/480.0L) - 37739.0L/120.0L) + 127027.0L/360.0L) - 72127.0L/360.0L) + 66439.0L/1440.0L) - 29.0L/720.0L) - 61.0L/180.0L) + 61.0L/180.0L) + 4.0L/5.0L) - 4.0L/5.0L);
poly_val[4] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*((6181.0L/160.0L)*x - 67991.0L/320.0L) + 37739.0L/80.0L) - 304865.0L/576.0L) + 9617.0L/32.0L) - 66431.0L/960.0L) + 91.0L/192.0L) - 205.0L/144.0L) + 1;
poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6181.0L/160.0L*x + 67991.0L/320.0L) - 37739.0L/80.0L) + 762163.0L/1440.0L) - 432767.0L/1440.0L) + 199259.0L/2880.0L) + 29.0L/720.0L) - 61.0L/180.0L) - 61.0L/180.0L) + 4.0L/5.0L) + 4.0L/5.0L);
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((6181.0L/240.0L)*x - 67991.0L/480.0L) + 37739.0L/120.0L) - 508109.0L/1440.0L) + 9016.0L/45.0L) - 66407.0L/1440.0L) - 13.0L/360.0L) + 169.0L/1440.0L) + 169.0L/720.0L) - 1.0L/10.0L) - 1.0L/5.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-883.0L/80.0L*x + 9713.0L/160.0L) - 37739.0L/280.0L) + 190541.0L/1260.0L) - 1288.0L/15.0L) + 1897.0L/96.0L) + 1.0L/80.0L) - 1.0L/60.0L) - 1.0L/20.0L) + 4.0L/315.0L) + 4.0L/105.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((883.0L/320.0L)*x - 9713.0L/640.0L) + 37739.0L/1120.0L) - 1524329.0L/40320.0L) + 432767.0L/20160.0L) - 28451.0L/5760.0L) - 1.0L/720.0L) + 7.0L/5760.0L) + 7.0L/1440.0L) - 1.0L/1120.0L) - 1.0L/280.0L);
poly_val[9] = pow(x, 6)*(x*(x*(x*(x*(-883.0L/2880.0L*x + 9713.0L/5760.0L) - 37739.0L/10080.0L) + 16937.0L/4032.0L) - 9617.0L/4032.0L) + 3161.0L/5760.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*((9713.0L/2880.0L)*x - 9713.0L/576.0L) + 37739.0L/1120.0L) - 169369.0L/5040.0L) + 48083.0L/2880.0L) - 3163.0L/960.0L) + 1.0L/144.0L) + 7.0L/1440.0L) - 7.0L/480.0L) - 1.0L/560.0L) + 1.0L/280.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(-9713.0L/320.0L*x + 9713.0L/64.0L) - 339651.0L/1120.0L) + 762161.0L/2520.0L) - 144251.0L/960.0L) + 9491.0L/320.0L) - 1.0L/16.0L) - 1.0L/15.0L) + 3.0L/20.0L) + 8.0L/315.0L) - 4.0L/105.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*((9713.0L/80.0L)*x - 9713.0L/16.0L) + 339651.0L/280.0L) - 1524323.0L/1260.0L) + 216379.0L/360.0L) - 5695.0L/48.0L) + 13.0L/72.0L) + 169.0L/360.0L) - 169.0L/240.0L) - 1.0L/5.0L) + 1.0L/5.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(-67991.0L/240.0L*x + 67991.0L/48.0L) - 113217.0L/40.0L) + 127027.0L/45.0L) - 504889.0L/360.0L) + 66439.0L/240.0L) - 29.0L/144.0L) - 61.0L/45.0L) + 61.0L/60.0L) + 8.0L/5.0L) - 4.0L/5.0L;
poly_val[4] = x*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*((67991.0L/160.0L)*x - 67991.0L/32.0L) + 339651.0L/80.0L) - 304865.0L/72.0L) + 67319.0L/32.0L) - 66431.0L/160.0L) + 91.0L/48.0L) - 205.0L/72.0L);
poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*(x*(-67991.0L/160.0L*x + 67991.0L/32.0L) - 339651.0L/80.0L) + 762163.0L/180.0L) - 3029369.0L/1440.0L) + 199259.0L/480.0L) + 29.0L/144.0L) - 61.0L/45.0L) - 61.0L/60.0L) + 8.0L/5.0L) + 4.0L/5.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*((67991.0L/240.0L)*x - 67991.0L/48.0L) + 113217.0L/40.0L) - 508109.0L/180.0L) + 63112.0L/45.0L) - 66407.0L/240.0L) - 13.0L/72.0L) + 169.0L/360.0L) + 169.0L/240.0L) - 1.0L/5.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(-9713.0L/80.0L*x + 9713.0L/16.0L) - 339651.0L/280.0L) + 381082.0L/315.0L) - 9016.0L/15.0L) + 1897.0L/16.0L) + 1.0L/16.0L) - 1.0L/15.0L) - 3.0L/20.0L) + 8.0L/315.0L) + 4.0L/105.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*((9713.0L/320.0L)*x - 9713.0L/64.0L) + 339651.0L/1120.0L) - 1524329.0L/5040.0L) + 432767.0L/2880.0L) - 28451.0L/960.0L) - 1.0L/144.0L) + 7.0L/1440.0L) + 7.0L/480.0L) - 1.0L/560.0L) - 1.0L/280.0L;
poly_val[9] = pow(x, 5)*(x*(x*(x*(x*(-9713.0L/2880.0L*x + 9713.0L/576.0L) - 37739.0L/1120.0L) + 16937.0L/504.0L) - 9617.0L/576.0L) + 3161.0L/960.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*((9713.0L/288.0L)*x - 9713.0L/64.0L) + 37739.0L/140.0L) - 169369.0L/720.0L) + 48083.0L/480.0L) - 3163.0L/192.0L) + 1.0L/36.0L) + 7.0L/480.0L) - 7.0L/240.0L) - 1.0L/560.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(-9713.0L/32.0L*x + 87417.0L/64.0L) - 339651.0L/140.0L) + 762161.0L/360.0L) - 144251.0L/160.0L) + 9491.0L/64.0L) - 1.0L/4.0L) - 1.0L/5.0L) + 3.0L/10.0L) + 8.0L/315.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*((9713.0L/8.0L)*x - 87417.0L/16.0L) + 339651.0L/35.0L) - 1524323.0L/180.0L) + 216379.0L/60.0L) - 28475.0L/48.0L) + 13.0L/18.0L) + 169.0L/120.0L) - 169.0L/120.0L) - 1.0L/5.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(-67991.0L/24.0L*x + 203973.0L/16.0L) - 113217.0L/5.0L) + 889189.0L/45.0L) - 504889.0L/60.0L) + 66439.0L/48.0L) - 29.0L/36.0L) - 61.0L/15.0L) + 61.0L/30.0L) + 8.0L/5.0L;
poly_val[4] = pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*((67991.0L/16.0L)*x - 611919.0L/32.0L) + 339651.0L/10.0L) - 2134055.0L/72.0L) + 201957.0L/16.0L) - 66431.0L/32.0L) + 91.0L/16.0L) - 205.0L/72.0L;
poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*(-67991.0L/16.0L*x + 611919.0L/32.0L) - 339651.0L/10.0L) + 5335141.0L/180.0L) - 3029369.0L/240.0L) + 199259.0L/96.0L) + 29.0L/36.0L) - 61.0L/15.0L) - 61.0L/30.0L) + 8.0L/5.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*((67991.0L/24.0L)*x - 203973.0L/16.0L) + 113217.0L/5.0L) - 3556763.0L/180.0L) + 126224.0L/15.0L) - 66407.0L/48.0L) - 13.0L/18.0L) + 169.0L/120.0L) + 169.0L/120.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(-9713.0L/8.0L*x + 87417.0L/16.0L) - 339651.0L/35.0L) + 381082.0L/45.0L) - 18032.0L/5.0L) + 9485.0L/16.0L) + 1.0L/4.0L) - 1.0L/5.0L) - 3.0L/10.0L) + 8.0L/315.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*((9713.0L/32.0L)*x - 87417.0L/64.0L) + 339651.0L/140.0L) - 1524329.0L/720.0L) + 432767.0L/480.0L) - 28451.0L/192.0L) - 1.0L/36.0L) + 7.0L/480.0L) + 7.0L/240.0L) - 1.0L/560.0L;
poly_val[9] = pow(x, 4)*(x*(x*(x*(x*(-9713.0L/288.0L*x + 9713.0L/64.0L) - 37739.0L/140.0L) + 16937.0L/72.0L) - 9617.0L/96.0L) + 3161.0L/192.0L);
break;
}
}
void beta_n4_m6(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-3161.0L/2880.0L*x + 41093.0L/5760.0L) - 11203.0L/576.0L) + 9119.0L/320.0L) - 477697.0L/20160.0L) + 21403.0L/2016.0L) - 385.0L/192.0L) - 1.0L/2880.0L) + 1.0L/720.0L) + 7.0L/5760.0L) - 7.0L/1440.0L) - 1.0L/1120.0L) + 1.0L/280.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((3161.0L/320.0L)*x - 41093.0L/640.0L) + 11203.0L/64.0L) - 82071.0L/320.0L) + 477697.0L/2240.0L) - 3852539.0L/40320.0L) + 121273.0L/6720.0L) + 1.0L/240.0L) - 1.0L/80.0L) - 1.0L/60.0L) + 1.0L/20.0L) + 4.0L/315.0L) - 4.0L/105.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-3161.0L/80.0L*x + 41093.0L/160.0L) - 11203.0L/16.0L) + 82071.0L/80.0L) - 477697.0L/560.0L) + 1926269.0L/5040.0L) - 181907.0L/2520.0L) - 13.0L/720.0L) + 13.0L/360.0L) + 169.0L/1440.0L) - 169.0L/720.0L) - 1.0L/10.0L) + 1.0L/5.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((22127.0L/240.0L)*x - 287651.0L/480.0L) + 78421.0L/48.0L) - 191499.0L/80.0L) + 477697.0L/240.0L) - 1284179.0L/1440.0L) + 12127.0L/72.0L) + 29.0L/720.0L) - 29.0L/720.0L) - 61.0L/180.0L) + 61.0L/180.0L) + 4.0L/5.0L) - 4.0L/5.0L);
poly_val[4] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(-22127.0L/160.0L*x + 287651.0L/320.0L) - 78421.0L/32.0L) + 574497.0L/160.0L) - 477697.0L/160.0L) + 481567.0L/360.0L) - 40423.0L/160.0L) - 5.0L/96.0L) + 91.0L/192.0L) - 205.0L/144.0L) + 1;
poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((22127.0L/160.0L)*x - 287651.0L/320.0L) + 78421.0L/32.0L) - 574497.0L/160.0L) + 477697.0L/160.0L) - 770507.0L/576.0L) + 72761.0L/288.0L) + 29.0L/720.0L) + 29.0L/720.0L) - 61.0L/180.0L) - 61.0L/180.0L) + 4.0L/5.0L) + 4.0L/5.0L);
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-22127.0L/240.0L*x + 287651.0L/480.0L) - 78421.0L/48.0L) + 191499.0L/80.0L) - 477697.0L/240.0L) + 642089.0L/720.0L) - 30317.0L/180.0L) - 13.0L/720.0L) - 13.0L/360.0L) + 169.0L/1440.0L) + 169.0L/720.0L) - 1.0L/10.0L) - 1.0L/5.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((3161.0L/80.0L)*x - 41093.0L/160.0L) + 11203.0L/16.0L) - 82071.0L/80.0L) + 477697.0L/560.0L) - 3852533.0L/10080.0L) + 4331.0L/60.0L) + 1.0L/240.0L) + 1.0L/80.0L) - 1.0L/60.0L) - 1.0L/20.0L) + 4.0L/315.0L) + 4.0L/105.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-3161.0L/320.0L*x + 41093.0L/640.0L) - 11203.0L/64.0L) + 82071.0L/320.0L) - 477697.0L/2240.0L) + 963133.0L/10080.0L) - 72761.0L/4032.0L) - 1.0L/2880.0L) - 1.0L/720.0L) + 7.0L/5760.0L) + 7.0L/1440.0L) - 1.0L/1120.0L) - 1.0L/280.0L);
poly_val[9] = pow(x, 7)*(x*(x*(x*(x*(x*((3161.0L/2880.0L)*x - 41093.0L/5760.0L) + 11203.0L/576.0L) - 9119.0L/320.0L) + 477697.0L/20160.0L) - 428059.0L/40320.0L) + 40423.0L/20160.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-41093.0L/2880.0L*x + 41093.0L/480.0L) - 123233.0L/576.0L) + 9119.0L/32.0L) - 477697.0L/2240.0L) + 21403.0L/252.0L) - 2695.0L/192.0L) - 1.0L/480.0L) + 1.0L/144.0L) + 7.0L/1440.0L) - 7.0L/480.0L) - 1.0L/560.0L) + 1.0L/280.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((41093.0L/320.0L)*x - 123279.0L/160.0L) + 123233.0L/64.0L) - 82071.0L/32.0L) + 4299273.0L/2240.0L) - 3852539.0L/5040.0L) + 121273.0L/960.0L) + 1.0L/40.0L) - 1.0L/16.0L) - 1.0L/15.0L) + 3.0L/20.0L) + 8.0L/315.0L) - 4.0L/105.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-41093.0L/80.0L*x + 123279.0L/40.0L) - 123233.0L/16.0L) + 82071.0L/8.0L) - 4299273.0L/560.0L) + 1926269.0L/630.0L) - 181907.0L/360.0L) - 13.0L/120.0L) + 13.0L/72.0L) + 169.0L/360.0L) - 169.0L/240.0L) - 1.0L/5.0L) + 1.0L/5.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((287651.0L/240.0L)*x - 287651.0L/40.0L) + 862631.0L/48.0L) - 191499.0L/8.0L) + 1433091.0L/80.0L) - 1284179.0L/180.0L) + 84889.0L/72.0L) + 29.0L/120.0L) - 29.0L/144.0L) - 61.0L/45.0L) + 61.0L/60.0L) + 8.0L/5.0L) - 4.0L/5.0L;
poly_val[4] = x*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(-287651.0L/160.0L*x + 862953.0L/80.0L) - 862631.0L/32.0L) + 574497.0L/16.0L) - 4299273.0L/160.0L) + 481567.0L/45.0L) - 282961.0L/160.0L) - 5.0L/16.0L) + 91.0L/48.0L) - 205.0L/72.0L);
poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((287651.0L/160.0L)*x - 862953.0L/80.0L) + 862631.0L/32.0L) - 574497.0L/16.0L) + 4299273.0L/160.0L) - 770507.0L/72.0L) + 509327.0L/288.0L) + 29.0L/120.0L) + 29.0L/144.0L) - 61.0L/45.0L) - 61.0L/60.0L) + 8.0L/5.0L) + 4.0L/5.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-287651.0L/240.0L*x + 287651.0L/40.0L) - 862631.0L/48.0L) + 191499.0L/8.0L) - 1433091.0L/80.0L) + 642089.0L/90.0L) - 212219.0L/180.0L) - 13.0L/120.0L) - 13.0L/72.0L) + 169.0L/360.0L) + 169.0L/240.0L) - 1.0L/5.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((41093.0L/80.0L)*x - 123279.0L/40.0L) + 123233.0L/16.0L) - 82071.0L/8.0L) + 4299273.0L/560.0L) - 3852533.0L/1260.0L) + 30317.0L/60.0L) + 1.0L/40.0L) + 1.0L/16.0L) - 1.0L/15.0L) - 3.0L/20.0L) + 8.0L/315.0L) + 4.0L/105.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-41093.0L/320.0L*x + 123279.0L/160.0L) - 123233.0L/64.0L) + 82071.0L/32.0L) - 4299273.0L/2240.0L) + 963133.0L/1260.0L) - 72761.0L/576.0L) - 1.0L/480.0L) - 1.0L/144.0L) + 7.0L/1440.0L) + 7.0L/480.0L) - 1.0L/560.0L) - 1.0L/280.0L;
poly_val[9] = pow(x, 6)*(x*(x*(x*(x*(x*((41093.0L/2880.0L)*x - 41093.0L/480.0L) + 123233.0L/576.0L) - 9119.0L/32.0L) + 477697.0L/2240.0L) - 428059.0L/5040.0L) + 40423.0L/2880.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-41093.0L/240.0L*x + 452023.0L/480.0L) - 616165.0L/288.0L) + 82071.0L/32.0L) - 477697.0L/280.0L) + 21403.0L/36.0L) - 2695.0L/32.0L) - 1.0L/96.0L) + 1.0L/36.0L) + 7.0L/480.0L) - 7.0L/240.0L) - 1.0L/560.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((123279.0L/80.0L)*x - 1356069.0L/160.0L) + 616165.0L/32.0L) - 738639.0L/32.0L) + 4299273.0L/280.0L) - 3852539.0L/720.0L) + 121273.0L/160.0L) + 1.0L/8.0L) - 1.0L/4.0L) - 1.0L/5.0L) + 3.0L/10.0L) + 8.0L/315.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-123279.0L/20.0L*x + 1356069.0L/40.0L) - 616165.0L/8.0L) + 738639.0L/8.0L) - 4299273.0L/70.0L) + 1926269.0L/90.0L) - 181907.0L/60.0L) - 13.0L/24.0L) + 13.0L/18.0L) + 169.0L/120.0L) - 169.0L/120.0L) - 1.0L/5.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((287651.0L/20.0L)*x - 3164161.0L/40.0L) + 4313155.0L/24.0L) - 1723491.0L/8.0L) + 1433091.0L/10.0L) - 8989253.0L/180.0L) + 84889.0L/12.0L) + 29.0L/24.0L) - 29.0L/36.0L) - 61.0L/15.0L) + 61.0L/30.0L) + 8.0L/5.0L;
poly_val[4] = pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(-862953.0L/40.0L*x + 9492483.0L/80.0L) - 4313155.0L/16.0L) + 5170473.0L/16.0L) - 4299273.0L/20.0L) + 3370969.0L/45.0L) - 848883.0L/80.0L) - 25.0L/16.0L) + 91.0L/16.0L) - 205.0L/72.0L;
poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((862953.0L/40.0L)*x - 9492483.0L/80.0L) + 4313155.0L/16.0L) - 5170473.0L/16.0L) + 4299273.0L/20.0L) - 5393549.0L/72.0L) + 509327.0L/48.0L) + 29.0L/24.0L) + 29.0L/36.0L) - 61.0L/15.0L) - 61.0L/30.0L) + 8.0L/5.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-287651.0L/20.0L*x + 3164161.0L/40.0L) - 4313155.0L/24.0L) + 1723491.0L/8.0L) - 1433091.0L/10.0L) + 4494623.0L/90.0L) - 212219.0L/30.0L) - 13.0L/24.0L) - 13.0L/18.0L) + 169.0L/120.0L) + 169.0L/120.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((123279.0L/20.0L)*x - 1356069.0L/40.0L) + 616165.0L/8.0L) - 738639.0L/8.0L) + 4299273.0L/70.0L) - 3852533.0L/180.0L) + 30317.0L/10.0L) + 1.0L/8.0L) + 1.0L/4.0L) - 1.0L/5.0L) - 3.0L/10.0L) + 8.0L/315.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-123279.0L/80.0L*x + 1356069.0L/160.0L) - 616165.0L/32.0L) + 738639.0L/32.0L) - 4299273.0L/280.0L) + 963133.0L/180.0L) - 72761.0L/96.0L) - 1.0L/96.0L) - 1.0L/36.0L) + 7.0L/480.0L) + 7.0L/240.0L) - 1.0L/560.0L;
poly_val[9] = pow(x, 5)*(x*(x*(x*(x*(x*((41093.0L/240.0L)*x - 452023.0L/480.0L) + 616165.0L/288.0L) - 82071.0L/32.0L) + 477697.0L/280.0L) - 428059.0L/720.0L) + 40423.0L/480.0L);
break;
}
}
void beta_n4_m7(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((40423.0L/10080.0L)*x - 40423.0L/1344.0L) + 6995.0L/72.0L) - 67327.0L/384.0L) + 55033.0L/288.0L) - 181291.0L/1440.0L) + 234277.0L/5040.0L) - 149777.0L/20160.0L) - 1.0L/10080.0L) - 1.0L/2880.0L) + 1.0L/720.0L) + 7.0L/5760.0L) - 7.0L/1440.0L) - 1.0L/1120.0L) + 1.0L/280.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-40423.0L/1120.0L*x + 121269.0L/448.0L) - 6995.0L/8.0L) + 201981.0L/128.0L) - 55033.0L/32.0L) + 181291.0L/160.0L) - 234277.0L/560.0L) + 385141.0L/5760.0L) + 1.0L/1680.0L) + 1.0L/240.0L) - 1.0L/80.0L) - 1.0L/60.0L) + 1.0L/20.0L) + 4.0L/315.0L) - 4.0L/105.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((40423.0L/280.0L)*x - 121269.0L/112.0L) + 6995.0L/2.0L) - 201981.0L/32.0L) + 55033.0L/8.0L) - 181291.0L/40.0L) + 234277.0L/140.0L) - 673997.0L/2520.0L) - 1.0L/720.0L) - 13.0L/720.0L) + 13.0L/360.0L) + 169.0L/1440.0L) - 169.0L/720.0L) - 1.0L/10.0L) + 1.0L/5.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-40423.0L/120.0L*x + 40423.0L/16.0L) - 48965.0L/6.0L) + 471289.0L/32.0L) - 385231.0L/24.0L) + 1269037.0L/120.0L) - 234277.0L/60.0L) + 898663.0L/1440.0L) + 1.0L/720.0L) + 29.0L/720.0L) - 29.0L/720.0L) - 61.0L/180.0L) + 61.0L/180.0L) + 4.0L/5.0L) - 4.0L/5.0L);
poly_val[4] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*((40423.0L/80.0L)*x - 121269.0L/32.0L) + 48965.0L/4.0L) - 1413867.0L/64.0L) + 385231.0L/16.0L) - 1269037.0L/80.0L) + 234277.0L/40.0L) - 269599.0L/288.0L) - 5.0L/96.0L) + 91.0L/192.0L) - 205.0L/144.0L) + 1;
poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-40423.0L/80.0L*x + 121269.0L/32.0L) - 48965.0L/4.0L) + 1413867.0L/64.0L) - 385231.0L/16.0L) + 1269037.0L/80.0L) - 234277.0L/40.0L) + 2695991.0L/2880.0L) - 1.0L/720.0L) + 29.0L/720.0L) + 29.0L/720.0L) - 61.0L/180.0L) - 61.0L/180.0L) + 4.0L/5.0L) + 4.0L/5.0L);
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((40423.0L/120.0L)*x - 40423.0L/16.0L) + 48965.0L/6.0L) - 471289.0L/32.0L) + 385231.0L/24.0L) - 1269037.0L/120.0L) + 234277.0L/60.0L) - 112333.0L/180.0L) + 1.0L/720.0L) - 13.0L/720.0L) - 13.0L/360.0L) + 169.0L/1440.0L) + 169.0L/720.0L) - 1.0L/10.0L) - 1.0L/5.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-40423.0L/280.0L*x + 121269.0L/112.0L) - 6995.0L/2.0L) + 201981.0L/32.0L) - 55033.0L/8.0L) + 181291.0L/40.0L) - 234277.0L/140.0L) + 2695993.0L/10080.0L) - 1.0L/1680.0L) + 1.0L/240.0L) + 1.0L/80.0L) - 1.0L/60.0L) - 1.0L/20.0L) + 4.0L/315.0L) + 4.0L/105.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((40423.0L/1120.0L)*x - 121269.0L/448.0L) + 6995.0L/8.0L) - 201981.0L/128.0L) + 55033.0L/32.0L) - 181291.0L/160.0L) + 234277.0L/560.0L) - 192571.0L/2880.0L) + 1.0L/10080.0L) - 1.0L/2880.0L) - 1.0L/720.0L) + 7.0L/5760.0L) + 7.0L/1440.0L) - 1.0L/1120.0L) - 1.0L/280.0L);
poly_val[9] = pow(x, 8)*(x*(x*(x*(x*(x*(x*(-40423.0L/10080.0L*x + 40423.0L/1344.0L) - 6995.0L/72.0L) + 67327.0L/384.0L) - 55033.0L/288.0L) + 181291.0L/1440.0L) - 234277.0L/5040.0L) + 59911.0L/8064.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((40423.0L/672.0L)*x - 40423.0L/96.0L) + 90935.0L/72.0L) - 67327.0L/32.0L) + 605363.0L/288.0L) - 181291.0L/144.0L) + 234277.0L/560.0L) - 149777.0L/2520.0L) - 1.0L/1440.0L) - 1.0L/480.0L) + 1.0L/144.0L) + 7.0L/1440.0L) - 7.0L/480.0L) - 1.0L/560.0L) + 1.0L/280.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-121269.0L/224.0L*x + 121269.0L/32.0L) - 90935.0L/8.0L) + 605943.0L/32.0L) - 605363.0L/32.0L) + 181291.0L/16.0L) - 2108493.0L/560.0L) + 385141.0L/720.0L) + 1.0L/240.0L) + 1.0L/40.0L) - 1.0L/16.0L) - 1.0L/15.0L) + 3.0L/20.0L) + 8.0L/315.0L) - 4.0L/105.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((121269.0L/56.0L)*x - 121269.0L/8.0L) + 90935.0L/2.0L) - 605943.0L/8.0L) + 605363.0L/8.0L) - 181291.0L/4.0L) + 2108493.0L/140.0L) - 673997.0L/315.0L) - 7.0L/720.0L) - 13.0L/120.0L) + 13.0L/72.0L) + 169.0L/360.0L) - 169.0L/240.0L) - 1.0L/5.0L) + 1.0L/5.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-40423.0L/8.0L*x + 282961.0L/8.0L) - 636545.0L/6.0L) + 1413867.0L/8.0L) - 4237541.0L/24.0L) + 1269037.0L/12.0L) - 702831.0L/20.0L) + 898663.0L/180.0L) + 7.0L/720.0L) + 29.0L/120.0L) - 29.0L/144.0L) - 61.0L/45.0L) + 61.0L/60.0L) + 8.0L/5.0L) - 4.0L/5.0L;
poly_val[4] = x*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*((121269.0L/16.0L)*x - 848883.0L/16.0L) + 636545.0L/4.0L) - 4241601.0L/16.0L) + 4237541.0L/16.0L) - 1269037.0L/8.0L) + 2108493.0L/40.0L) - 269599.0L/36.0L) - 5.0L/16.0L) + 91.0L/48.0L) - 205.0L/72.0L);
poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-121269.0L/16.0L*x + 848883.0L/16.0L) - 636545.0L/4.0L) + 4241601.0L/16.0L) - 4237541.0L/16.0L) + 1269037.0L/8.0L) - 2108493.0L/40.0L) + 2695991.0L/360.0L) - 7.0L/720.0L) + 29.0L/120.0L) + 29.0L/144.0L) - 61.0L/45.0L) - 61.0L/60.0L) + 8.0L/5.0L) + 4.0L/5.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((40423.0L/8.0L)*x - 282961.0L/8.0L) + 636545.0L/6.0L) - 1413867.0L/8.0L) + 4237541.0L/24.0L) - 1269037.0L/12.0L) + 702831.0L/20.0L) - 224666.0L/45.0L) + 7.0L/720.0L) - 13.0L/120.0L) - 13.0L/72.0L) + 169.0L/360.0L) + 169.0L/240.0L) - 1.0L/5.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-121269.0L/56.0L*x + 121269.0L/8.0L) - 90935.0L/2.0L) + 605943.0L/8.0L) - 605363.0L/8.0L) + 181291.0L/4.0L) - 2108493.0L/140.0L) + 2695993.0L/1260.0L) - 1.0L/240.0L) + 1.0L/40.0L) + 1.0L/16.0L) - 1.0L/15.0L) - 3.0L/20.0L) + 8.0L/315.0L) + 4.0L/105.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((121269.0L/224.0L)*x - 121269.0L/32.0L) + 90935.0L/8.0L) - 605943.0L/32.0L) + 605363.0L/32.0L) - 181291.0L/16.0L) + 2108493.0L/560.0L) - 192571.0L/360.0L) + 1.0L/1440.0L) - 1.0L/480.0L) - 1.0L/144.0L) + 7.0L/1440.0L) + 7.0L/480.0L) - 1.0L/560.0L) - 1.0L/280.0L;
poly_val[9] = pow(x, 7)*(x*(x*(x*(x*(x*(x*(-40423.0L/672.0L*x + 40423.0L/96.0L) - 90935.0L/72.0L) + 67327.0L/32.0L) - 605363.0L/288.0L) + 181291.0L/144.0L) - 234277.0L/560.0L) + 59911.0L/1008.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((40423.0L/48.0L)*x - 525499.0L/96.0L) + 90935.0L/6.0L) - 740597.0L/32.0L) + 3026815.0L/144.0L) - 181291.0L/16.0L) + 234277.0L/70.0L) - 149777.0L/360.0L) - 1.0L/240.0L) - 1.0L/96.0L) + 1.0L/36.0L) + 7.0L/480.0L) - 7.0L/240.0L) - 1.0L/560.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-121269.0L/16.0L*x + 1576497.0L/32.0L) - 272805.0L/2.0L) + 6665373.0L/32.0L) - 3026815.0L/16.0L) + 1631619.0L/16.0L) - 2108493.0L/70.0L) + 2695987.0L/720.0L) + 1.0L/40.0L) + 1.0L/8.0L) - 1.0L/4.0L) - 1.0L/5.0L) + 3.0L/10.0L) + 8.0L/315.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((121269.0L/4.0L)*x - 1576497.0L/8.0L) + 545610) - 6665373.0L/8.0L) + 3026815.0L/4.0L) - 1631619.0L/4.0L) + 4216986.0L/35.0L) - 673997.0L/45.0L) - 7.0L/120.0L) - 13.0L/24.0L) + 13.0L/18.0L) + 169.0L/120.0L) - 169.0L/120.0L) - 1.0L/5.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-282961.0L/4.0L*x + 3678493.0L/8.0L) - 1273090) + 15552537.0L/8.0L) - 21187705.0L/12.0L) + 3807111.0L/4.0L) - 1405662.0L/5.0L) + 6290641.0L/180.0L) + 7.0L/120.0L) + 29.0L/24.0L) - 29.0L/36.0L) - 61.0L/15.0L) + 61.0L/30.0L) + 8.0L/5.0L;
poly_val[4] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*((848883.0L/8.0L)*x - 11035479.0L/16.0L) + 1909635) - 46657611.0L/16.0L) + 21187705.0L/8.0L) - 11421333.0L/8.0L) + 2108493.0L/5.0L) - 1887193.0L/36.0L) - 25.0L/16.0L) + 91.0L/16.0L) - 205.0L/72.0L;
poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-848883.0L/8.0L*x + 11035479.0L/16.0L) - 1909635) + 46657611.0L/16.0L) - 21187705.0L/8.0L) + 11421333.0L/8.0L) - 2108493.0L/5.0L) + 18871937.0L/360.0L) - 7.0L/120.0L) + 29.0L/24.0L) + 29.0L/36.0L) - 61.0L/15.0L) - 61.0L/30.0L) + 8.0L/5.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((282961.0L/4.0L)*x - 3678493.0L/8.0L) + 1273090) - 15552537.0L/8.0L) + 21187705.0L/12.0L) - 3807111.0L/4.0L) + 1405662.0L/5.0L) - 1572662.0L/45.0L) + 7.0L/120.0L) - 13.0L/24.0L) - 13.0L/18.0L) + 169.0L/120.0L) + 169.0L/120.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-121269.0L/4.0L*x + 1576497.0L/8.0L) - 545610) + 6665373.0L/8.0L) - 3026815.0L/4.0L) + 1631619.0L/4.0L) - 4216986.0L/35.0L) + 2695993.0L/180.0L) - 1.0L/40.0L) + 1.0L/8.0L) + 1.0L/4.0L) - 1.0L/5.0L) - 3.0L/10.0L) + 8.0L/315.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((121269.0L/16.0L)*x - 1576497.0L/32.0L) + 272805.0L/2.0L) - 6665373.0L/32.0L) + 3026815.0L/16.0L) - 1631619.0L/16.0L) + 2108493.0L/70.0L) - 1347997.0L/360.0L) + 1.0L/240.0L) - 1.0L/96.0L) - 1.0L/36.0L) + 7.0L/480.0L) + 7.0L/240.0L) - 1.0L/560.0L;
poly_val[9] = pow(x, 6)*(x*(x*(x*(x*(x*(x*(-40423.0L/48.0L*x + 525499.0L/96.0L) - 90935.0L/6.0L) + 740597.0L/32.0L) - 3026815.0L/144.0L) + 181291.0L/16.0L) - 234277.0L/70.0L) + 59911.0L/144.0L);
break;
}
}
void beta_n4_m8(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-59911.0L/4032.0L*x + 1018487.0L/8064.0L) - 4752457.0L/10080.0L) + 4072501.0L/4032.0L) - 391397.0L/288.0L) + 1355705.0L/1152.0L) - 61537.0L/96.0L) + 168839.0L/840.0L) - 186889.0L/6720.0L) + 1.0L/40320.0L) - 1.0L/10080.0L) - 1.0L/2880.0L) + 1.0L/720.0L) + 7.0L/5760.0L) - 7.0L/1440.0L) - 1.0L/1120.0L) + 1.0L/280.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((59911.0L/448.0L)*x - 1018487.0L/896.0L) + 4752457.0L/1120.0L) - 4072501.0L/448.0L) + 391397.0L/32.0L) - 1355705.0L/128.0L) + 184611.0L/32.0L) - 506517.0L/280.0L) + 560667.0L/2240.0L) - 1.0L/5040.0L) + 1.0L/1680.0L) + 1.0L/240.0L) - 1.0L/80.0L) - 1.0L/60.0L) + 1.0L/20.0L) + 4.0L/315.0L) - 4.0L/105.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-59911.0L/112.0L*x + 1018487.0L/224.0L) - 4752457.0L/280.0L) + 4072501.0L/112.0L) - 391397.0L/8.0L) + 1355705.0L/32.0L) - 184611.0L/8.0L) + 506517.0L/70.0L) - 560667.0L/560.0L) + 1.0L/1440.0L) - 1.0L/720.0L) - 13.0L/720.0L) + 13.0L/360.0L) + 169.0L/1440.0L) - 169.0L/720.0L) - 1.0L/10.0L) + 1.0L/5.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((59911.0L/48.0L)*x - 1018487.0L/96.0L) + 4752457.0L/120.0L) - 4072501.0L/48.0L) + 2739779.0L/24.0L) - 9489935.0L/96.0L) + 430759.0L/8.0L) - 168839.0L/10.0L) + 186889.0L/80.0L) - 1.0L/720.0L) + 1.0L/720.0L) + 29.0L/720.0L) - 29.0L/720.0L) - 61.0L/180.0L) + 61.0L/180.0L) + 4.0L/5.0L) - 4.0L/5.0L);
poly_val[4] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(x*(x*(-59911.0L/32.0L*x + 1018487.0L/64.0L) - 4752457.0L/80.0L) + 4072501.0L/32.0L) - 2739779.0L/16.0L) + 9489935.0L/64.0L) - 1292277.0L/16.0L) + 506517.0L/20.0L) - 560667.0L/160.0L) + 1.0L/576.0L) - 5.0L/96.0L) + 91.0L/192.0L) - 205.0L/144.0L) + 1;
poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((59911.0L/32.0L)*x - 1018487.0L/64.0L) + 4752457.0L/80.0L) - 4072501.0L/32.0L) + 2739779.0L/16.0L) - 9489935.0L/64.0L) + 1292277.0L/16.0L) - 506517.0L/20.0L) + 560667.0L/160.0L) - 1.0L/720.0L) - 1.0L/720.0L) + 29.0L/720.0L) + 29.0L/720.0L) - 61.0L/180.0L) - 61.0L/180.0L) + 4.0L/5.0L) + 4.0L/5.0L);
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-59911.0L/48.0L*x + 1018487.0L/96.0L) - 4752457.0L/120.0L) + 4072501.0L/48.0L) - 2739779.0L/24.0L) + 9489935.0L/96.0L) - 430759.0L/8.0L) + 168839.0L/10.0L) - 186889.0L/80.0L) + 1.0L/1440.0L) + 1.0L/720.0L) - 13.0L/720.0L) - 13.0L/360.0L) + 169.0L/1440.0L) + 169.0L/720.0L) - 1.0L/10.0L) - 1.0L/5.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((59911.0L/112.0L)*x - 1018487.0L/224.0L) + 4752457.0L/280.0L) - 4072501.0L/112.0L) + 391397.0L/8.0L) - 1355705.0L/32.0L) + 184611.0L/8.0L) - 506517.0L/70.0L) + 560667.0L/560.0L) - 1.0L/5040.0L) - 1.0L/1680.0L) + 1.0L/240.0L) + 1.0L/80.0L) - 1.0L/60.0L) - 1.0L/20.0L) + 4.0L/315.0L) + 4.0L/105.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-59911.0L/448.0L*x + 1018487.0L/896.0L) - 4752457.0L/1120.0L) + 4072501.0L/448.0L) - 391397.0L/32.0L) + 1355705.0L/128.0L) - 184611.0L/32.0L) + 506517.0L/280.0L) - 560667.0L/2240.0L) + 1.0L/40320.0L) + 1.0L/10080.0L) - 1.0L/2880.0L) - 1.0L/720.0L) + 7.0L/5760.0L) + 7.0L/1440.0L) - 1.0L/1120.0L) - 1.0L/280.0L);
poly_val[9] = pow(x, 9)*(x*(x*(x*(x*(x*(x*(x*((59911.0L/4032.0L)*x - 1018487.0L/8064.0L) + 4752457.0L/10080.0L) - 4072501.0L/4032.0L) + 391397.0L/288.0L) - 1355705.0L/1152.0L) + 61537.0L/96.0L) - 168839.0L/840.0L) + 186889.0L/6720.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-1018487.0L/4032.0L*x + 1018487.0L/504.0L) - 4752457.0L/672.0L) + 4072501.0L/288.0L) - 5088161.0L/288.0L) + 1355705.0L/96.0L) - 676907.0L/96.0L) + 168839.0L/84.0L) - 560667.0L/2240.0L) + 1.0L/5040.0L) - 1.0L/1440.0L) - 1.0L/480.0L) + 1.0L/144.0L) + 7.0L/1440.0L) - 7.0L/480.0L) - 1.0L/560.0L) + 1.0L/280.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((1018487.0L/448.0L)*x - 1018487.0L/56.0L) + 14257371.0L/224.0L) - 4072501.0L/32.0L) + 5088161.0L/32.0L) - 4067115.0L/32.0L) + 2030721.0L/32.0L) - 506517.0L/28.0L) + 5046003.0L/2240.0L) - 1.0L/630.0L) + 1.0L/240.0L) + 1.0L/40.0L) - 1.0L/16.0L) - 1.0L/15.0L) + 3.0L/20.0L) + 8.0L/315.0L) - 4.0L/105.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-1018487.0L/112.0L*x + 1018487.0L/14.0L) - 14257371.0L/56.0L) + 4072501.0L/8.0L) - 5088161.0L/8.0L) + 4067115.0L/8.0L) - 2030721.0L/8.0L) + 506517.0L/7.0L) - 5046003.0L/560.0L) + 1.0L/180.0L) - 7.0L/720.0L) - 13.0L/120.0L) + 13.0L/72.0L) + 169.0L/360.0L) - 169.0L/240.0L) - 1.0L/5.0L) + 1.0L/5.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((1018487.0L/48.0L)*x - 1018487.0L/6.0L) + 4752457.0L/8.0L) - 28507507.0L/24.0L) + 35617127.0L/24.0L) - 9489935.0L/8.0L) + 4738349.0L/8.0L) - 168839) + 1682001.0L/80.0L) - 1.0L/90.0L) + 7.0L/720.0L) + 29.0L/120.0L) - 29.0L/144.0L) - 61.0L/45.0L) + 61.0L/60.0L) + 8.0L/5.0L) - 4.0L/5.0L;
poly_val[4] = x*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(x*(x*(-1018487.0L/32.0L*x + 1018487.0L/4.0L) - 14257371.0L/16.0L) + 28507507.0L/16.0L) - 35617127.0L/16.0L) + 28469805.0L/16.0L) - 14215047.0L/16.0L) + 506517.0L/2.0L) - 5046003.0L/160.0L) + 1.0L/72.0L) - 5.0L/16.0L) + 91.0L/48.0L) - 205.0L/72.0L);
poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((1018487.0L/32.0L)*x - 1018487.0L/4.0L) + 14257371.0L/16.0L) - 28507507.0L/16.0L) + 35617127.0L/16.0L) - 28469805.0L/16.0L) + 14215047.0L/16.0L) - 506517.0L/2.0L) + 5046003.0L/160.0L) - 1.0L/90.0L) - 7.0L/720.0L) + 29.0L/120.0L) + 29.0L/144.0L) - 61.0L/45.0L) - 61.0L/60.0L) + 8.0L/5.0L) + 4.0L/5.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-1018487.0L/48.0L*x + 1018487.0L/6.0L) - 4752457.0L/8.0L) + 28507507.0L/24.0L) - 35617127.0L/24.0L) + 9489935.0L/8.0L) - 4738349.0L/8.0L) + 168839) - 1682001.0L/80.0L) + 1.0L/180.0L) + 7.0L/720.0L) - 13.0L/120.0L) - 13.0L/72.0L) + 169.0L/360.0L) + 169.0L/240.0L) - 1.0L/5.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((1018487.0L/112.0L)*x - 1018487.0L/14.0L) + 14257371.0L/56.0L) - 4072501.0L/8.0L) + 5088161.0L/8.0L) - 4067115.0L/8.0L) + 2030721.0L/8.0L) - 506517.0L/7.0L) + 5046003.0L/560.0L) - 1.0L/630.0L) - 1.0L/240.0L) + 1.0L/40.0L) + 1.0L/16.0L) - 1.0L/15.0L) - 3.0L/20.0L) + 8.0L/315.0L) + 4.0L/105.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-1018487.0L/448.0L*x + 1018487.0L/56.0L) - 14257371.0L/224.0L) + 4072501.0L/32.0L) - 5088161.0L/32.0L) + 4067115.0L/32.0L) - 2030721.0L/32.0L) + 506517.0L/28.0L) - 5046003.0L/2240.0L) + 1.0L/5040.0L) + 1.0L/1440.0L) - 1.0L/480.0L) - 1.0L/144.0L) + 7.0L/1440.0L) + 7.0L/480.0L) - 1.0L/560.0L) - 1.0L/280.0L;
poly_val[9] = pow(x, 8)*(x*(x*(x*(x*(x*(x*(x*((1018487.0L/4032.0L)*x - 1018487.0L/504.0L) + 4752457.0L/672.0L) - 4072501.0L/288.0L) + 5088161.0L/288.0L) - 1355705.0L/96.0L) + 676907.0L/96.0L) - 168839.0L/84.0L) + 560667.0L/2240.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-1018487.0L/252.0L*x + 5092435.0L/168.0L) - 4752457.0L/48.0L) + 52942513.0L/288.0L) - 5088161.0L/24.0L) + 14912755.0L/96.0L) - 3384535.0L/48.0L) + 506517.0L/28.0L) - 560667.0L/280.0L) + 1.0L/720.0L) - 1.0L/240.0L) - 1.0L/96.0L) + 1.0L/36.0L) + 7.0L/480.0L) - 7.0L/240.0L) - 1.0L/560.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((1018487.0L/28.0L)*x - 15277305.0L/56.0L) + 14257371.0L/16.0L) - 52942513.0L/32.0L) + 15264483.0L/8.0L) - 44738265.0L/32.0L) + 10153605.0L/16.0L) - 4558653.0L/28.0L) + 5046003.0L/280.0L) - 1.0L/90.0L) + 1.0L/40.0L) + 1.0L/8.0L) - 1.0L/4.0L) - 1.0L/5.0L) + 3.0L/10.0L) + 8.0L/315.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-1018487.0L/7.0L*x + 15277305.0L/14.0L) - 14257371.0L/4.0L) + 52942513.0L/8.0L) - 15264483.0L/2.0L) + 44738265.0L/8.0L) - 10153605.0L/4.0L) + 4558653.0L/7.0L) - 5046003.0L/70.0L) + 7.0L/180.0L) - 7.0L/120.0L) - 13.0L/24.0L) + 13.0L/18.0L) + 169.0L/120.0L) - 169.0L/120.0L) - 1.0L/5.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((1018487.0L/3.0L)*x - 5092435.0L/2.0L) + 33267199.0L/4.0L) - 370597591.0L/24.0L) + 35617127.0L/2.0L) - 104389285.0L/8.0L) + 23691745.0L/4.0L) - 1519551) + 1682001.0L/10.0L) - 7.0L/90.0L) + 7.0L/120.0L) + 29.0L/24.0L) - 29.0L/36.0L) - 61.0L/15.0L) + 61.0L/30.0L) + 8.0L/5.0L;
poly_val[4] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(x*(x*(-1018487.0L/2.0L*x + 15277305.0L/4.0L) - 99801597.0L/8.0L) + 370597591.0L/16.0L) - 106851381.0L/4.0L) + 313167855.0L/16.0L) - 71075235.0L/8.0L) + 4558653.0L/2.0L) - 5046003.0L/20.0L) + 7.0L/72.0L) - 25.0L/16.0L) + 91.0L/16.0L) - 205.0L/72.0L;
poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((1018487.0L/2.0L)*x - 15277305.0L/4.0L) + 99801597.0L/8.0L) - 370597591.0L/16.0L) + 106851381.0L/4.0L) - 313167855.0L/16.0L) + 71075235.0L/8.0L) - 4558653.0L/2.0L) + 5046003.0L/20.0L) - 7.0L/90.0L) - 7.0L/120.0L) + 29.0L/24.0L) + 29.0L/36.0L) - 61.0L/15.0L) - 61.0L/30.0L) + 8.0L/5.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-1018487.0L/3.0L*x + 5092435.0L/2.0L) - 33267199.0L/4.0L) + 370597591.0L/24.0L) - 35617127.0L/2.0L) + 104389285.0L/8.0L) - 23691745.0L/4.0L) + 1519551) - 1682001.0L/10.0L) + 7.0L/180.0L) + 7.0L/120.0L) - 13.0L/24.0L) - 13.0L/18.0L) + 169.0L/120.0L) + 169.0L/120.0L) - 1.0L/5.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((1018487.0L/7.0L)*x - 15277305.0L/14.0L) + 14257371.0L/4.0L) - 52942513.0L/8.0L) + 15264483.0L/2.0L) - 44738265.0L/8.0L) + 10153605.0L/4.0L) - 4558653.0L/7.0L) + 5046003.0L/70.0L) - 1.0L/90.0L) - 1.0L/40.0L) + 1.0L/8.0L) + 1.0L/4.0L) - 1.0L/5.0L) - 3.0L/10.0L) + 8.0L/315.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-1018487.0L/28.0L*x + 15277305.0L/56.0L) - 14257371.0L/16.0L) + 52942513.0L/32.0L) - 15264483.0L/8.0L) + 44738265.0L/32.0L) - 10153605.0L/16.0L) + 4558653.0L/28.0L) - 5046003.0L/280.0L) + 1.0L/720.0L) + 1.0L/240.0L) - 1.0L/96.0L) - 1.0L/36.0L) + 7.0L/480.0L) + 7.0L/240.0L) - 1.0L/560.0L;
poly_val[9] = pow(x, 7)*(x*(x*(x*(x*(x*(x*(x*((1018487.0L/252.0L)*x - 5092435.0L/168.0L) + 4752457.0L/48.0L) - 52942513.0L/288.0L) + 5088161.0L/24.0L) - 14912755.0L/96.0L) + 3384535.0L/48.0L) - 506517.0L/28.0L) + 560667.0L/280.0L);
break;
}
}
