/**********************************************************************
*                                                                     *
*  Copyright 2015 the TurTLE team                                     *
*                                                                     *
*  This file is part of TurTLE.                                       *
*                                                                     *
*  TurTLE is free software: you can redistribute it and/or modify     *
*  it under the terms of the GNU General Public License as published  *
*  by the Free Software Foundation, either version 3 of the License,  *
*  or (at your option) any later version.                             *
*                                                                     *
*  TurTLE is distributed in the hope that it will be useful,          *
*  but WITHOUT ANY WARRANTY; without even the implied warranty of     *
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      *
*  GNU General Public License for more details.                       *
*                                                                     *
*  You should have received a copy of the GNU General Public License  *
*  along with TurTLE.  If not, see <http://www.gnu.org/licenses/>     *
*                                                                     *
* Contact: Cristian.Lalescu@ds.mpg.de                                 *
*                                                                     *
**********************************************************************/



#include "spline_n7.hpp"
#include <cmath>

void beta_n7_m0(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = 0;
        poly_val[1] = 0;
        poly_val[2] = 0;
        poly_val[3] = 0;
        poly_val[4] = 0;
        poly_val[5] = 0;
        poly_val[6] = 0;
        poly_val[7] = -x + 1;
        poly_val[8] = x;
        poly_val[9] = 0;
        poly_val[10] = 0;
        poly_val[11] = 0;
        poly_val[12] = 0;
        poly_val[13] = 0;
        poly_val[14] = 0;
        poly_val[15] = 0;
        break;
    case 1:
        poly_val[0] = 0;
        poly_val[1] = 0;
        poly_val[2] = 0;
        poly_val[3] = 0;
        poly_val[4] = 0;
        poly_val[5] = 0;
        poly_val[6] = 0;
        poly_val[7] = -1;
        poly_val[8] = 1;
        poly_val[9] = 0;
        poly_val[10] = 0;
        poly_val[11] = 0;
        poly_val[12] = 0;
        poly_val[13] = 0;
        poly_val[14] = 0;
        poly_val[15] = 0;
        break;
    case 2:
        poly_val[0] = 0;
        poly_val[1] = 0;
        poly_val[2] = 0;
        poly_val[3] = 0;
        poly_val[4] = 0;
        poly_val[5] = 0;
        poly_val[6] = 0;
        poly_val[7] = 0;
        poly_val[8] = 0;
        poly_val[9] = 0;
        poly_val[10] = 0;
        poly_val[11] = 0;
        poly_val[12] = 0;
        poly_val[13] = 0;
        poly_val[14] = 0;
        poly_val[15] = 0;
        break;
    }
}
void beta_n7_m1(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = x*(x*(-1.0L/24024.0L*x + 1.0L/12012.0L) - 1.0L/24024.0L);
        poly_val[1] = x*(x*((23.0L/36036.0L)*x - 95.0L/72072.0L) + 7.0L/10296.0L);
        poly_val[2] = x*(x*(-119.0L/25740.0L*x + 511.0L/51480.0L) - 7.0L/1320.0L);
        poly_val[3] = x*(x*((7.0L/330.0L)*x - 21.0L/440.0L) + 7.0L/264.0L);
        poly_val[4] = x*(x*(-7.0L/99.0L*x + 133.0L/792.0L) - 7.0L/72.0L);
        poly_val[5] = x*(x*((7.0L/36.0L)*x - 35.0L/72.0L) + 7.0L/24.0L);
        poly_val[6] = x*(x*(-7.0L/12.0L*x + 35.0L/24.0L) - 7.0L/8.0L);
        poly_val[7] = pow(x, 2)*((9.0L/8.0L)*x - 17.0L/8.0L) + 1;
        poly_val[8] = x*(x*(-9.0L/8.0L*x + 5.0L/4.0L) + 7.0L/8.0L);
        poly_val[9] = x*(x*((7.0L/12.0L)*x - 7.0L/24.0L) - 7.0L/24.0L);
        poly_val[10] = x*(x*(-7.0L/36.0L*x + 7.0L/72.0L) + 7.0L/72.0L);
        poly_val[11] = x*(x*((7.0L/99.0L)*x - 35.0L/792.0L) - 7.0L/264.0L);
        poly_val[12] = x*(x*(-7.0L/330.0L*x + 7.0L/440.0L) + 7.0L/1320.0L);
        poly_val[13] = x*(x*((119.0L/25740.0L)*x - 203.0L/51480.0L) - 7.0L/10296.0L);
        poly_val[14] = x*(x*(-23.0L/36036.0L*x + 43.0L/72072.0L) + 1.0L/24024.0L);
        poly_val[15] = pow(x, 2)*((1.0L/24024.0L)*x - 1.0L/24024.0L);
        break;
    case 1:
        poly_val[0] = x*(-1.0L/8008.0L*x + 1.0L/6006.0L) - 1.0L/24024.0L;
        poly_val[1] = x*((23.0L/12012.0L)*x - 95.0L/36036.0L) + 7.0L/10296.0L;
        poly_val[2] = x*(-119.0L/8580.0L*x + 511.0L/25740.0L) - 7.0L/1320.0L;
        poly_val[3] = x*((7.0L/110.0L)*x - 21.0L/220.0L) + 7.0L/264.0L;
        poly_val[4] = x*(-7.0L/33.0L*x + 133.0L/396.0L) - 7.0L/72.0L;
        poly_val[5] = x*((7.0L/12.0L)*x - 35.0L/36.0L) + 7.0L/24.0L;
        poly_val[6] = x*(-7.0L/4.0L*x + 35.0L/12.0L) - 7.0L/8.0L;
        poly_val[7] = x*((27.0L/8.0L)*x - 17.0L/4.0L);
        poly_val[8] = x*(-27.0L/8.0L*x + 5.0L/2.0L) + 7.0L/8.0L;
        poly_val[9] = x*((7.0L/4.0L)*x - 7.0L/12.0L) - 7.0L/24.0L;
        poly_val[10] = x*(-7.0L/12.0L*x + 7.0L/36.0L) + 7.0L/72.0L;
        poly_val[11] = x*((7.0L/33.0L)*x - 35.0L/396.0L) - 7.0L/264.0L;
        poly_val[12] = x*(-7.0L/110.0L*x + 7.0L/220.0L) + 7.0L/1320.0L;
        poly_val[13] = x*((119.0L/8580.0L)*x - 203.0L/25740.0L) - 7.0L/10296.0L;
        poly_val[14] = x*(-23.0L/12012.0L*x + 43.0L/36036.0L) + 1.0L/24024.0L;
        poly_val[15] = x*((1.0L/8008.0L)*x - 1.0L/12012.0L);
        break;
    case 2:
        poly_val[0] = -1.0L/4004.0L*x + 1.0L/6006.0L;
        poly_val[1] = (23.0L/6006.0L)*x - 95.0L/36036.0L;
        poly_val[2] = -119.0L/4290.0L*x + 511.0L/25740.0L;
        poly_val[3] = (7.0L/55.0L)*x - 21.0L/220.0L;
        poly_val[4] = -14.0L/33.0L*x + 133.0L/396.0L;
        poly_val[5] = (7.0L/6.0L)*x - 35.0L/36.0L;
        poly_val[6] = -7.0L/2.0L*x + 35.0L/12.0L;
        poly_val[7] = (27.0L/4.0L)*x - 17.0L/4.0L;
        poly_val[8] = -27.0L/4.0L*x + 5.0L/2.0L;
        poly_val[9] = (7.0L/2.0L)*x - 7.0L/12.0L;
        poly_val[10] = -7.0L/6.0L*x + 7.0L/36.0L;
        poly_val[11] = (14.0L/33.0L)*x - 35.0L/396.0L;
        poly_val[12] = -7.0L/55.0L*x + 7.0L/220.0L;
        poly_val[13] = (119.0L/4290.0L)*x - 203.0L/25740.0L;
        poly_val[14] = -23.0L/6006.0L*x + 43.0L/36036.0L;
        poly_val[15] = (1.0L/4004.0L)*x - 1.0L/12012.0L;
        break;
    }
}
void beta_n7_m2(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = x*(x*(x*(x*((5.0L/42042.0L)*x - 53.0L/168168.0L) + 1.0L/4312.0L) + 1.0L/168168.0L) - 1.0L/24024.0L);
        poly_val[1] = x*(x*(x*(x*(-5435.0L/3027024.0L*x + 1613.0L/336336.0L) - 3599.0L/1009008.0L) - 7.0L/61776.0L) + 7.0L/10296.0L);
        poly_val[2] = x*(x*(x*(x*((19607.0L/1544400.0L)*x - 26453.0L/772200.0L) + 39851.0L/1544400.0L) + 7.0L/6600.0L) - 7.0L/1320.0L);
        poly_val[3] = x*(x*(x*(x*(-1477.0L/26400.0L*x + 4039.0L/26400.0L) - 1029.0L/8800.0L) - 7.0L/1056.0L) + 7.0L/264.0L);
        poly_val[4] = x*(x*(x*(x*((1645.0L/9504.0L)*x - 763.0L/1584.0L) + 1183.0L/3168.0L) + 7.0L/216.0L) - 7.0L/72.0L);
        poly_val[5] = x*(x*(x*(x*(-175.0L/432.0L*x + 497.0L/432.0L) - 385.0L/432.0L) - 7.0L/48.0L) + 7.0L/24.0L);
        poly_val[6] = x*(x*(x*(x*((35.0L/48.0L)*x - 49.0L/24.0L) + 21.0L/16.0L) + 7.0L/8.0L) - 7.0L/8.0L);
        poly_val[7] = pow(x, 2)*(x*(x*(-174319.0L/176400.0L*x + 152269.0L/58800.0L) - 64069.0L/58800.0L) - 266681.0L/176400.0L) + 1;
        poly_val[8] = x*(x*(x*(x*((174319.0L/176400.0L)*x - 103697.0L/44100.0L) + 108169.0L/176400.0L) + 7.0L/8.0L) + 7.0L/8.0L);
        poly_val[9] = x*(x*(x*(x*(-35.0L/48.0L*x + 77.0L/48.0L) - 7.0L/16.0L) - 7.0L/48.0L) - 7.0L/24.0L);
        poly_val[10] = x*(x*(x*(x*((175.0L/432.0L)*x - 7.0L/8.0L) + 49.0L/144.0L) + 7.0L/216.0L) + 7.0L/72.0L);
        poly_val[11] = x*(x*(x*(x*(-1645.0L/9504.0L*x + 3647.0L/9504.0L) - 1687.0L/9504.0L) - 7.0L/1056.0L) - 7.0L/264.0L);
        poly_val[12] = x*(x*(x*(x*((1477.0L/26400.0L)*x - 1673.0L/13200.0L) + 567.0L/8800.0L) + 7.0L/6600.0L) + 7.0L/1320.0L);
        poly_val[13] = x*(x*(x*(x*(-19607.0L/1544400.0L*x + 15043.0L/514800.0L) - 623.0L/39600.0L) - 7.0L/61776.0L) - 7.0L/10296.0L);
        poly_val[14] = x*(x*(x*(x*((5435.0L/3027024.0L)*x - 6329.0L/1513512.0L) + 7079.0L/3027024.0L) + 1.0L/168168.0L) + 1.0L/24024.0L);
        poly_val[15] = pow(x, 3)*(x*(-5.0L/42042.0L*x + 47.0L/168168.0L) - 9.0L/56056.0L);
        break;
    case 1:
        poly_val[0] = x*(x*(x*((25.0L/42042.0L)*x - 53.0L/42042.0L) + 3.0L/4312.0L) + 1.0L/84084.0L) - 1.0L/24024.0L;
        poly_val[1] = x*(x*(x*(-27175.0L/3027024.0L*x + 1613.0L/84084.0L) - 3599.0L/336336.0L) - 7.0L/30888.0L) + 7.0L/10296.0L;
        poly_val[2] = x*(x*(x*((19607.0L/308880.0L)*x - 26453.0L/193050.0L) + 39851.0L/514800.0L) + 7.0L/3300.0L) - 7.0L/1320.0L;
        poly_val[3] = x*(x*(x*(-1477.0L/5280.0L*x + 4039.0L/6600.0L) - 3087.0L/8800.0L) - 7.0L/528.0L) + 7.0L/264.0L;
        poly_val[4] = x*(x*(x*((8225.0L/9504.0L)*x - 763.0L/396.0L) + 1183.0L/1056.0L) + 7.0L/108.0L) - 7.0L/72.0L;
        poly_val[5] = x*(x*(x*(-875.0L/432.0L*x + 497.0L/108.0L) - 385.0L/144.0L) - 7.0L/24.0L) + 7.0L/24.0L;
        poly_val[6] = x*(x*(x*((175.0L/48.0L)*x - 49.0L/6.0L) + 63.0L/16.0L) + 7.0L/4.0L) - 7.0L/8.0L;
        poly_val[7] = x*(x*(x*(-174319.0L/35280.0L*x + 152269.0L/14700.0L) - 64069.0L/19600.0L) - 266681.0L/88200.0L);
        poly_val[8] = x*(x*(x*((174319.0L/35280.0L)*x - 103697.0L/11025.0L) + 108169.0L/58800.0L) + 7.0L/4.0L) + 7.0L/8.0L;
        poly_val[9] = x*(x*(x*(-175.0L/48.0L*x + 77.0L/12.0L) - 21.0L/16.0L) - 7.0L/24.0L) - 7.0L/24.0L;
        poly_val[10] = x*(x*(x*((875.0L/432.0L)*x - 7.0L/2.0L) + 49.0L/48.0L) + 7.0L/108.0L) + 7.0L/72.0L;
        poly_val[11] = x*(x*(x*(-8225.0L/9504.0L*x + 3647.0L/2376.0L) - 1687.0L/3168.0L) - 7.0L/528.0L) - 7.0L/264.0L;
        poly_val[12] = x*(x*(x*((1477.0L/5280.0L)*x - 1673.0L/3300.0L) + 1701.0L/8800.0L) + 7.0L/3300.0L) + 7.0L/1320.0L;
        poly_val[13] = x*(x*(x*(-19607.0L/308880.0L*x + 15043.0L/128700.0L) - 623.0L/13200.0L) - 7.0L/30888.0L) - 7.0L/10296.0L;
        poly_val[14] = x*(x*(x*((27175.0L/3027024.0L)*x - 6329.0L/378378.0L) + 7079.0L/1009008.0L) + 1.0L/84084.0L) + 1.0L/24024.0L;
        poly_val[15] = pow(x, 2)*(x*(-25.0L/42042.0L*x + 47.0L/42042.0L) - 27.0L/56056.0L);
        break;
    case 2:
        poly_val[0] = x*(x*((50.0L/21021.0L)*x - 53.0L/14014.0L) + 3.0L/2156.0L) + 1.0L/84084.0L;
        poly_val[1] = x*(x*(-27175.0L/756756.0L*x + 1613.0L/28028.0L) - 3599.0L/168168.0L) - 7.0L/30888.0L;
        poly_val[2] = x*(x*((19607.0L/77220.0L)*x - 26453.0L/64350.0L) + 39851.0L/257400.0L) + 7.0L/3300.0L;
        poly_val[3] = x*(x*(-1477.0L/1320.0L*x + 4039.0L/2200.0L) - 3087.0L/4400.0L) - 7.0L/528.0L;
        poly_val[4] = x*(x*((8225.0L/2376.0L)*x - 763.0L/132.0L) + 1183.0L/528.0L) + 7.0L/108.0L;
        poly_val[5] = x*(x*(-875.0L/108.0L*x + 497.0L/36.0L) - 385.0L/72.0L) - 7.0L/24.0L;
        poly_val[6] = x*(x*((175.0L/12.0L)*x - 49.0L/2.0L) + 63.0L/8.0L) + 7.0L/4.0L;
        poly_val[7] = x*(x*(-174319.0L/8820.0L*x + 152269.0L/4900.0L) - 64069.0L/9800.0L) - 266681.0L/88200.0L;
        poly_val[8] = x*(x*((174319.0L/8820.0L)*x - 103697.0L/3675.0L) + 108169.0L/29400.0L) + 7.0L/4.0L;
        poly_val[9] = x*(x*(-175.0L/12.0L*x + 77.0L/4.0L) - 21.0L/8.0L) - 7.0L/24.0L;
        poly_val[10] = x*(x*((875.0L/108.0L)*x - 21.0L/2.0L) + 49.0L/24.0L) + 7.0L/108.0L;
        poly_val[11] = x*(x*(-8225.0L/2376.0L*x + 3647.0L/792.0L) - 1687.0L/1584.0L) - 7.0L/528.0L;
        poly_val[12] = x*(x*((1477.0L/1320.0L)*x - 1673.0L/1100.0L) + 1701.0L/4400.0L) + 7.0L/3300.0L;
        poly_val[13] = x*(x*(-19607.0L/77220.0L*x + 15043.0L/42900.0L) - 623.0L/6600.0L) - 7.0L/30888.0L;
        poly_val[14] = x*(x*((27175.0L/756756.0L)*x - 6329.0L/126126.0L) + 7079.0L/504504.0L) + 1.0L/84084.0L;
        poly_val[15] = x*(x*(-50.0L/21021.0L*x + 47.0L/14014.0L) - 27.0L/28028.0L);
        break;
    }
}
void beta_n7_m3(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = x*(x*(x*(x*(x*(x*(-200017.0L/605404800.0L*x + 175717.0L/151351200.0L) - 139417.0L/100900800.0L) + 6109.0L/11642400.0L) + 59.0L/950400.0L) + 1.0L/168168.0L) - 1.0L/24024.0L);
        poly_val[1] = x*(x*(x*(x*(x*(x*((4502941.0L/908107200.0L)*x - 2878489.0L/165110400.0L) + 119663.0L/5765760.0L) - 1094837.0L/139708800.0L) - 20137.0L/19958400.0L) - 7.0L/61776.0L) + 7.0L/10296.0L);
        poly_val[2] = x*(x*(x*(x*(x*(x*(-901357.0L/25945920.0L*x + 10570201.0L/86486400.0L) - 4195157.0L/28828800.0L) + 14135041.0L/259459200.0L) + 2077.0L/266112.0L) + 7.0L/6600.0L) - 7.0L/1320.0L);
        poly_val[3] = x*(x*(x*(x*(x*(x*((200569.0L/1330560.0L)*x - 3530803.0L/6652800.0L) + 93403.0L/147840.0L) - 1551821.0L/6652800.0L) - 31957.0L/831600.0L) - 7.0L/1056.0L) + 7.0L/264.0L);
        poly_val[4] = x*(x*(x*(x*(x*(x*(-9044677.0L/19958400.0L*x + 56909.0L/35640.0L) - 6314093.0L/3326400.0L) + 213061.0L/311850.0L) + 247081.0L/1814400.0L) + 7.0L/216.0L) - 7.0L/72.0L);
        poly_val[5] = x*(x*(x*(x*(x*(x*((906869.0L/907200.0L)*x - 2130157.0L/604800.0L) + 503599.0L/120960.0L) - 2574109.0L/1814400.0L) - 222581.0L/604800.0L) - 7.0L/48.0L) + 7.0L/24.0L);
        poly_val[6] = x*(x*(x*(x*(x*(x*(-505069.0L/302400.0L*x + 394819.0L/67200.0L) - 277219.0L/40320.0L) + 1344209.0L/604800.0L) + 90281.0L/201600.0L) + 7.0L/8.0L) - 7.0L/8.0L);
        poly_val[7] = pow(x, 2)*(pow(x, 2)*(x*(x*((121399.0L/56448.0L)*x - 1182509.0L/156800.0L) + 12323341.0L/1411200.0L) - 3993487.0L/1411200.0L) - 266681.0L/176400.0L) + 1;
        poly_val[8] = x*(x*(x*(x*(x*(x*(-121399.0L/56448.0L*x + 2650561.0L/352800.0L) - 174319.0L/20160.0L) + 350719.0L/117600.0L) - 90281.0L/201600.0L) + 7.0L/8.0L) + 7.0L/8.0L);
        poly_val[9] = x*(x*(x*(x*(x*(x*((505069.0L/302400.0L)*x - 703519.0L/120960.0L) + 1350319.0L/201600.0L) - 1501481.0L/604800.0L) + 222581.0L/604800.0L) - 7.0L/48.0L) - 7.0L/24.0L);
        poly_val[10] = x*(x*(x*(x*(x*(x*(-906869.0L/907200.0L*x + 1261139.0L/362880.0L) - 811073.0L/201600.0L) + 2819581.0L/1814400.0L) - 247081.0L/1814400.0L) + 7.0L/216.0L) + 7.0L/72.0L);
        poly_val[11] = x*(x*(x*(x*(x*(x*((9044677.0L/19958400.0L)*x - 1497319.0L/950400.0L) + 813523.0L/443520.0L) - 14314981.0L/19958400.0L) + 31957.0L/831600.0L) - 7.0L/1056.0L) - 7.0L/264.0L);
        poly_val[12] = x*(x*(x*(x*(x*(x*(-200569.0L/1330560.0L*x + 39649.0L/75600.0L) - 226559.0L/369600.0L) + 200173.0L/831600.0L) - 2077.0L/266112.0L) + 7.0L/6600.0L) + 7.0L/1320.0L);
        poly_val[13] = x*(x*(x*(x*(x*(x*((901357.0L/25945920.0L)*x - 31384387.0L/259459200.0L) + 2451851.0L/17297280.0L) - 1112533.0L/19958400.0L) + 20137.0L/19958400.0L) - 7.0L/61776.0L) - 7.0L/10296.0L);
        poly_val[14] = x*(x*(x*(x*(x*(x*(-4502941.0L/908107200.0L*x + 2091853.0L/121080960.0L) - 12279031.0L/605404800.0L) + 1114733.0L/139708800.0L) - 59.0L/950400.0L) + 1.0L/168168.0L) + 1.0L/24024.0L);
        poly_val[15] = pow(x, 4)*(x*(x*((200017.0L/605404800.0L)*x - 232417.0L/201801600.0L) + 39031.0L/28828800.0L) - 322417.0L/605404800.0L);
        break;
    case 1:
        poly_val[0] = x*(x*(x*(x*(x*(-200017.0L/86486400.0L*x + 175717.0L/25225200.0L) - 139417.0L/20180160.0L) + 6109.0L/2910600.0L) + 59.0L/316800.0L) + 1.0L/84084.0L) - 1.0L/24024.0L;
        poly_val[1] = x*(x*(x*(x*(x*((4502941.0L/129729600.0L)*x - 2878489.0L/27518400.0L) + 119663.0L/1153152.0L) - 1094837.0L/34927200.0L) - 20137.0L/6652800.0L) - 7.0L/30888.0L) + 7.0L/10296.0L;
        poly_val[2] = x*(x*(x*(x*(x*(-901357.0L/3706560.0L*x + 10570201.0L/14414400.0L) - 4195157.0L/5765760.0L) + 14135041.0L/64864800.0L) + 2077.0L/88704.0L) + 7.0L/3300.0L) - 7.0L/1320.0L;
        poly_val[3] = x*(x*(x*(x*(x*((200569.0L/190080.0L)*x - 3530803.0L/1108800.0L) + 93403.0L/29568.0L) - 1551821.0L/1663200.0L) - 31957.0L/277200.0L) - 7.0L/528.0L) + 7.0L/264.0L;
        poly_val[4] = x*(x*(x*(x*(x*(-9044677.0L/2851200.0L*x + 56909.0L/5940.0L) - 6314093.0L/665280.0L) + 426122.0L/155925.0L) + 247081.0L/604800.0L) + 7.0L/108.0L) - 7.0L/72.0L;
        poly_val[5] = x*(x*(x*(x*(x*((906869.0L/129600.0L)*x - 2130157.0L/100800.0L) + 503599.0L/24192.0L) - 2574109.0L/453600.0L) - 222581.0L/201600.0L) - 7.0L/24.0L) + 7.0L/24.0L;
        poly_val[6] = x*(x*(x*(x*(x*(-505069.0L/43200.0L*x + 394819.0L/11200.0L) - 277219.0L/8064.0L) + 1344209.0L/151200.0L) + 90281.0L/67200.0L) + 7.0L/4.0L) - 7.0L/8.0L;
        poly_val[7] = x*(pow(x, 2)*(x*(x*((121399.0L/8064.0L)*x - 3547527.0L/78400.0L) + 12323341.0L/282240.0L) - 3993487.0L/352800.0L) - 266681.0L/88200.0L);
        poly_val[8] = x*(x*(x*(x*(x*(-121399.0L/8064.0L*x + 2650561.0L/58800.0L) - 174319.0L/4032.0L) + 350719.0L/29400.0L) - 90281.0L/67200.0L) + 7.0L/4.0L) + 7.0L/8.0L;
        poly_val[9] = x*(x*(x*(x*(x*((505069.0L/43200.0L)*x - 703519.0L/20160.0L) + 1350319.0L/40320.0L) - 1501481.0L/151200.0L) + 222581.0L/201600.0L) - 7.0L/24.0L) - 7.0L/24.0L;
        poly_val[10] = x*(x*(x*(x*(x*(-906869.0L/129600.0L*x + 1261139.0L/60480.0L) - 811073.0L/40320.0L) + 2819581.0L/453600.0L) - 247081.0L/604800.0L) + 7.0L/108.0L) + 7.0L/72.0L;
        poly_val[11] = x*(x*(x*(x*(x*((9044677.0L/2851200.0L)*x - 1497319.0L/158400.0L) + 813523.0L/88704.0L) - 14314981.0L/4989600.0L) + 31957.0L/277200.0L) - 7.0L/528.0L) - 7.0L/264.0L;
        poly_val[12] = x*(x*(x*(x*(x*(-200569.0L/190080.0L*x + 39649.0L/12600.0L) - 226559.0L/73920.0L) + 200173.0L/207900.0L) - 2077.0L/88704.0L) + 7.0L/3300.0L) + 7.0L/1320.0L;
        poly_val[13] = x*(x*(x*(x*(x*((901357.0L/3706560.0L)*x - 31384387.0L/43243200.0L) + 2451851.0L/3459456.0L) - 1112533.0L/4989600.0L) + 20137.0L/6652800.0L) - 7.0L/30888.0L) - 7.0L/10296.0L;
        poly_val[14] = x*(x*(x*(x*(x*(-4502941.0L/129729600.0L*x + 2091853.0L/20180160.0L) - 12279031.0L/121080960.0L) + 1114733.0L/34927200.0L) - 59.0L/316800.0L) + 1.0L/84084.0L) + 1.0L/24024.0L;
        poly_val[15] = pow(x, 3)*(x*(x*((200017.0L/86486400.0L)*x - 232417.0L/33633600.0L) + 39031.0L/5765760.0L) - 322417.0L/151351200.0L);
        break;
    case 2:
        poly_val[0] = x*(x*(x*(x*(-200017.0L/14414400.0L*x + 175717.0L/5045040.0L) - 139417.0L/5045040.0L) + 6109.0L/970200.0L) + 59.0L/158400.0L) + 1.0L/84084.0L;
        poly_val[1] = x*(x*(x*(x*((4502941.0L/21621600.0L)*x - 2878489.0L/5503680.0L) + 119663.0L/288288.0L) - 1094837.0L/11642400.0L) - 20137.0L/3326400.0L) - 7.0L/30888.0L;
        poly_val[2] = x*(x*(x*(x*(-901357.0L/617760.0L*x + 10570201.0L/2882880.0L) - 4195157.0L/1441440.0L) + 14135041.0L/21621600.0L) + 2077.0L/44352.0L) + 7.0L/3300.0L;
        poly_val[3] = x*(x*(x*(x*((200569.0L/31680.0L)*x - 3530803.0L/221760.0L) + 93403.0L/7392.0L) - 1551821.0L/554400.0L) - 31957.0L/138600.0L) - 7.0L/528.0L;
        poly_val[4] = x*(x*(x*(x*(-9044677.0L/475200.0L*x + 56909.0L/1188.0L) - 6314093.0L/166320.0L) + 426122.0L/51975.0L) + 247081.0L/302400.0L) + 7.0L/108.0L;
        poly_val[5] = x*(x*(x*(x*((906869.0L/21600.0L)*x - 2130157.0L/20160.0L) + 503599.0L/6048.0L) - 2574109.0L/151200.0L) - 222581.0L/100800.0L) - 7.0L/24.0L;
        poly_val[6] = x*(x*(x*(x*(-505069.0L/7200.0L*x + 394819.0L/2240.0L) - 277219.0L/2016.0L) + 1344209.0L/50400.0L) + 90281.0L/33600.0L) + 7.0L/4.0L;
        poly_val[7] = pow(x, 2)*(x*(x*((121399.0L/1344.0L)*x - 3547527.0L/15680.0L) + 12323341.0L/70560.0L) - 3993487.0L/117600.0L) - 266681.0L/88200.0L;
        poly_val[8] = x*(x*(x*(x*(-121399.0L/1344.0L*x + 2650561.0L/11760.0L) - 174319.0L/1008.0L) + 350719.0L/9800.0L) - 90281.0L/33600.0L) + 7.0L/4.0L;
        poly_val[9] = x*(x*(x*(x*((505069.0L/7200.0L)*x - 703519.0L/4032.0L) + 1350319.0L/10080.0L) - 1501481.0L/50400.0L) + 222581.0L/100800.0L) - 7.0L/24.0L;
        poly_val[10] = x*(x*(x*(x*(-906869.0L/21600.0L*x + 1261139.0L/12096.0L) - 811073.0L/10080.0L) + 2819581.0L/151200.0L) - 247081.0L/302400.0L) + 7.0L/108.0L;
        poly_val[11] = x*(x*(x*(x*((9044677.0L/475200.0L)*x - 1497319.0L/31680.0L) + 813523.0L/22176.0L) - 14314981.0L/1663200.0L) + 31957.0L/138600.0L) - 7.0L/528.0L;
        poly_val[12] = x*(x*(x*(x*(-200569.0L/31680.0L*x + 39649.0L/2520.0L) - 226559.0L/18480.0L) + 200173.0L/69300.0L) - 2077.0L/44352.0L) + 7.0L/3300.0L;
        poly_val[13] = x*(x*(x*(x*((901357.0L/617760.0L)*x - 31384387.0L/8648640.0L) + 2451851.0L/864864.0L) - 1112533.0L/1663200.0L) + 20137.0L/3326400.0L) - 7.0L/30888.0L;
        poly_val[14] = x*(x*(x*(x*(-4502941.0L/21621600.0L*x + 2091853.0L/4036032.0L) - 12279031.0L/30270240.0L) + 1114733.0L/11642400.0L) - 59.0L/158400.0L) + 1.0L/84084.0L;
        poly_val[15] = pow(x, 2)*(x*(x*((200017.0L/14414400.0L)*x - 232417.0L/6726720.0L) + 39031.0L/1441440.0L) - 322417.0L/50450400.0L);
        break;
    }
}
void beta_n7_m4(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*((322727.0L/302702400.0L)*x - 414979.0L/86486400.0L) + 141853.0L/17297280.0L) - 6059.0L/960960.0L) + 11.0L/6048.0L) - 59.0L/6652800.0L) + 59.0L/950400.0L) + 1.0L/168168.0L) - 1.0L/24024.0L);
        poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(-13405813.0L/838252800.0L*x + 60333233.0L/838252800.0L) - 670268567.0L/5448643200.0L) + 3680359.0L/38918880.0L) - 42433073.0L/1556755200.0L) + 20137.0L/119750400.0L) - 20137.0L/19958400.0L) - 7.0L/61776.0L) + 7.0L/10296.0L);
        poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*((174279691.0L/1556755200.0L)*x - 1120513.0L/2223936.0L) + 44685269.0L/51891840.0L) - 515148581.0L/778377600.0L) + 296702557.0L/1556755200.0L) - 2077.0L/1330560.0L) + 2077.0L/266112.0L) + 7.0L/6600.0L) - 7.0L/1320.0L);
        poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(-28817.0L/59400.0L*x + 4841917.0L/2217600.0L) - 2256829.0L/604800.0L) + 19073623.0L/6652800.0L) - 609701.0L/739200.0L) + 31957.0L/3326400.0L) - 31957.0L/831600.0L) - 7.0L/1056.0L) + 7.0L/264.0L);
        poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*((3112349.0L/2138400.0L)*x - 56029813.0L/8553600.0L) + 60931183.0L/5443200.0L) - 36766399.0L/4276800.0L) + 14799451.0L/5987520.0L) - 247081.0L/5443200.0L) + 247081.0L/1814400.0L) + 7.0L/216.0L) - 7.0L/72.0L);
        poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*(-4979933.0L/1555200.0L*x + 156886007.0L/10886400.0L) - 8935543.0L/362880.0L) + 51445649.0L/2721600.0L) - 59327153.0L/10886400.0L) + 222581.0L/1209600.0L) - 222581.0L/604800.0L) - 7.0L/48.0L) + 7.0L/24.0L);
        poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*((6455647.0L/1209600.0L)*x - 7263173.0L/302400.0L) + 8272337.0L/201600.0L) - 3809647.0L/120960.0L) + 11059493.0L/1209600.0L) - 90281.0L/201600.0L) + 90281.0L/201600.0L) + 7.0L/8.0L) - 7.0L/8.0L);
        poly_val[7] = pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(-43576279.0L/6350400.0L*x + 11205641.0L/362880.0L) - 19141411.0L/362880.0L) + 73478603.0L/1814400.0L) - 21513043.0L/1814400.0L) + 54613.0L/90720.0L) - 266681.0L/176400.0L) + 1;
        poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*((43576279.0L/6350400.0L)*x - 392175587.0L/12700800.0L) + 223287331.0L/4233600.0L) - 36755869.0L/907200.0L) + 1353509.0L/113400.0L) - 90281.0L/201600.0L) - 90281.0L/201600.0L) + 7.0L/8.0L) + 7.0L/8.0L);
        poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(-6455647.0L/1209600.0L*x + 4149733.0L/172800.0L) - 24807889.0L/604800.0L) + 794597.0L/25200.0L) - 2251181.0L/241920.0L) + 222581.0L/1209600.0L) + 222581.0L/604800.0L) - 7.0L/48.0L) - 7.0L/24.0L);
        poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*((4979933.0L/1555200.0L)*x - 39212443.0L/2721600.0L) + 5358427.0L/217728.0L) - 103036921.0L/5443200.0L) + 60708181.0L/10886400.0L) - 247081.0L/5443200.0L) - 247081.0L/1814400.0L) + 7.0L/216.0L) + 7.0L/72.0L);
        poly_val[11] = x*(x*(x*(x*(x*(x*(x*(x*(-3112349.0L/2138400.0L*x + 56014751.0L/8553600.0L) - 223273759.0L/19958400.0L) + 14724943.0L/1710720.0L) - 13763713.0L/5443200.0L) + 31957.0L/3326400.0L) + 31957.0L/831600.0L) - 7.0L/1056.0L) - 7.0L/264.0L);
        poly_val[12] = x*(x*(x*(x*(x*(x*(x*(x*((28817.0L/59400.0L)*x - 968119.0L/443520.0L) + 4961851.0L/1330560.0L) - 9545759.0L/3326400.0L) + 932753.0L/1108800.0L) - 2077.0L/1330560.0L) - 2077.0L/266112.0L) + 7.0L/6600.0L) + 7.0L/1320.0L);
        poly_val[13] = x*(x*(x*(x*(x*(x*(x*(x*(-174279691.0L/1556755200.0L*x + 784158119.0L/1556755200.0L) - 669877073.0L/778377600.0L) + 257762143.0L/389188800.0L) - 23213117.0L/119750400.0L) + 20137.0L/119750400.0L) + 20137.0L/19958400.0L) - 7.0L/61776.0L) - 7.0L/10296.0L);
        poly_val[14] = x*(x*(x*(x*(x*(x*(x*(x*((13405813.0L/838252800.0L)*x - 2154253.0L/29937600.0L) + 2900003.0L/23587200.0L) - 73650743.0L/778377600.0L) + 1722493.0L/62270208.0L) - 59.0L/6652800.0L) - 59.0L/950400.0L) + 1.0L/168168.0L) + 1.0L/24024.0L);
        poly_val[15] = pow(x, 5)*(x*(x*(x*(-322727.0L/302702400.0L*x + 2904233.0L/605404800.0L) - 2005.0L/244608.0L) + 545581.0L/86486400.0L) - 159353.0L/86486400.0L);
        break;
    case 1:
        poly_val[0] = x*(x*(x*(x*(x*(x*(x*((322727.0L/33633600.0L)*x - 414979.0L/10810800.0L) + 141853.0L/2471040.0L) - 6059.0L/160160.0L) + 55.0L/6048.0L) - 59.0L/1663200.0L) + 59.0L/316800.0L) + 1.0L/84084.0L) - 1.0L/24024.0L;
        poly_val[1] = x*(x*(x*(x*(x*(x*(x*(-13405813.0L/93139200.0L*x + 60333233.0L/104781600.0L) - 670268567.0L/778377600.0L) + 3680359.0L/6486480.0L) - 42433073.0L/311351040.0L) + 20137.0L/29937600.0L) - 20137.0L/6652800.0L) - 7.0L/30888.0L) + 7.0L/10296.0L;
        poly_val[2] = x*(x*(x*(x*(x*(x*(x*((174279691.0L/172972800.0L)*x - 1120513.0L/277992.0L) + 44685269.0L/7413120.0L) - 515148581.0L/129729600.0L) + 296702557.0L/311351040.0L) - 2077.0L/332640.0L) + 2077.0L/88704.0L) + 7.0L/3300.0L) - 7.0L/1320.0L;
        poly_val[3] = x*(x*(x*(x*(x*(x*(x*(-28817.0L/6600.0L*x + 4841917.0L/277200.0L) - 2256829.0L/86400.0L) + 19073623.0L/1108800.0L) - 609701.0L/147840.0L) + 31957.0L/831600.0L) - 31957.0L/277200.0L) - 7.0L/528.0L) + 7.0L/264.0L;
        poly_val[4] = x*(x*(x*(x*(x*(x*(x*((3112349.0L/237600.0L)*x - 56029813.0L/1069200.0L) + 60931183.0L/777600.0L) - 36766399.0L/712800.0L) + 14799451.0L/1197504.0L) - 247081.0L/1360800.0L) + 247081.0L/604800.0L) + 7.0L/108.0L) - 7.0L/72.0L;
        poly_val[5] = x*(x*(x*(x*(x*(x*(x*(-4979933.0L/172800.0L*x + 156886007.0L/1360800.0L) - 8935543.0L/51840.0L) + 51445649.0L/453600.0L) - 59327153.0L/2177280.0L) + 222581.0L/302400.0L) - 222581.0L/201600.0L) - 7.0L/24.0L) + 7.0L/24.0L;
        poly_val[6] = x*(x*(x*(x*(x*(x*(x*((6455647.0L/134400.0L)*x - 7263173.0L/37800.0L) + 8272337.0L/28800.0L) - 3809647.0L/20160.0L) + 11059493.0L/241920.0L) - 90281.0L/50400.0L) + 90281.0L/67200.0L) + 7.0L/4.0L) - 7.0L/8.0L;
        poly_val[7] = x*(pow(x, 2)*(x*(x*(x*(x*(-43576279.0L/705600.0L*x + 11205641.0L/45360.0L) - 19141411.0L/51840.0L) + 73478603.0L/302400.0L) - 21513043.0L/362880.0L) + 54613.0L/22680.0L) - 266681.0L/88200.0L);
        poly_val[8] = x*(x*(x*(x*(x*(x*(x*((43576279.0L/705600.0L)*x - 392175587.0L/1587600.0L) + 223287331.0L/604800.0L) - 36755869.0L/151200.0L) + 1353509.0L/22680.0L) - 90281.0L/50400.0L) - 90281.0L/67200.0L) + 7.0L/4.0L) + 7.0L/8.0L;
        poly_val[9] = x*(x*(x*(x*(x*(x*(x*(-6455647.0L/134400.0L*x + 4149733.0L/21600.0L) - 24807889.0L/86400.0L) + 794597.0L/4200.0L) - 2251181.0L/48384.0L) + 222581.0L/302400.0L) + 222581.0L/201600.0L) - 7.0L/24.0L) - 7.0L/24.0L;
        poly_val[10] = x*(x*(x*(x*(x*(x*(x*((4979933.0L/172800.0L)*x - 39212443.0L/340200.0L) + 5358427.0L/31104.0L) - 103036921.0L/907200.0L) + 60708181.0L/2177280.0L) - 247081.0L/1360800.0L) - 247081.0L/604800.0L) + 7.0L/108.0L) + 7.0L/72.0L;
        poly_val[11] = x*(x*(x*(x*(x*(x*(x*(-3112349.0L/237600.0L*x + 56014751.0L/1069200.0L) - 223273759.0L/2851200.0L) + 14724943.0L/285120.0L) - 13763713.0L/1088640.0L) + 31957.0L/831600.0L) + 31957.0L/277200.0L) - 7.0L/528.0L) - 7.0L/264.0L;
        poly_val[12] = x*(x*(x*(x*(x*(x*(x*((28817.0L/6600.0L)*x - 968119.0L/55440.0L) + 4961851.0L/190080.0L) - 9545759.0L/554400.0L) + 932753.0L/221760.0L) - 2077.0L/332640.0L) - 2077.0L/88704.0L) + 7.0L/3300.0L) + 7.0L/1320.0L;
        poly_val[13] = x*(x*(x*(x*(x*(x*(x*(-174279691.0L/172972800.0L*x + 784158119.0L/194594400.0L) - 669877073.0L/111196800.0L) + 257762143.0L/64864800.0L) - 23213117.0L/23950080.0L) + 20137.0L/29937600.0L) + 20137.0L/6652800.0L) - 7.0L/30888.0L) - 7.0L/10296.0L;
        poly_val[14] = x*(x*(x*(x*(x*(x*(x*((13405813.0L/93139200.0L)*x - 2154253.0L/3742200.0L) + 2900003.0L/3369600.0L) - 73650743.0L/129729600.0L) + 8612465.0L/62270208.0L) - 59.0L/1663200.0L) - 59.0L/316800.0L) + 1.0L/84084.0L) + 1.0L/24024.0L;
        poly_val[15] = pow(x, 4)*(x*(x*(x*(-322727.0L/33633600.0L*x + 2904233.0L/75675600.0L) - 2005.0L/34944.0L) + 545581.0L/14414400.0L) - 159353.0L/17297280.0L);
        break;
    case 2:
        poly_val[0] = x*(x*(x*(x*(x*(x*((322727.0L/4204200.0L)*x - 414979.0L/1544400.0L) + 141853.0L/411840.0L) - 6059.0L/32032.0L) + 55.0L/1512.0L) - 59.0L/554400.0L) + 59.0L/158400.0L) + 1.0L/84084.0L;
        poly_val[1] = x*(x*(x*(x*(x*(x*(-13405813.0L/11642400.0L*x + 60333233.0L/14968800.0L) - 670268567.0L/129729600.0L) + 3680359.0L/1297296.0L) - 42433073.0L/77837760.0L) + 20137.0L/9979200.0L) - 20137.0L/3326400.0L) - 7.0L/30888.0L;
        poly_val[2] = x*(x*(x*(x*(x*(x*((174279691.0L/21621600.0L)*x - 7843591.0L/277992.0L) + 44685269.0L/1235520.0L) - 515148581.0L/25945920.0L) + 296702557.0L/77837760.0L) - 2077.0L/110880.0L) + 2077.0L/44352.0L) + 7.0L/3300.0L;
        poly_val[3] = x*(x*(x*(x*(x*(x*(-28817.0L/825.0L*x + 4841917.0L/39600.0L) - 2256829.0L/14400.0L) + 19073623.0L/221760.0L) - 609701.0L/36960.0L) + 31957.0L/277200.0L) - 31957.0L/138600.0L) - 7.0L/528.0L;
        poly_val[4] = x*(x*(x*(x*(x*(x*((3112349.0L/29700.0L)*x - 392208691.0L/1069200.0L) + 60931183.0L/129600.0L) - 36766399.0L/142560.0L) + 14799451.0L/299376.0L) - 247081.0L/453600.0L) + 247081.0L/302400.0L) + 7.0L/108.0L;
        poly_val[5] = x*(x*(x*(x*(x*(x*(-4979933.0L/21600.0L*x + 156886007.0L/194400.0L) - 8935543.0L/8640.0L) + 51445649.0L/90720.0L) - 59327153.0L/544320.0L) + 222581.0L/100800.0L) - 222581.0L/100800.0L) - 7.0L/24.0L;
        poly_val[6] = x*(x*(x*(x*(x*(x*((6455647.0L/16800.0L)*x - 7263173.0L/5400.0L) + 8272337.0L/4800.0L) - 3809647.0L/4032.0L) + 11059493.0L/60480.0L) - 90281.0L/16800.0L) + 90281.0L/33600.0L) + 7.0L/4.0L;
        poly_val[7] = pow(x, 2)*(x*(x*(x*(x*(-43576279.0L/88200.0L*x + 11205641.0L/6480.0L) - 19141411.0L/8640.0L) + 73478603.0L/60480.0L) - 21513043.0L/90720.0L) + 54613.0L/7560.0L) - 266681.0L/88200.0L;
        poly_val[8] = x*(x*(x*(x*(x*(x*((43576279.0L/88200.0L)*x - 392175587.0L/226800.0L) + 223287331.0L/100800.0L) - 36755869.0L/30240.0L) + 1353509.0L/5670.0L) - 90281.0L/16800.0L) - 90281.0L/33600.0L) + 7.0L/4.0L;
        poly_val[9] = x*(x*(x*(x*(x*(x*(-6455647.0L/16800.0L*x + 29048131.0L/21600.0L) - 24807889.0L/14400.0L) + 794597.0L/840.0L) - 2251181.0L/12096.0L) + 222581.0L/100800.0L) + 222581.0L/100800.0L) - 7.0L/24.0L;
        poly_val[10] = x*(x*(x*(x*(x*(x*((4979933.0L/21600.0L)*x - 39212443.0L/48600.0L) + 5358427.0L/5184.0L) - 103036921.0L/181440.0L) + 60708181.0L/544320.0L) - 247081.0L/453600.0L) - 247081.0L/302400.0L) + 7.0L/108.0L;
        poly_val[11] = x*(x*(x*(x*(x*(x*(-3112349.0L/29700.0L*x + 392103257.0L/1069200.0L) - 223273759.0L/475200.0L) + 14724943.0L/57024.0L) - 13763713.0L/272160.0L) + 31957.0L/277200.0L) + 31957.0L/138600.0L) - 7.0L/528.0L;
        poly_val[12] = x*(x*(x*(x*(x*(x*((28817.0L/825.0L)*x - 968119.0L/7920.0L) + 4961851.0L/31680.0L) - 9545759.0L/110880.0L) + 932753.0L/55440.0L) - 2077.0L/110880.0L) - 2077.0L/44352.0L) + 7.0L/3300.0L;
        poly_val[13] = x*(x*(x*(x*(x*(x*(-174279691.0L/21621600.0L*x + 784158119.0L/27799200.0L) - 669877073.0L/18532800.0L) + 257762143.0L/12972960.0L) - 23213117.0L/5987520.0L) + 20137.0L/9979200.0L) + 20137.0L/3326400.0L) - 7.0L/30888.0L;
        poly_val[14] = x*(x*(x*(x*(x*(x*((13405813.0L/11642400.0L)*x - 2154253.0L/534600.0L) + 2900003.0L/561600.0L) - 73650743.0L/25945920.0L) + 8612465.0L/15567552.0L) - 59.0L/554400.0L) - 59.0L/158400.0L) + 1.0L/84084.0L;
        poly_val[15] = pow(x, 3)*(x*(x*(x*(-322727.0L/4204200.0L*x + 2904233.0L/10810800.0L) - 2005.0L/5824.0L) + 545581.0L/2882880.0L) - 159353.0L/4324320.0L);
        break;
    }
}
