/**********************************************************************
*                                                                     *
*  Copyright 2015 the TurTLE team                                     *
*                                                                     *
*  This file is part of TurTLE.                                       *
*                                                                     *
*  TurTLE is free software: you can redistribute it and/or modify     *
*  it under the terms of the GNU General Public License as published  *
*  by the Free Software Foundation, either version 3 of the License,  *
*  or (at your option) any later version.                             *
*                                                                     *
*  TurTLE is distributed in the hope that it will be useful,          *
*  but WITHOUT ANY WARRANTY; without even the implied warranty of     *
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      *
*  GNU General Public License for more details.                       *
*                                                                     *
*  You should have received a copy of the GNU General Public License  *
*  along with TurTLE.  If not, see <http://www.gnu.org/licenses/>     *
*                                                                     *
* Contact: Cristian.Lalescu@ds.mpg.de                                 *
*                                                                     *
**********************************************************************/



#include "spline_n8.hpp"
#include <cmath>

void beta_n8_m0(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = 0;
        poly_val[1] = 0;
        poly_val[2] = 0;
        poly_val[3] = 0;
        poly_val[4] = 0;
        poly_val[5] = 0;
        poly_val[6] = 0;
        poly_val[7] = 0;
        poly_val[8] = -x + 1;
        poly_val[9] = x;
        poly_val[10] = 0;
        poly_val[11] = 0;
        poly_val[12] = 0;
        poly_val[13] = 0;
        poly_val[14] = 0;
        poly_val[15] = 0;
        poly_val[16] = 0;
        poly_val[17] = 0;
        break;
    case 1:
        poly_val[0] = 0;
        poly_val[1] = 0;
        poly_val[2] = 0;
        poly_val[3] = 0;
        poly_val[4] = 0;
        poly_val[5] = 0;
        poly_val[6] = 0;
        poly_val[7] = 0;
        poly_val[8] = -1;
        poly_val[9] = 1;
        poly_val[10] = 0;
        poly_val[11] = 0;
        poly_val[12] = 0;
        poly_val[13] = 0;
        poly_val[14] = 0;
        poly_val[15] = 0;
        poly_val[16] = 0;
        poly_val[17] = 0;
        break;
    case 2:
        poly_val[0] = 0;
        poly_val[1] = 0;
        poly_val[2] = 0;
        poly_val[3] = 0;
        poly_val[4] = 0;
        poly_val[5] = 0;
        poly_val[6] = 0;
        poly_val[7] = 0;
        poly_val[8] = 0;
        poly_val[9] = 0;
        poly_val[10] = 0;
        poly_val[11] = 0;
        poly_val[12] = 0;
        poly_val[13] = 0;
        poly_val[14] = 0;
        poly_val[15] = 0;
        poly_val[16] = 0;
        poly_val[17] = 0;
        break;
    }
}
void beta_n8_m1(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = x*(x*((1.0L/102960.0L)*x - 1.0L/51480.0L) + 1.0L/102960.0L);
        poly_val[1] = x*(x*(-11.0L/65520.0L*x + 83.0L/240240.0L) - 8.0L/45045.0L);
        poly_val[2] = x*(x*((62.0L/45045.0L)*x - 4.0L/1365.0L) + 2.0L/1287.0L);
        poly_val[3] = x*(x*(-46.0L/6435.0L*x + 34.0L/2145.0L) - 56.0L/6435.0L);
        poly_val[4] = x*(x*((343.0L/12870.0L)*x - 133.0L/2145.0L) + 7.0L/198.0L);
        poly_val[5] = x*(x*(-7.0L/90.0L*x + 21.0L/110.0L) - 56.0L/495.0L);
        poly_val[6] = x*(x*((98.0L/495.0L)*x - 28.0L/55.0L) + 14.0L/45.0L);
        poly_val[7] = x*(x*(-26.0L/45.0L*x + 22.0L/15.0L) - 8.0L/9.0L);
        poly_val[8] = pow(x, 2)*((10.0L/9.0L)*x - 19.0L/9.0L) + 1;
        poly_val[9] = x*(x*(-10.0L/9.0L*x + 11.0L/9.0L) + 8.0L/9.0L);
        poly_val[10] = x*(x*((26.0L/45.0L)*x - 4.0L/15.0L) - 14.0L/45.0L);
        poly_val[11] = x*(x*(-98.0L/495.0L*x + 14.0L/165.0L) + 56.0L/495.0L);
        poly_val[12] = x*(x*((7.0L/90.0L)*x - 7.0L/165.0L) - 7.0L/198.0L);
        poly_val[13] = x*(x*(-343.0L/12870.0L*x + 7.0L/390.0L) + 56.0L/6435.0L);
        poly_val[14] = x*(x*((46.0L/6435.0L)*x - 4.0L/715.0L) - 2.0L/1287.0L);
        poly_val[15] = x*(x*(-62.0L/45045.0L*x + 6.0L/5005.0L) + 8.0L/45045.0L);
        poly_val[16] = x*(x*((11.0L/65520.0L)*x - 19.0L/120120.0L) - 1.0L/102960.0L);
        poly_val[17] = pow(x, 2)*(-1.0L/102960.0L*x + 1.0L/102960.0L);
        break;
    case 1:
        poly_val[0] = x*((1.0L/34320.0L)*x - 1.0L/25740.0L) + 1.0L/102960.0L;
        poly_val[1] = x*(-11.0L/21840.0L*x + 83.0L/120120.0L) - 8.0L/45045.0L;
        poly_val[2] = x*((62.0L/15015.0L)*x - 8.0L/1365.0L) + 2.0L/1287.0L;
        poly_val[3] = x*(-46.0L/2145.0L*x + 68.0L/2145.0L) - 56.0L/6435.0L;
        poly_val[4] = x*((343.0L/4290.0L)*x - 266.0L/2145.0L) + 7.0L/198.0L;
        poly_val[5] = x*(-7.0L/30.0L*x + 21.0L/55.0L) - 56.0L/495.0L;
        poly_val[6] = x*((98.0L/165.0L)*x - 56.0L/55.0L) + 14.0L/45.0L;
        poly_val[7] = x*(-26.0L/15.0L*x + 44.0L/15.0L) - 8.0L/9.0L;
        poly_val[8] = x*((10.0L/3.0L)*x - 38.0L/9.0L);
        poly_val[9] = x*(-10.0L/3.0L*x + 22.0L/9.0L) + 8.0L/9.0L;
        poly_val[10] = x*((26.0L/15.0L)*x - 8.0L/15.0L) - 14.0L/45.0L;
        poly_val[11] = x*(-98.0L/165.0L*x + 28.0L/165.0L) + 56.0L/495.0L;
        poly_val[12] = x*((7.0L/30.0L)*x - 14.0L/165.0L) - 7.0L/198.0L;
        poly_val[13] = x*(-343.0L/4290.0L*x + 7.0L/195.0L) + 56.0L/6435.0L;
        poly_val[14] = x*((46.0L/2145.0L)*x - 8.0L/715.0L) - 2.0L/1287.0L;
        poly_val[15] = x*(-62.0L/15015.0L*x + 12.0L/5005.0L) + 8.0L/45045.0L;
        poly_val[16] = x*((11.0L/21840.0L)*x - 19.0L/60060.0L) - 1.0L/102960.0L;
        poly_val[17] = x*(-1.0L/34320.0L*x + 1.0L/51480.0L);
        break;
    case 2:
        poly_val[0] = (1.0L/17160.0L)*x - 1.0L/25740.0L;
        poly_val[1] = -11.0L/10920.0L*x + 83.0L/120120.0L;
        poly_val[2] = (124.0L/15015.0L)*x - 8.0L/1365.0L;
        poly_val[3] = -92.0L/2145.0L*x + 68.0L/2145.0L;
        poly_val[4] = (343.0L/2145.0L)*x - 266.0L/2145.0L;
        poly_val[5] = -7.0L/15.0L*x + 21.0L/55.0L;
        poly_val[6] = (196.0L/165.0L)*x - 56.0L/55.0L;
        poly_val[7] = -52.0L/15.0L*x + 44.0L/15.0L;
        poly_val[8] = (20.0L/3.0L)*x - 38.0L/9.0L;
        poly_val[9] = -20.0L/3.0L*x + 22.0L/9.0L;
        poly_val[10] = (52.0L/15.0L)*x - 8.0L/15.0L;
        poly_val[11] = -196.0L/165.0L*x + 28.0L/165.0L;
        poly_val[12] = (7.0L/15.0L)*x - 14.0L/165.0L;
        poly_val[13] = -343.0L/2145.0L*x + 7.0L/195.0L;
        poly_val[14] = (92.0L/2145.0L)*x - 8.0L/715.0L;
        poly_val[15] = -124.0L/15015.0L*x + 12.0L/5005.0L;
        poly_val[16] = (11.0L/10920.0L)*x - 19.0L/60060.0L;
        poly_val[17] = -1.0L/17160.0L*x + 1.0L/51480.0L;
        break;
    }
}
void beta_n8_m2(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = x*(x*(x*(x*(-23.0L/823680.0L*x + 61.0L/823680.0L) - 1.0L/18304.0L) - 1.0L/823680.0L) + 1.0L/102960.0L);
        poly_val[1] = x*(x*(x*(x*((3851.0L/8072064.0L)*x - 5143.0L/4036032.0L) + 12773.0L/13453440.0L) + 8.0L/315315.0L) - 8.0L/45045.0L);
        poly_val[2] = x*(x*(x*(x*(-3637.0L/945945.0L*x + 33.0L/3185.0L) - 821.0L/105105.0L) - 1.0L/3861.0L) + 2.0L/1287.0L);
        poly_val[3] = x*(x*(x*(x*((1877.0L/96525.0L)*x - 5116.0L/96525.0L) + 3911.0L/96525.0L) + 56.0L/32175.0L) - 56.0L/6435.0L);
        poly_val[4] = x*(x*(x*(x*(-17857.0L/257400.0L*x + 49399.0L/257400.0L) - 4263.0L/28600.0L) - 7.0L/792.0L) + 7.0L/198.0L);
        poly_val[5] = x*(x*(x*(x*((2219.0L/11880.0L)*x - 1043.0L/1980.0L) + 329.0L/792.0L) + 56.0L/1485.0L) - 56.0L/495.0L);
        poly_val[6] = x*(x*(x*(x*(-119.0L/297.0L*x + 343.0L/297.0L) - 1351.0L/1485.0L) - 7.0L/45.0L) + 14.0L/45.0L);
        poly_val[7] = x*(x*(x*(x*((31.0L/45.0L)*x - 88.0L/45.0L) + 19.0L/15.0L) + 8.0L/9.0L) - 8.0L/9.0L);
        poly_val[8] = pow(x, 2)*(x*(x*(-647051.0L/705600.0L*x + 568651.0L/235200.0L) - 686753.0L/705600.0L) - 1077749.0L/705600.0L) + 1;
        poly_val[9] = x*(x*(x*(x*((647051.0L/705600.0L)*x - 764651.0L/352800.0L) + 333451.0L/705600.0L) + 8.0L/9.0L) + 8.0L/9.0L);
        poly_val[10] = x*(x*(x*(x*(-31.0L/45.0L*x + 67.0L/45.0L) - 1.0L/3.0L) - 7.0L/45.0L) - 14.0L/45.0L);
        poly_val[11] = x*(x*(x*(x*((119.0L/297.0L)*x - 28.0L/33.0L) + 49.0L/165.0L) + 56.0L/1485.0L) + 56.0L/495.0L);
        poly_val[12] = x*(x*(x*(x*(-2219.0L/11880.0L*x + 4837.0L/11880.0L) - 2093.0L/11880.0L) - 7.0L/792.0L) - 7.0L/198.0L);
        poly_val[13] = x*(x*(x*(x*((17857.0L/257400.0L)*x - 1813.0L/11700.0L) + 2149.0L/28600.0L) + 56.0L/32175.0L) + 56.0L/6435.0L);
        poly_val[14] = x*(x*(x*(x*(-1877.0L/96525.0L*x + 1423.0L/32175.0L) - 739.0L/32175.0L) - 1.0L/3861.0L) - 2.0L/1287.0L);
        poly_val[15] = x*(x*(x*(x*((3637.0L/945945.0L)*x - 8384.0L/945945.0L) + 911.0L/189189.0L) + 8.0L/315315.0L) + 8.0L/45045.0L);
        poly_val[16] = x*(x*(x*(x*(-3851.0L/8072064.0L*x + 8969.0L/8072064.0L) - 8383.0L/13453440.0L) - 1.0L/823680.0L) - 1.0L/102960.0L);
        poly_val[17] = pow(x, 3)*(x*((23.0L/823680.0L)*x - 3.0L/45760.0L) + 31.0L/823680.0L);
        break;
    case 1:
        poly_val[0] = x*(x*(x*(-23.0L/164736.0L*x + 61.0L/205920.0L) - 3.0L/18304.0L) - 1.0L/411840.0L) + 1.0L/102960.0L;
        poly_val[1] = x*(x*(x*((19255.0L/8072064.0L)*x - 5143.0L/1009008.0L) + 12773.0L/4484480.0L) + 16.0L/315315.0L) - 8.0L/45045.0L;
        poly_val[2] = x*(x*(x*(-3637.0L/189189.0L*x + 132.0L/3185.0L) - 821.0L/35035.0L) - 2.0L/3861.0L) + 2.0L/1287.0L;
        poly_val[3] = x*(x*(x*((1877.0L/19305.0L)*x - 20464.0L/96525.0L) + 3911.0L/32175.0L) + 112.0L/32175.0L) - 56.0L/6435.0L;
        poly_val[4] = x*(x*(x*(-17857.0L/51480.0L*x + 49399.0L/64350.0L) - 12789.0L/28600.0L) - 7.0L/396.0L) + 7.0L/198.0L;
        poly_val[5] = x*(x*(x*((2219.0L/2376.0L)*x - 1043.0L/495.0L) + 329.0L/264.0L) + 112.0L/1485.0L) - 56.0L/495.0L;
        poly_val[6] = x*(x*(x*(-595.0L/297.0L*x + 1372.0L/297.0L) - 1351.0L/495.0L) - 14.0L/45.0L) + 14.0L/45.0L;
        poly_val[7] = x*(x*(x*((31.0L/9.0L)*x - 352.0L/45.0L) + 19.0L/5.0L) + 16.0L/9.0L) - 8.0L/9.0L;
        poly_val[8] = x*(x*(x*(-647051.0L/141120.0L*x + 568651.0L/58800.0L) - 686753.0L/235200.0L) - 1077749.0L/352800.0L);
        poly_val[9] = x*(x*(x*((647051.0L/141120.0L)*x - 764651.0L/88200.0L) + 333451.0L/235200.0L) + 16.0L/9.0L) + 8.0L/9.0L;
        poly_val[10] = x*(x*(x*(-31.0L/9.0L*x + 268.0L/45.0L) - 1) - 14.0L/45.0L) - 14.0L/45.0L;
        poly_val[11] = x*(x*(x*((595.0L/297.0L)*x - 112.0L/33.0L) + 49.0L/55.0L) + 112.0L/1485.0L) + 56.0L/495.0L;
        poly_val[12] = x*(x*(x*(-2219.0L/2376.0L*x + 4837.0L/2970.0L) - 2093.0L/3960.0L) - 7.0L/396.0L) - 7.0L/198.0L;
        poly_val[13] = x*(x*(x*((17857.0L/51480.0L)*x - 1813.0L/2925.0L) + 6447.0L/28600.0L) + 112.0L/32175.0L) + 56.0L/6435.0L;
        poly_val[14] = x*(x*(x*(-1877.0L/19305.0L*x + 5692.0L/32175.0L) - 739.0L/10725.0L) - 2.0L/3861.0L) - 2.0L/1287.0L;
        poly_val[15] = x*(x*(x*((3637.0L/189189.0L)*x - 33536.0L/945945.0L) + 911.0L/63063.0L) + 16.0L/315315.0L) + 8.0L/45045.0L;
        poly_val[16] = x*(x*(x*(-19255.0L/8072064.0L*x + 8969.0L/2018016.0L) - 8383.0L/4484480.0L) - 1.0L/411840.0L) - 1.0L/102960.0L;
        poly_val[17] = pow(x, 2)*(x*((23.0L/164736.0L)*x - 3.0L/11440.0L) + 31.0L/274560.0L);
        break;
    case 2:
        poly_val[0] = x*(x*(-23.0L/41184.0L*x + 61.0L/68640.0L) - 3.0L/9152.0L) - 1.0L/411840.0L;
        poly_val[1] = x*(x*((19255.0L/2018016.0L)*x - 5143.0L/336336.0L) + 12773.0L/2242240.0L) + 16.0L/315315.0L;
        poly_val[2] = x*(x*(-14548.0L/189189.0L*x + 396.0L/3185.0L) - 1642.0L/35035.0L) - 2.0L/3861.0L;
        poly_val[3] = x*(x*((7508.0L/19305.0L)*x - 20464.0L/32175.0L) + 7822.0L/32175.0L) + 112.0L/32175.0L;
        poly_val[4] = x*(x*(-17857.0L/12870.0L*x + 49399.0L/21450.0L) - 12789.0L/14300.0L) - 7.0L/396.0L;
        poly_val[5] = x*(x*((2219.0L/594.0L)*x - 1043.0L/165.0L) + 329.0L/132.0L) + 112.0L/1485.0L;
        poly_val[6] = x*(x*(-2380.0L/297.0L*x + 1372.0L/99.0L) - 2702.0L/495.0L) - 14.0L/45.0L;
        poly_val[7] = x*(x*((124.0L/9.0L)*x - 352.0L/15.0L) + 38.0L/5.0L) + 16.0L/9.0L;
        poly_val[8] = x*(x*(-647051.0L/35280.0L*x + 568651.0L/19600.0L) - 686753.0L/117600.0L) - 1077749.0L/352800.0L;
        poly_val[9] = x*(x*((647051.0L/35280.0L)*x - 764651.0L/29400.0L) + 333451.0L/117600.0L) + 16.0L/9.0L;
        poly_val[10] = x*(x*(-124.0L/9.0L*x + 268.0L/15.0L) - 2) - 14.0L/45.0L;
        poly_val[11] = x*(x*((2380.0L/297.0L)*x - 112.0L/11.0L) + 98.0L/55.0L) + 112.0L/1485.0L;
        poly_val[12] = x*(x*(-2219.0L/594.0L*x + 4837.0L/990.0L) - 2093.0L/1980.0L) - 7.0L/396.0L;
        poly_val[13] = x*(x*((17857.0L/12870.0L)*x - 1813.0L/975.0L) + 6447.0L/14300.0L) + 112.0L/32175.0L;
        poly_val[14] = x*(x*(-7508.0L/19305.0L*x + 5692.0L/10725.0L) - 1478.0L/10725.0L) - 2.0L/3861.0L;
        poly_val[15] = x*(x*((14548.0L/189189.0L)*x - 33536.0L/315315.0L) + 1822.0L/63063.0L) + 16.0L/315315.0L;
        poly_val[16] = x*(x*(-19255.0L/2018016.0L*x + 8969.0L/672672.0L) - 8383.0L/2242240.0L) - 1.0L/411840.0L;
        poly_val[17] = x*(x*((23.0L/41184.0L)*x - 9.0L/11440.0L) + 31.0L/137280.0L);
        break;
    }
}
void beta_n8_m3(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = x*(x*(x*(x*(x*(x*((1409119.0L/18162144000.0L)*x - 225133.0L/825552000.0L) + 982819.0L/3027024000.0L) - 280097.0L/2270268000.0L) - 266681.0L/18162144000.0L) - 1.0L/823680.0L) + 1.0L/102960.0L);
        poly_val[1] = x*(x*(x*(x*(x*(x*(-3423751.0L/2594592000.0L*x + 84281297.0L/18162144000.0L) - 1239279.0L/224224000.0L) + 584159.0L/279417600.0L) + 21701.0L/81081000.0L) + 8.0L/315315.0L) - 8.0L/45045.0L);
        poly_val[2] = x*(x*(x*(x*(x*(x*((1142023.0L/108108000.0L)*x - 2637197.0L/70945875.0L) + 16757869.0L/378378000.0L) - 1574527.0L/94594500.0L) - 1058149.0L/454053600.0L) - 1.0L/3861.0L) + 2.0L/1287.0L);
        poly_val[3] = x*(x*(x*(x*(x*(x*(-8002307.0L/151351200.0L*x + 84540767.0L/454053600.0L) - 33583789.0L/151351200.0L) + 961571.0L/11642400.0L) + 41981.0L/3243240.0L) + 56.0L/32175.0L) - 56.0L/6435.0L);
        poly_val[4] = x*(x*(x*(x*(x*(x*((6870101.0L/37065600.0L)*x - 8475431.0L/12972960.0L) + 1246801.0L/1601600.0L) - 18501503.0L/64864800.0L) - 1033649.0L/19958400.0L) - 7.0L/792.0L) + 7.0L/198.0L);
        poly_val[5] = x*(x*(x*(x*(x*(x*(-16071287.0L/33264000.0L*x + 24300857.0L/14256000.0L) - 22488359.0L/11088000.0L) + 24013303.0L/33264000.0L) + 999349.0L/6237000.0L) + 56.0L/1485.0L) - 56.0L/495.0L);
        poly_val[6] = x*(x*(x*(x*(x*(x*((383939.0L/396000.0L)*x - 2667076.0L/779625.0L) + 5606353.0L/1386000.0L) - 25547.0L/18900.0L) - 901349.0L/2268000.0L) - 7.0L/45.0L) + 14.0L/45.0L);
        poly_val[7] = x*(x*(x*(x*(x*(x*(-24268063.0L/15876000.0L*x + 85470809.0L/15876000.0L) - 1232929.0L/196000.0L) + 31221523.0L/15876000.0L) + 372149.0L/793800.0L) + 8.0L/9.0L) - 8.0L/9.0L);
        poly_val[8] = pow(x, 2)*(pow(x, 2)*(x*(x*((434251.0L/226800.0L)*x - 14219287.0L/2116800.0L) + 4099663.0L/529200.0L) - 7673891.0L/3175200.0L) - 1077749.0L/705600.0L) + 1;
        poly_val[9] = x*(x*(x*(x*(x*(x*(-434251.0L/226800.0L*x + 8491067.0L/1270080.0L) - 8098063.0L/1058400.0L) + 16330063.0L/6350400.0L) - 372149.0L/793800.0L) + 8.0L/9.0L) + 8.0L/9.0L);
        poly_val[10] = x*(x*(x*(x*(x*(x*((24268063.0L/15876000.0L)*x - 2637676.0L/496125.0L) + 596739.0L/98000.0L) - 4429349.0L/1984500.0L) + 901349.0L/2268000.0L) - 7.0L/45.0L) - 14.0L/45.0L);
        poly_val[11] = x*(x*(x*(x*(x*(x*(-383939.0L/396000.0L*x + 7633697.0L/2268000.0L) - 32262353.0L/8316000.0L) + 2482583.0L/1663200.0L) - 999349.0L/6237000.0L) + 56.0L/1485.0L) + 56.0L/495.0L);
        poly_val[12] = x*(x*(x*(x*(x*(x*((16071287.0L/33264000.0L)*x - 5978251.0L/3564000.0L) + 32375053.0L/16632000.0L) - 6319283.0L/8316000.0L) + 1033649.0L/19958400.0L) - 7.0L/792.0L) - 7.0L/198.0L);
        poly_val[13] = x*(x*(x*(x*(x*(x*(-6870101.0L/37065600.0L*x + 167126329.0L/259459200.0L) - 2405369.0L/3203200.0L) + 76448243.0L/259459200.0L) - 41981.0L/3243240.0L) + 56.0L/32175.0L) + 56.0L/6435.0L);
        poly_val[14] = x*(x*(x*(x*(x*(x*((8002307.0L/151351200.0L)*x - 521923.0L/2837835.0L) + 5425117.0L/25225200.0L) - 41011.0L/485100.0L) + 1058149.0L/454053600.0L) - 1.0L/3861.0L) - 2.0L/1287.0L);
        poly_val[15] = x*(x*(x*(x*(x*(x*(-1142023.0L/108108000.0L*x + 83487077.0L/2270268000.0L) - 10870837.0L/252252000.0L) + 12826589.0L/756756000.0L) - 21701.0L/81081000.0L) + 8.0L/315315.0L) + 8.0L/45045.0L);
        poly_val[16] = x*(x*(x*(x*(x*(x*((3423751.0L/2594592000.0L)*x - 41741251.0L/9081072000.0L) + 604847.0L/112112000.0L) - 7411.0L/3492720.0L) + 266681.0L/18162144000.0L) - 1.0L/823680.0L) - 1.0L/102960.0L);
        poly_val[17] = pow(x, 4)*(x*(x*(-1409119.0L/18162144000.0L*x + 1636969.0L/6054048000.0L) - 1923619.0L/6054048000.0L) + 206279.0L/1651104000.0L);
        break;
    case 1:
        poly_val[0] = x*(x*(x*(x*(x*((1409119.0L/2594592000.0L)*x - 225133.0L/137592000.0L) + 982819.0L/605404800.0L) - 280097.0L/567567000.0L) - 266681.0L/6054048000.0L) - 1.0L/411840.0L) + 1.0L/102960.0L;
        poly_val[1] = x*(x*(x*(x*(x*(-3423751.0L/370656000.0L*x + 84281297.0L/3027024000.0L) - 1239279.0L/44844800.0L) + 584159.0L/69854400.0L) + 21701.0L/27027000.0L) + 16.0L/315315.0L) - 8.0L/45045.0L;
        poly_val[2] = x*(x*(x*(x*(x*((1142023.0L/15444000.0L)*x - 5274394.0L/23648625.0L) + 16757869.0L/75675600.0L) - 1574527.0L/23648625.0L) - 1058149.0L/151351200.0L) - 2.0L/3861.0L) + 2.0L/1287.0L;
        poly_val[3] = x*(x*(x*(x*(x*(-8002307.0L/21621600.0L*x + 84540767.0L/75675600.0L) - 33583789.0L/30270240.0L) + 961571.0L/2910600.0L) + 41981.0L/1081080.0L) + 112.0L/32175.0L) - 56.0L/6435.0L;
        poly_val[4] = x*(x*(x*(x*(x*((48090707.0L/37065600.0L)*x - 8475431.0L/2162160.0L) + 1246801.0L/320320.0L) - 18501503.0L/16216200.0L) - 1033649.0L/6652800.0L) - 7.0L/396.0L) + 7.0L/198.0L;
        poly_val[5] = x*(x*(x*(x*(x*(-16071287.0L/4752000.0L*x + 24300857.0L/2376000.0L) - 22488359.0L/2217600.0L) + 24013303.0L/8316000.0L) + 999349.0L/2079000.0L) + 112.0L/1485.0L) - 56.0L/495.0L;
        poly_val[6] = x*(x*(x*(x*(x*((2687573.0L/396000.0L)*x - 5334152.0L/259875.0L) + 5606353.0L/277200.0L) - 25547.0L/4725.0L) - 901349.0L/756000.0L) - 14.0L/45.0L) + 14.0L/45.0L;
        poly_val[7] = x*(x*(x*(x*(x*(-24268063.0L/2268000.0L*x + 85470809.0L/2646000.0L) - 1232929.0L/39200.0L) + 31221523.0L/3969000.0L) + 372149.0L/264600.0L) + 16.0L/9.0L) - 8.0L/9.0L;
        poly_val[8] = x*(pow(x, 2)*(x*(x*((434251.0L/32400.0L)*x - 14219287.0L/352800.0L) + 4099663.0L/105840.0L) - 7673891.0L/793800.0L) - 1077749.0L/352800.0L);
        poly_val[9] = x*(x*(x*(x*(x*(-434251.0L/32400.0L*x + 8491067.0L/211680.0L) - 8098063.0L/211680.0L) + 16330063.0L/1587600.0L) - 372149.0L/264600.0L) + 16.0L/9.0L) + 8.0L/9.0L;
        poly_val[10] = x*(x*(x*(x*(x*((24268063.0L/2268000.0L)*x - 5275352.0L/165375.0L) + 596739.0L/19600.0L) - 4429349.0L/496125.0L) + 901349.0L/756000.0L) - 14.0L/45.0L) - 14.0L/45.0L;
        poly_val[11] = x*(x*(x*(x*(x*(-2687573.0L/396000.0L*x + 7633697.0L/378000.0L) - 32262353.0L/1663200.0L) + 2482583.0L/415800.0L) - 999349.0L/2079000.0L) + 112.0L/1485.0L) + 56.0L/495.0L;
        poly_val[12] = x*(x*(x*(x*(x*((16071287.0L/4752000.0L)*x - 5978251.0L/594000.0L) + 32375053.0L/3326400.0L) - 6319283.0L/2079000.0L) + 1033649.0L/6652800.0L) - 7.0L/396.0L) - 7.0L/198.0L;
        poly_val[13] = x*(x*(x*(x*(x*(-48090707.0L/37065600.0L*x + 167126329.0L/43243200.0L) - 2405369.0L/640640.0L) + 76448243.0L/64864800.0L) - 41981.0L/1081080.0L) + 112.0L/32175.0L) + 56.0L/6435.0L;
        poly_val[14] = x*(x*(x*(x*(x*((8002307.0L/21621600.0L)*x - 1043846.0L/945945.0L) + 5425117.0L/5045040.0L) - 41011.0L/121275.0L) + 1058149.0L/151351200.0L) - 2.0L/3861.0L) - 2.0L/1287.0L;
        poly_val[15] = x*(x*(x*(x*(x*(-1142023.0L/15444000.0L*x + 83487077.0L/378378000.0L) - 10870837.0L/50450400.0L) + 12826589.0L/189189000.0L) - 21701.0L/27027000.0L) + 16.0L/315315.0L) + 8.0L/45045.0L;
        poly_val[16] = x*(x*(x*(x*(x*((3423751.0L/370656000.0L)*x - 41741251.0L/1513512000.0L) + 604847.0L/22422400.0L) - 7411.0L/873180.0L) + 266681.0L/6054048000.0L) - 1.0L/411840.0L) - 1.0L/102960.0L;
        poly_val[17] = pow(x, 3)*(x*(x*(-1409119.0L/2594592000.0L*x + 1636969.0L/1009008000.0L) - 1923619.0L/1210809600.0L) + 206279.0L/412776000.0L);
        break;
    case 2:
        poly_val[0] = x*(x*(x*(x*((1409119.0L/432432000.0L)*x - 225133.0L/27518400.0L) + 982819.0L/151351200.0L) - 280097.0L/189189000.0L) - 266681.0L/3027024000.0L) - 1.0L/411840.0L;
        poly_val[1] = x*(x*(x*(x*(-3423751.0L/61776000.0L*x + 84281297.0L/605404800.0L) - 1239279.0L/11211200.0L) + 584159.0L/23284800.0L) + 21701.0L/13513500.0L) + 16.0L/315315.0L;
        poly_val[2] = x*(x*(x*(x*((1142023.0L/2574000.0L)*x - 5274394.0L/4729725.0L) + 16757869.0L/18918900.0L) - 1574527.0L/7882875.0L) - 1058149.0L/75675600.0L) - 2.0L/3861.0L;
        poly_val[3] = x*(x*(x*(x*(-8002307.0L/3603600.0L*x + 84540767.0L/15135120.0L) - 33583789.0L/7567560.0L) + 961571.0L/970200.0L) + 41981.0L/540540.0L) + 112.0L/32175.0L;
        poly_val[4] = x*(x*(x*(x*((48090707.0L/6177600.0L)*x - 8475431.0L/432432.0L) + 1246801.0L/80080.0L) - 18501503.0L/5405400.0L) - 1033649.0L/3326400.0L) - 7.0L/396.0L;
        poly_val[5] = x*(x*(x*(x*(-16071287.0L/792000.0L*x + 24300857.0L/475200.0L) - 22488359.0L/554400.0L) + 24013303.0L/2772000.0L) + 999349.0L/1039500.0L) + 112.0L/1485.0L;
        poly_val[6] = x*(x*(x*(x*((2687573.0L/66000.0L)*x - 5334152.0L/51975.0L) + 5606353.0L/69300.0L) - 25547.0L/1575.0L) - 901349.0L/378000.0L) - 14.0L/45.0L;
        poly_val[7] = x*(x*(x*(x*(-24268063.0L/378000.0L*x + 85470809.0L/529200.0L) - 1232929.0L/9800.0L) + 31221523.0L/1323000.0L) + 372149.0L/132300.0L) + 16.0L/9.0L;
        poly_val[8] = pow(x, 2)*(x*(x*((434251.0L/5400.0L)*x - 14219287.0L/70560.0L) + 4099663.0L/26460.0L) - 7673891.0L/264600.0L) - 1077749.0L/352800.0L;
        poly_val[9] = x*(x*(x*(x*(-434251.0L/5400.0L*x + 8491067.0L/42336.0L) - 8098063.0L/52920.0L) + 16330063.0L/529200.0L) - 372149.0L/132300.0L) + 16.0L/9.0L;
        poly_val[10] = x*(x*(x*(x*((24268063.0L/378000.0L)*x - 5275352.0L/33075.0L) + 596739.0L/4900.0L) - 4429349.0L/165375.0L) + 901349.0L/378000.0L) - 14.0L/45.0L;
        poly_val[11] = x*(x*(x*(x*(-2687573.0L/66000.0L*x + 7633697.0L/75600.0L) - 32262353.0L/415800.0L) + 2482583.0L/138600.0L) - 999349.0L/1039500.0L) + 112.0L/1485.0L;
        poly_val[12] = x*(x*(x*(x*((16071287.0L/792000.0L)*x - 5978251.0L/118800.0L) + 32375053.0L/831600.0L) - 6319283.0L/693000.0L) + 1033649.0L/3326400.0L) - 7.0L/396.0L;
        poly_val[13] = x*(x*(x*(x*(-48090707.0L/6177600.0L*x + 167126329.0L/8648640.0L) - 2405369.0L/160160.0L) + 76448243.0L/21621600.0L) - 41981.0L/540540.0L) + 112.0L/32175.0L;
        poly_val[14] = x*(x*(x*(x*((8002307.0L/3603600.0L)*x - 1043846.0L/189189.0L) + 5425117.0L/1261260.0L) - 41011.0L/40425.0L) + 1058149.0L/75675600.0L) - 2.0L/3861.0L;
        poly_val[15] = x*(x*(x*(x*(-1142023.0L/2574000.0L*x + 83487077.0L/75675600.0L) - 10870837.0L/12612600.0L) + 12826589.0L/63063000.0L) - 21701.0L/13513500.0L) + 16.0L/315315.0L;
        poly_val[16] = x*(x*(x*(x*((3423751.0L/61776000.0L)*x - 41741251.0L/302702400.0L) + 604847.0L/5605600.0L) - 7411.0L/291060.0L) + 266681.0L/3027024000.0L) - 1.0L/411840.0L;
        poly_val[17] = pow(x, 2)*(x*(x*(-1409119.0L/432432000.0L*x + 1636969.0L/201801600.0L) - 1923619.0L/302702400.0L) + 206279.0L/137592000.0L);
        break;
    }
}
void beta_n8_m4(const int deriv, const double x, double *__restrict__ poly_val) {
    switch(deriv)
    {
    case 0:
        poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(-1101377.0L/4402944000.0L*x + 14870423.0L/13208832000.0L) - 159755.0L/83026944.0L) + 1953779.0L/1320883200.0L) - 952949.0L/2235340800.0L) + 266681.0L/145297152000.0L) - 266681.0L/18162144000.0L) - 1.0L/823680.0L) + 1.0L/102960.0L);
        poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*((617882417.0L/145297152000.0L)*x - 4729333.0L/247104000.0L) + 43207609.0L/1320883200.0L) - 913297027.0L/36324288000.0L) + 38966747.0L/5381376000.0L) - 21701.0L/567567000.0L) + 21701.0L/81081000.0L) + 8.0L/315315.0L) - 8.0L/45045.0L);
        poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(-463422059.0L/13621608000.0L*x + 189610079.0L/1238328000.0L) - 891181997.0L/3405402000.0L) + 273948221.0L/1362160800.0L) - 788229307.0L/13621608000.0L) + 1058149.0L/2724321600.0L) - 1058149.0L/454053600.0L) - 1.0L/3861.0L) + 2.0L/1287.0L);
        poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*((42130577.0L/247665600.0L)*x - 18961871.0L/24766560.0L) + 7617133.0L/5821200.0L) - 1369431659.0L/1362160800.0L) + 787169833.0L/2724321600.0L) - 41981.0L/16216200.0L) + 41981.0L/3243240.0L) + 56.0L/32175.0L) - 56.0L/6435.0L);
        poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(-617941241.0L/1037836800.0L*x + 34336129.0L/12812800.0L) - 216051389.0L/47174400.0L) + 1825249697.0L/518918400.0L) - 349286711.0L/345945600.0L) + 1033649.0L/79833600.0L) - 1033649.0L/19958400.0L) - 7.0L/792.0L) + 7.0L/198.0L);
        poly_val[5] = x*(x*(x*(x*(x*(x*(x*(x*((264845533.0L/171072000.0L)*x - 149002003.0L/21384000.0L) + 1425869503.0L/119750400.0L) - 177679.0L/19440.0L) + 627784987.0L/239500800.0L) - 999349.0L/18711000.0L) + 999349.0L/6237000.0L) + 56.0L/1485.0L) - 56.0L/495.0L);
        poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(-42136729.0L/13608000.0L*x + 189644803.0L/13608000.0L) - 5940337.0L/249480.0L) + 1367199013.0L/74844000.0L) - 786324923.0L/149688000.0L) + 901349.0L/4536000.0L) - 901349.0L/2268000.0L) - 7.0L/45.0L) + 14.0L/45.0L);
        poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*((154508033.0L/31752000.0L)*x - 115893523.0L/5292000.0L) + 2651402.0L/70875.0L) - 18221291.0L/635040.0L) + 88029853.0L/10584000.0L) - 372149.0L/793800.0L) + 372149.0L/793800.0L) + 8.0L/9.0L) - 8.0L/9.0L);
        poly_val[8] = pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(-618047281.0L/101606400.0L*x + 5297753.0L/193536.0L) - 2375132021.0L/50803200.0L) + 1822225277.0L/50803200.0L) - 355812263.0L/33868800.0L) + 63566689.0L/101606400.0L) - 1077749.0L/705600.0L) + 1;
        poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*((618047281.0L/101606400.0L)*x - 231758767.0L/8467200.0L) + 2374701779.0L/50803200.0L) - 303866687.0L/8467200.0L) + 119588617.0L/11289600.0L) - 372149.0L/793800.0L) - 372149.0L/793800.0L) + 8.0L/9.0L) + 8.0L/9.0L);
        poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(-154508033.0L/31752000.0L*x + 231737053.0L/10584000.0L) - 59361409.0L/1587600.0L) + 91229503.0L/3175200.0L) - 5997349.0L/705600.0L) + 901349.0L/4536000.0L) + 901349.0L/2268000.0L) - 7.0L/45.0L) - 14.0L/45.0L);
        poly_val[11] = x*(x*(x*(x*(x*(x*(x*(x*((42136729.0L/13608000.0L)*x - 94792879.0L/6804000.0L) + 178080211.0L/7484400.0L) - 124488893.0L/6804000.0L) + 808490713.0L/149688000.0L) - 999349.0L/18711000.0L) - 999349.0L/6237000.0L) + 56.0L/1485.0L) + 56.0L/495.0L);
        poly_val[12] = x*(x*(x*(x*(x*(x*(x*(x*(-264845533.0L/171072000.0L*x + 1191593773.0L/171072000.0L) - 23984633.0L/2016000.0L) + 156569593.0L/17107200.0L) - 3224840863.0L/1197504000.0L) + 1033649.0L/79833600.0L) + 1033649.0L/19958400.0L) - 7.0L/792.0L) - 7.0L/198.0L);
        poly_val[13] = x*(x*(x*(x*(x*(x*(x*(x*((617941241.0L/1037836800.0L)*x - 351041.0L/131040.0L) + 2374601821.0L/518918400.0L) - 456767273.0L/129729600.0L) + 27500531.0L/26611200.0L) - 41981.0L/16216200.0L) - 41981.0L/3243240.0L) + 56.0L/32175.0L) + 56.0L/6435.0L);
        poly_val[14] = x*(x*(x*(x*(x*(x*(x*(x*(-42130577.0L/247665600.0L*x + 189556483.0L/247665600.0L) - 7951072.0L/6081075.0L) + 1370477429.0L/1362160800.0L) - 803027411.0L/2724321600.0L) + 1058149.0L/2724321600.0L) + 1058149.0L/454053600.0L) - 1.0L/3861.0L) - 2.0L/1287.0L);
        poly_val[15] = x*(x*(x*(x*(x*(x*(x*(x*((463422059.0L/13621608000.0L)*x - 148934833.0L/972972000.0L) + 2698663.0L/10319400.0L) - 274116233.0L/1362160800.0L) + 160398913.0L/2724321600.0L) - 21701.0L/567567000.0L) - 21701.0L/81081000.0L) + 8.0L/315315.0L) + 8.0L/45045.0L);
        poly_val[16] = x*(x*(x*(x*(x*(x*(x*(x*(-617882417.0L/145297152000.0L*x + 926697983.0L/48432384000.0L) - 36537089.0L/1117670400.0L) + 166138879.0L/6604416000.0L) - 356085943.0L/48432384000.0L) + 266681.0L/145297152000.0L) + 266681.0L/18162144000.0L) - 1.0L/823680.0L) - 1.0L/102960.0L);
        poly_val[17] = pow(x, 5)*(x*(x*(x*((1101377.0L/4402944000.0L)*x - 3716689.0L/3302208000.0L) + 46568317.0L/24216192000.0L) - 1194499.0L/807206400.0L) + 62788793.0L/145297152000.0L);
        break;
    case 1:
        poly_val[0] = x*(x*(x*(x*(x*(x*(x*(-1101377.0L/489216000.0L*x + 14870423.0L/1651104000.0L) - 159755.0L/11860992.0L) + 1953779.0L/220147200.0L) - 952949.0L/447068160.0L) + 266681.0L/36324288000.0L) - 266681.0L/6054048000.0L) - 1.0L/411840.0L) + 1.0L/102960.0L;
        poly_val[1] = x*(x*(x*(x*(x*(x*(x*((617882417.0L/16144128000.0L)*x - 4729333.0L/30888000.0L) + 43207609.0L/188697600.0L) - 913297027.0L/6054048000.0L) + 38966747.0L/1076275200.0L) - 21701.0L/141891750.0L) + 21701.0L/27027000.0L) + 16.0L/315315.0L) - 8.0L/45045.0L;
        poly_val[2] = x*(x*(x*(x*(x*(x*(x*(-463422059.0L/1513512000.0L*x + 189610079.0L/154791000.0L) - 891181997.0L/486486000.0L) + 273948221.0L/227026800.0L) - 788229307.0L/2724321600.0L) + 1058149.0L/681080400.0L) - 1058149.0L/151351200.0L) - 2.0L/3861.0L) + 2.0L/1287.0L;
        poly_val[3] = x*(x*(x*(x*(x*(x*(x*((42130577.0L/27518400.0L)*x - 18961871.0L/3095820.0L) + 7617133.0L/831600.0L) - 1369431659.0L/227026800.0L) + 787169833.0L/544864320.0L) - 41981.0L/4054050.0L) + 41981.0L/1081080.0L) + 112.0L/32175.0L) - 56.0L/6435.0L;
        poly_val[4] = x*(x*(x*(x*(x*(x*(x*(-617941241.0L/115315200.0L*x + 34336129.0L/1601600.0L) - 216051389.0L/6739200.0L) + 1825249697.0L/86486400.0L) - 349286711.0L/69189120.0L) + 1033649.0L/19958400.0L) - 1033649.0L/6652800.0L) - 7.0L/396.0L) + 7.0L/198.0L;
        poly_val[5] = x*(x*(x*(x*(x*(x*(x*((264845533.0L/19008000.0L)*x - 149002003.0L/2673000.0L) + 1425869503.0L/17107200.0L) - 177679.0L/3240.0L) + 627784987.0L/47900160.0L) - 999349.0L/4677750.0L) + 999349.0L/2079000.0L) + 112.0L/1485.0L) - 56.0L/495.0L;
        poly_val[6] = x*(x*(x*(x*(x*(x*(x*(-42136729.0L/1512000.0L*x + 189644803.0L/1701000.0L) - 5940337.0L/35640.0L) + 1367199013.0L/12474000.0L) - 786324923.0L/29937600.0L) + 901349.0L/1134000.0L) - 901349.0L/756000.0L) - 14.0L/45.0L) + 14.0L/45.0L;
        poly_val[7] = x*(x*(x*(x*(x*(x*(x*((154508033.0L/3528000.0L)*x - 115893523.0L/661500.0L) + 2651402.0L/10125.0L) - 18221291.0L/105840.0L) + 88029853.0L/2116800.0L) - 372149.0L/198450.0L) + 372149.0L/264600.0L) + 16.0L/9.0L) - 8.0L/9.0L;
        poly_val[8] = x*(pow(x, 2)*(x*(x*(x*(x*(-618047281.0L/11289600.0L*x + 5297753.0L/24192.0L) - 2375132021.0L/7257600.0L) + 1822225277.0L/8467200.0L) - 355812263.0L/6773760.0L) + 63566689.0L/25401600.0L) - 1077749.0L/352800.0L);
        poly_val[9] = x*(x*(x*(x*(x*(x*(x*((618047281.0L/11289600.0L)*x - 231758767.0L/1058400.0L) + 2374701779.0L/7257600.0L) - 303866687.0L/1411200.0L) + 119588617.0L/2257920.0L) - 372149.0L/198450.0L) - 372149.0L/264600.0L) + 16.0L/9.0L) + 8.0L/9.0L;
        poly_val[10] = x*(x*(x*(x*(x*(x*(x*(-154508033.0L/3528000.0L*x + 231737053.0L/1323000.0L) - 59361409.0L/226800.0L) + 91229503.0L/529200.0L) - 5997349.0L/141120.0L) + 901349.0L/1134000.0L) + 901349.0L/756000.0L) - 14.0L/45.0L) - 14.0L/45.0L;
        poly_val[11] = x*(x*(x*(x*(x*(x*(x*((42136729.0L/1512000.0L)*x - 94792879.0L/850500.0L) + 178080211.0L/1069200.0L) - 124488893.0L/1134000.0L) + 808490713.0L/29937600.0L) - 999349.0L/4677750.0L) - 999349.0L/2079000.0L) + 112.0L/1485.0L) + 56.0L/495.0L;
        poly_val[12] = x*(x*(x*(x*(x*(x*(x*(-264845533.0L/19008000.0L*x + 1191593773.0L/21384000.0L) - 23984633.0L/288000.0L) + 156569593.0L/2851200.0L) - 3224840863.0L/239500800.0L) + 1033649.0L/19958400.0L) + 1033649.0L/6652800.0L) - 7.0L/396.0L) - 7.0L/198.0L;
        poly_val[13] = x*(x*(x*(x*(x*(x*(x*((617941241.0L/115315200.0L)*x - 351041.0L/16380.0L) + 2374601821.0L/74131200.0L) - 456767273.0L/21621600.0L) + 27500531.0L/5322240.0L) - 41981.0L/4054050.0L) - 41981.0L/1081080.0L) + 112.0L/32175.0L) + 56.0L/6435.0L;
        poly_val[14] = x*(x*(x*(x*(x*(x*(x*(-42130577.0L/27518400.0L*x + 189556483.0L/30958200.0L) - 7951072.0L/868725.0L) + 1370477429.0L/227026800.0L) - 803027411.0L/544864320.0L) + 1058149.0L/681080400.0L) + 1058149.0L/151351200.0L) - 2.0L/3861.0L) - 2.0L/1287.0L;
        poly_val[15] = x*(x*(x*(x*(x*(x*(x*((463422059.0L/1513512000.0L)*x - 148934833.0L/121621500.0L) + 2698663.0L/1474200.0L) - 274116233.0L/227026800.0L) + 160398913.0L/544864320.0L) - 21701.0L/141891750.0L) - 21701.0L/27027000.0L) + 16.0L/315315.0L) + 8.0L/45045.0L;
        poly_val[16] = x*(x*(x*(x*(x*(x*(x*(-617882417.0L/16144128000.0L*x + 926697983.0L/6054048000.0L) - 36537089.0L/159667200.0L) + 166138879.0L/1100736000.0L) - 356085943.0L/9686476800.0L) + 266681.0L/36324288000.0L) + 266681.0L/6054048000.0L) - 1.0L/411840.0L) - 1.0L/102960.0L;
        poly_val[17] = pow(x, 4)*(x*(x*(x*((1101377.0L/489216000.0L)*x - 3716689.0L/412776000.0L) + 46568317.0L/3459456000.0L) - 1194499.0L/134534400.0L) + 62788793.0L/29059430400.0L);
        break;
    case 2:
        poly_val[0] = x*(x*(x*(x*(x*(x*(-1101377.0L/61152000.0L*x + 14870423.0L/235872000.0L) - 159755.0L/1976832.0L) + 1953779.0L/44029440.0L) - 952949.0L/111767040.0L) + 266681.0L/12108096000.0L) - 266681.0L/3027024000.0L) - 1.0L/411840.0L;
        poly_val[1] = x*(x*(x*(x*(x*(x*((617882417.0L/2018016000.0L)*x - 33105331.0L/30888000.0L) + 43207609.0L/31449600.0L) - 913297027.0L/1210809600.0L) + 38966747.0L/269068800.0L) - 21701.0L/47297250.0L) + 21701.0L/13513500.0L) + 16.0L/315315.0L;
        poly_val[2] = x*(x*(x*(x*(x*(x*(-463422059.0L/189189000.0L*x + 189610079.0L/22113000.0L) - 891181997.0L/81081000.0L) + 273948221.0L/45405360.0L) - 788229307.0L/681080400.0L) + 1058149.0L/227026800.0L) - 1058149.0L/75675600.0L) - 2.0L/3861.0L;
        poly_val[3] = x*(x*(x*(x*(x*(x*((42130577.0L/3439800.0L)*x - 18961871.0L/442260.0L) + 7617133.0L/138600.0L) - 1369431659.0L/45405360.0L) + 787169833.0L/136216080.0L) - 41981.0L/1351350.0L) + 41981.0L/540540.0L) + 112.0L/32175.0L;
        poly_val[4] = x*(x*(x*(x*(x*(x*(-617941241.0L/14414400.0L*x + 34336129.0L/228800.0L) - 216051389.0L/1123200.0L) + 1825249697.0L/17297280.0L) - 349286711.0L/17297280.0L) + 1033649.0L/6652800.0L) - 1033649.0L/3326400.0L) - 7.0L/396.0L;
        poly_val[5] = x*(x*(x*(x*(x*(x*((264845533.0L/2376000.0L)*x - 1043014021.0L/2673000.0L) + 1425869503.0L/2851200.0L) - 177679.0L/648.0L) + 627784987.0L/11975040.0L) - 999349.0L/1559250.0L) + 999349.0L/1039500.0L) + 112.0L/1485.0L;
        poly_val[6] = x*(x*(x*(x*(x*(x*(-42136729.0L/189000.0L*x + 189644803.0L/243000.0L) - 5940337.0L/5940.0L) + 1367199013.0L/2494800.0L) - 786324923.0L/7484400.0L) + 901349.0L/378000.0L) - 901349.0L/378000.0L) - 14.0L/45.0L;
        poly_val[7] = x*(x*(x*(x*(x*(x*((154508033.0L/441000.0L)*x - 115893523.0L/94500.0L) + 5302804.0L/3375.0L) - 18221291.0L/21168.0L) + 88029853.0L/529200.0L) - 372149.0L/66150.0L) + 372149.0L/132300.0L) + 16.0L/9.0L;
        poly_val[8] = pow(x, 2)*(x*(x*(x*(x*(-618047281.0L/1411200.0L*x + 5297753.0L/3456.0L) - 2375132021.0L/1209600.0L) + 1822225277.0L/1693440.0L) - 355812263.0L/1693440.0L) + 63566689.0L/8467200.0L) - 1077749.0L/352800.0L;
        poly_val[9] = x*(x*(x*(x*(x*(x*((618047281.0L/1411200.0L)*x - 231758767.0L/151200.0L) + 2374701779.0L/1209600.0L) - 303866687.0L/282240.0L) + 119588617.0L/564480.0L) - 372149.0L/66150.0L) - 372149.0L/132300.0L) + 16.0L/9.0L;
        poly_val[10] = x*(x*(x*(x*(x*(x*(-154508033.0L/441000.0L*x + 231737053.0L/189000.0L) - 59361409.0L/37800.0L) + 91229503.0L/105840.0L) - 5997349.0L/35280.0L) + 901349.0L/378000.0L) + 901349.0L/378000.0L) - 14.0L/45.0L;
        poly_val[11] = x*(x*(x*(x*(x*(x*((42136729.0L/189000.0L)*x - 94792879.0L/121500.0L) + 178080211.0L/178200.0L) - 124488893.0L/226800.0L) + 808490713.0L/7484400.0L) - 999349.0L/1559250.0L) - 999349.0L/1039500.0L) + 112.0L/1485.0L;
        poly_val[12] = x*(x*(x*(x*(x*(x*(-264845533.0L/2376000.0L*x + 8341156411.0L/21384000.0L) - 23984633.0L/48000.0L) + 156569593.0L/570240.0L) - 3224840863.0L/59875200.0L) + 1033649.0L/6652800.0L) + 1033649.0L/3326400.0L) - 7.0L/396.0L;
        poly_val[13] = x*(x*(x*(x*(x*(x*((617941241.0L/14414400.0L)*x - 351041.0L/2340.0L) + 2374601821.0L/12355200.0L) - 456767273.0L/4324320.0L) + 27500531.0L/1330560.0L) - 41981.0L/1351350.0L) - 41981.0L/540540.0L) + 112.0L/32175.0L;
        poly_val[14] = x*(x*(x*(x*(x*(x*(-42130577.0L/3439800.0L*x + 189556483.0L/4422600.0L) - 15902144.0L/289575.0L) + 1370477429.0L/45405360.0L) - 803027411.0L/136216080.0L) + 1058149.0L/227026800.0L) + 1058149.0L/75675600.0L) - 2.0L/3861.0L;
        poly_val[15] = x*(x*(x*(x*(x*(x*((463422059.0L/189189000.0L)*x - 148934833.0L/17374500.0L) + 2698663.0L/245700.0L) - 274116233.0L/45405360.0L) + 160398913.0L/136216080.0L) - 21701.0L/47297250.0L) - 21701.0L/13513500.0L) + 16.0L/315315.0L;
        poly_val[16] = x*(x*(x*(x*(x*(x*(-617882417.0L/2018016000.0L*x + 926697983.0L/864864000.0L) - 36537089.0L/26611200.0L) + 166138879.0L/220147200.0L) - 356085943.0L/2421619200.0L) + 266681.0L/12108096000.0L) + 266681.0L/3027024000.0L) - 1.0L/411840.0L;
        poly_val[17] = pow(x, 3)*(x*(x*(x*((1101377.0L/61152000.0L)*x - 3716689.0L/58968000.0L) + 46568317.0L/576576000.0L) - 1194499.0L/26906880.0L) + 62788793.0L/7264857600.0L);
        break;
    }
}
