import os
import sys
import getpass
import numpy as np
import h5py

import TurTLE
import TurTLE.PP
import TurTLE.DNS

username = getpass.getuser()
homefolder = os.path.expanduser('~')
cpp_location = None

import pathlib
cpp_location = pathlib.Path(__file__).parent.resolve()


class acc_test(TurTLE.PP):
    def __init__(
            self,
            **kwargs):
        TurTLE.PP.__init__(self, **kwargs)
        return None
    def write_src(
            self):
        self.version_message = (
                '/***********************************************************************\n' +
                '* this code automatically generated by TurTLE\n' +
                '* version {0}\n'.format(TurTLE.__version__) +
                '***********************************************************************/\n\n\n')
        self.include_list = [
                '"full_code/main_code.hpp"',
                '<cmath>']
        self.main = """
            int main(int argc, char *argv[])
            {{
                bool fpe = (
                    (getenv("BFPS_FPE_OFF") == nullptr) ||
                    (getenv("BFPS_FPE_OFF") != std::string("TRUE")));
                return main_code< {0} >(argc, argv, fpe);
            }}
            """.format(self.dns_type + '<{0}>'.format(self.C_field_dtype))
        self.includes = '\n'.join(
                ['#include ' + hh
                 for hh in self.include_list])
        self.name = 'acceleration_check'
        self.dns_type = 'acceleration_check'
        self.definitions = ''
        self.definitions += open(
            os.path.join(
                cpp_location, 'acceleration_check.hpp'), 'r').read()
        self.definitions += open(
            os.path.join(
                cpp_location, 'acceleration_check.cpp'), 'r').read()
        with open(self.name + '.cpp', 'w') as outfile:
            outfile.write(self.version_message + '\n\n')
            outfile.write(self.includes + '\n\n')
            outfile.write(self.definitions + '\n\n')
            outfile.write(self.main + '\n')
        return None
    def add_parser_arguments(
            self,
            parser):
        subparsers = parser.add_subparsers(
                dest = 'DNS_class',
                help = 'type of simulation to run')
        subparsers.required = True
        parser_ac = subparsers.add_parser(
                'acceleration_check')
        self.simulation_parser_arguments(parser_ac)
        self.job_parser_arguments(parser_ac)
        self.parameters_to_parser_arguments(parser_ac)
        self.parameters_to_parser_arguments(
            parser_ac,
            parameters = self.extra_postprocessing_parameters(
                'acceleration_check'))
        return None
    def extra_postprocessing_parameters(
            self,
            dns_type = None):
        assert(dns_type == 'acceleration_check')
        pars = {}
        return pars

def plot_scalars(
        s0, s1,
        fname = 'tst.pdf'):
    import matplotlib.pyplot as plt
    f = plt.figure(figsize = (9, 9))
    a = f.add_subplot(331)
    a.set_axis_off()
    a.imshow(s0[0])
    a = f.add_subplot(332)
    a.set_axis_off()
    a.imshow(s1[0])
    a = f.add_subplot(333)
    a.set_axis_off()
    a.imshow(s1[0] - s0[0])
    a = f.add_subplot(334)
    a.set_axis_off()
    a.imshow(s0[:, 0])
    a = f.add_subplot(335)
    a.set_axis_off()
    a.imshow(s1[:, 0])
    a = f.add_subplot(336)
    a.set_axis_off()
    a.imshow(s1[:, 0] - s0[:, 0])
    a = f.add_subplot(337)
    a.set_axis_off()
    a.imshow(s0[:, :, 0])
    a = f.add_subplot(338)
    a.set_axis_off()
    a.imshow(s1[:, :, 0])
    a = f.add_subplot(339)
    a.set_axis_off()
    a.imshow(s1[:, :, 0] - s0[:, :, 0])
    print("error is ", np.max(np.abs(s1 - s0)))
    f.tight_layout()
    f.savefig(fname)
    plt.close(f)
    return None

def main():
    if not os.path.exists('acceleration_check_data.h5'):
        cc = TurTLE.DNS()
        cc.launch(['NSVE', '--np', '2', '--simname', 'acceleration_check_data'])
    bla = acc_test()
    bla.launch(
            ['acceleration_check',
             '--np', '1',
             '--ntpp', '1',
             '--simname', 'acceleration_check_data']
            + sys.argv[1:])

    # corresponding C++ code needs to be turned on for this to work
    ######
    #dfile = h5py.File('field_test.h5', 'r')
    #pnse = dfile['nse/real/0'][()]
    #pnsve = dfile['nsve/real/0'][()]
    #plot_scalars(pnsve, pnse, 'tst_real.pdf')
    #pnse = dfile['nse/complex/0'][()]
    #pnsve = dfile['nsve/complex/0'][()]
    #plot_scalars(np.abs(pnsve), np.abs(pnse), 'tst_complex.pdf')
    #dfile.close()
    return None

if __name__ == '__main__':
    main()
