import os
import sys
import getpass
import numpy as np
import h5py

import TurTLE
import TurTLE.PP
import TurTLE.DNS
import TurTLE.TEST

username = getpass.getuser()
homefolder = os.path.expanduser('~')
cpp_location = None

import pathlib
cpp_location = pathlib.Path(__file__).parent.resolve()


class sanity_check(TurTLE.TEST):
    def __init__(
            self,
            check_type = 'analytic',
            **kwargs):
        TurTLE.PP.__init__(self, **kwargs)
        self.check_type = check_type
        return None
    def write_src(
            self):
        self.version_message = (
                '/***********************************************************************\n' +
                '* this code automatically generated by TurTLE\n' +
                '* version {0}\n'.format(TurTLE.__version__) +
                '***********************************************************************/\n\n\n')
        self.include_list = [
                '"full_code/main_code.hpp"',
                '<cmath>']
        self.main = """
            int main(int argc, char *argv[])
            {{
                bool fpe = (
                    (getenv("BFPS_FPE_OFF") == nullptr) ||
                    (getenv("BFPS_FPE_OFF") != std::string("TRUE")));
                return main_code< {0} >(argc, argv, fpe);
            }}
            """.format(self.dns_type + '<{0}>'.format(self.C_field_dtype))
        self.includes = '\n'.join(
                ['#include ' + hh
                 for hh in self.include_list])
        self.dns_type = 'fluid_solver_check'
        if self.check_type == 'general':
            self.name = 'fluid_solver_check'
        elif self.check_type == 'analytic':
            self.name = 'fluid_solver_check_analytic'
        self.definitions = ''
        self.definitions += open(
            os.path.join(
                cpp_location, 'fluid_solver_check.hpp'), 'r').read()
        self.definitions += open(
            os.path.join(
                cpp_location, self.name + '.cpp'), 'r').read()
        with open(self.name + '.cpp', 'w') as outfile:
            outfile.write(self.version_message + '\n\n')
            outfile.write(self.includes + '\n\n')
            outfile.write(self.definitions + '\n\n')
            outfile.write(self.main + '\n')
        return None
    def add_parser_arguments(
            self,
            parser):
        subparsers = parser.add_subparsers(
                dest = 'TEST_class',
                help = 'type of simulation to run')
        subparsers.required = True
        parser_ac = subparsers.add_parser(
                'fluid_solver_check')
        self.simulation_parser_arguments(parser_ac)
        self.job_parser_arguments(parser_ac)
        self.parameters_to_parser_arguments(parser_ac)
        self.parameters_to_parser_arguments(
            parser_ac,
            parameters = self.extra_postprocessing_parameters(
                'fluid_solver_check'))
        return None
    def extra_postprocessing_parameters(
            self,
            dns_type = None):
        assert(dns_type == 'fluid_solver_check')
        pars = {}
        return pars

import matplotlib.pyplot as plt

def main():
    bla = sanity_check(check_type = 'analytic')
    bla.launch(
            ['fluid_solver_check',
             '--np', '1',
             '--ntpp', '1',
             '--simname', 'fluid_solver_onestep_analytic_check']
            + sys.argv[1:])
    bla = sanity_check(check_type = 'general')
    bla.launch(
            ['fluid_solver_check',
             '--np', '1',
             '--ntpp', '1',
             '--simname', 'fluid_solver_onestep_general_check']
            + sys.argv[1:])
    return None

if __name__ == '__main__':
    main()
