/**********************************************************************
*                                                                     *
*  Copyright 2015 the TurTLE team                                     *
*                                                                     *
*  This file is part of TurTLE.                                       *
*                                                                     *
*  TurTLE is free software: you can redistribute it and/or modify     *
*  it under the terms of the GNU General Public License as published  *
*  by the Free Software Foundation, either version 3 of the License,  *
*  or (at your option) any later version.                             *
*                                                                     *
*  TurTLE is distributed in the hope that it will be useful,          *
*  but WITHOUT ANY WARRANTY; without even the implied warranty of     *
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      *
*  GNU General Public License for more details.                       *
*                                                                     *
*  You should have received a copy of the GNU General Public License  *
*  along with TurTLE.  If not, see <http://www.gnu.org/licenses/>     *
*                                                                     *
* Contact: Cristian.Lalescu@ds.mpg.de                                 *
*                                                                     *
**********************************************************************/



#include "spline_n5.hpp"
#include <cmath>
void beta_n5_m0(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = 0;
poly_val[1] = 0;
poly_val[2] = 0;
poly_val[3] = 0;
poly_val[4] = 0;
poly_val[5] = -x + 1;
poly_val[6] = x;
poly_val[7] = 0;
poly_val[8] = 0;
poly_val[9] = 0;
poly_val[10] = 0;
poly_val[11] = 0;
break;
case 1:
poly_val[0] = 0;
poly_val[1] = 0;
poly_val[2] = 0;
poly_val[3] = 0;
poly_val[4] = 0;
poly_val[5] = -1;
poly_val[6] = 1;
poly_val[7] = 0;
poly_val[8] = 0;
poly_val[9] = 0;
poly_val[10] = 0;
poly_val[11] = 0;
break;
case 2:
poly_val[0] = 0;
poly_val[1] = 0;
poly_val[2] = 0;
poly_val[3] = 0;
poly_val[4] = 0;
poly_val[5] = 0;
poly_val[6] = 0;
poly_val[7] = 0;
poly_val[8] = 0;
poly_val[9] = 0;
poly_val[10] = 0;
poly_val[11] = 0;
break;
}
}
void beta_n5_m1(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(-1.0L/1260.0L*x + 1.0L/630.0L) - 1.0L/1260.0L);
poly_val[1] = x*(x*((23.0L/2520.0L)*x - 2.0L/105.0L) + 5.0L/504.0L);
poly_val[2] = x*(x*(-25.0L/504.0L*x + 55.0L/504.0L) - 5.0L/84.0L);
poly_val[3] = x*(x*((5.0L/28.0L)*x - 5.0L/12.0L) + 5.0L/21.0L);
poly_val[4] = x*(x*(-25.0L/42.0L*x + 10.0L/7.0L) - 5.0L/6.0L);
poly_val[5] = pow(x, 2)*((7.0L/6.0L)*x - 13.0L/6.0L) + 1;
poly_val[6] = x*(x*(-7.0L/6.0L*x + 4.0L/3.0L) + 5.0L/6.0L);
poly_val[7] = x*(x*((25.0L/42.0L)*x - 5.0L/14.0L) - 5.0L/21.0L);
poly_val[8] = x*(x*(-5.0L/28.0L*x + 5.0L/42.0L) + 5.0L/84.0L);
poly_val[9] = x*(x*((25.0L/504.0L)*x - 5.0L/126.0L) - 5.0L/504.0L);
poly_val[10] = x*(x*(-23.0L/2520.0L*x + 1.0L/120.0L) + 1.0L/1260.0L);
poly_val[11] = pow(x, 2)*((1.0L/1260.0L)*x - 1.0L/1260.0L);
break;
case 1:
poly_val[0] = x*(-1.0L/420.0L*x + 1.0L/315.0L) - 1.0L/1260.0L;
poly_val[1] = x*((23.0L/840.0L)*x - 4.0L/105.0L) + 5.0L/504.0L;
poly_val[2] = x*(-25.0L/168.0L*x + 55.0L/252.0L) - 5.0L/84.0L;
poly_val[3] = x*((15.0L/28.0L)*x - 5.0L/6.0L) + 5.0L/21.0L;
poly_val[4] = x*(-25.0L/14.0L*x + 20.0L/7.0L) - 5.0L/6.0L;
poly_val[5] = x*((7.0L/2.0L)*x - 13.0L/3.0L);
poly_val[6] = x*(-7.0L/2.0L*x + 8.0L/3.0L) + 5.0L/6.0L;
poly_val[7] = x*((25.0L/14.0L)*x - 5.0L/7.0L) - 5.0L/21.0L;
poly_val[8] = x*(-15.0L/28.0L*x + 5.0L/21.0L) + 5.0L/84.0L;
poly_val[9] = x*((25.0L/168.0L)*x - 5.0L/63.0L) - 5.0L/504.0L;
poly_val[10] = x*(-23.0L/840.0L*x + 1.0L/60.0L) + 1.0L/1260.0L;
poly_val[11] = x*((1.0L/420.0L)*x - 1.0L/630.0L);
break;
case 2:
poly_val[0] = -1.0L/210.0L*x + 1.0L/315.0L;
poly_val[1] = (23.0L/420.0L)*x - 4.0L/105.0L;
poly_val[2] = -25.0L/84.0L*x + 55.0L/252.0L;
poly_val[3] = (15.0L/14.0L)*x - 5.0L/6.0L;
poly_val[4] = -25.0L/7.0L*x + 20.0L/7.0L;
poly_val[5] = 7*x - 13.0L/3.0L;
poly_val[6] = -7*x + 8.0L/3.0L;
poly_val[7] = (25.0L/7.0L)*x - 5.0L/7.0L;
poly_val[8] = -15.0L/14.0L*x + 5.0L/21.0L;
poly_val[9] = (25.0L/84.0L)*x - 5.0L/63.0L;
poly_val[10] = -23.0L/420.0L*x + 1.0L/60.0L;
poly_val[11] = (1.0L/210.0L)*x - 1.0L/630.0L;
break;
}
}
void beta_n5_m2(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*((1.0L/450.0L)*x - 37.0L/6300.0L) + 3.0L/700.0L) + 1.0L/6300.0L) - 1.0L/1260.0L);
poly_val[1] = x*(x*(x*(x*(-1247.0L/50400.0L*x + 3329.0L/50400.0L) - 39.0L/800.0L) - 5.0L/2016.0L) + 5.0L/504.0L);
poly_val[2] = x*(x*(x*(x*((85.0L/672.0L)*x - 115.0L/336.0L) + 515.0L/2016.0L) + 5.0L/252.0L) - 5.0L/84.0L);
poly_val[3] = x*(x*(x*(x*(-25.0L/63.0L*x + 275.0L/252.0L) - 205.0L/252.0L) - 5.0L/42.0L) + 5.0L/21.0L);
poly_val[4] = x*(x*(x*(x*((5.0L/6.0L)*x - 95.0L/42.0L) + 10.0L/7.0L) + 5.0L/6.0L) - 5.0L/6.0L);
poly_val[5] = pow(x, 2)*(x*(x*(-4331.0L/3600.0L*x + 3731.0L/1200.0L) - 577.0L/400.0L) - 5269.0L/3600.0L) + 1;
poly_val[6] = x*(x*(x*(x*((4331.0L/3600.0L)*x - 5231.0L/1800.0L) + 3731.0L/3600.0L) + 5.0L/6.0L) + 5.0L/6.0L);
poly_val[7] = x*(x*(x*(x*(-5.0L/6.0L*x + 40.0L/21.0L) - 5.0L/7.0L) - 5.0L/42.0L) - 5.0L/21.0L);
poly_val[8] = x*(x*(x*(x*((25.0L/63.0L)*x - 25.0L/28.0L) + 5.0L/12.0L) + 5.0L/252.0L) + 5.0L/84.0L);
poly_val[9] = x*(x*(x*(x*(-85.0L/672.0L*x + 65.0L/224.0L) - 305.0L/2016.0L) - 5.0L/2016.0L) - 5.0L/504.0L);
poly_val[10] = x*(x*(x*(x*((1247.0L/50400.0L)*x - 1453.0L/25200.0L) + 179.0L/5600.0L) + 1.0L/6300.0L) + 1.0L/1260.0L);
poly_val[11] = pow(x, 3)*(x*(-1.0L/450.0L*x + 11.0L/2100.0L) - 19.0L/6300.0L);
break;
case 1:
poly_val[0] = x*(x*(x*((1.0L/90.0L)*x - 37.0L/1575.0L) + 9.0L/700.0L) + 1.0L/3150.0L) - 1.0L/1260.0L;
poly_val[1] = x*(x*(x*(-1247.0L/10080.0L*x + 3329.0L/12600.0L) - 117.0L/800.0L) - 5.0L/1008.0L) + 5.0L/504.0L;
poly_val[2] = x*(x*(x*((425.0L/672.0L)*x - 115.0L/84.0L) + 515.0L/672.0L) + 5.0L/126.0L) - 5.0L/84.0L;
poly_val[3] = x*(x*(x*(-125.0L/63.0L*x + 275.0L/63.0L) - 205.0L/84.0L) - 5.0L/21.0L) + 5.0L/21.0L;
poly_val[4] = x*(x*(x*((25.0L/6.0L)*x - 190.0L/21.0L) + 30.0L/7.0L) + 5.0L/3.0L) - 5.0L/6.0L;
poly_val[5] = x*(x*(x*(-4331.0L/720.0L*x + 3731.0L/300.0L) - 1731.0L/400.0L) - 5269.0L/1800.0L);
poly_val[6] = x*(x*(x*((4331.0L/720.0L)*x - 5231.0L/450.0L) + 3731.0L/1200.0L) + 5.0L/3.0L) + 5.0L/6.0L;
poly_val[7] = x*(x*(x*(-25.0L/6.0L*x + 160.0L/21.0L) - 15.0L/7.0L) - 5.0L/21.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*((125.0L/63.0L)*x - 25.0L/7.0L) + 5.0L/4.0L) + 5.0L/126.0L) + 5.0L/84.0L;
poly_val[9] = x*(x*(x*(-425.0L/672.0L*x + 65.0L/56.0L) - 305.0L/672.0L) - 5.0L/1008.0L) - 5.0L/504.0L;
poly_val[10] = x*(x*(x*((1247.0L/10080.0L)*x - 1453.0L/6300.0L) + 537.0L/5600.0L) + 1.0L/3150.0L) + 1.0L/1260.0L;
poly_val[11] = pow(x, 2)*(x*(-1.0L/90.0L*x + 11.0L/525.0L) - 19.0L/2100.0L);
break;
case 2:
poly_val[0] = x*(x*((2.0L/45.0L)*x - 37.0L/525.0L) + 9.0L/350.0L) + 1.0L/3150.0L;
poly_val[1] = x*(x*(-1247.0L/2520.0L*x + 3329.0L/4200.0L) - 117.0L/400.0L) - 5.0L/1008.0L;
poly_val[2] = x*(x*((425.0L/168.0L)*x - 115.0L/28.0L) + 515.0L/336.0L) + 5.0L/126.0L;
poly_val[3] = x*(x*(-500.0L/63.0L*x + 275.0L/21.0L) - 205.0L/42.0L) - 5.0L/21.0L;
poly_val[4] = x*(x*((50.0L/3.0L)*x - 190.0L/7.0L) + 60.0L/7.0L) + 5.0L/3.0L;
poly_val[5] = x*(x*(-4331.0L/180.0L*x + 3731.0L/100.0L) - 1731.0L/200.0L) - 5269.0L/1800.0L;
poly_val[6] = x*(x*((4331.0L/180.0L)*x - 5231.0L/150.0L) + 3731.0L/600.0L) + 5.0L/3.0L;
poly_val[7] = x*(x*(-50.0L/3.0L*x + 160.0L/7.0L) - 30.0L/7.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*((500.0L/63.0L)*x - 75.0L/7.0L) + 5.0L/2.0L) + 5.0L/126.0L;
poly_val[9] = x*(x*(-425.0L/168.0L*x + 195.0L/56.0L) - 305.0L/336.0L) - 5.0L/1008.0L;
poly_val[10] = x*(x*((1247.0L/2520.0L)*x - 1453.0L/2100.0L) + 537.0L/2800.0L) + 1.0L/3150.0L;
poly_val[11] = x*(x*(-2.0L/45.0L*x + 11.0L/175.0L) - 19.0L/1050.0L);
break;
}
}
void beta_n5_m3(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*(-5599.0L/907200.0L*x + 983.0L/45360.0L) - 779.0L/30240.0L) + 443.0L/45360.0L) + 41.0L/36288.0L) + 1.0L/6300.0L) - 1.0L/1260.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*((61639.0L/907200.0L)*x - 216533.0L/907200.0L) + 28591.0L/100800.0L) - 2759.0L/25920.0L) - 1261.0L/90720.0L) - 5.0L/2016.0L) + 5.0L/504.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*(-12343.0L/36288.0L*x + 1291.0L/1080.0L) - 5363.0L/3780.0L) + 23711.0L/45360.0L) + 541.0L/6720.0L) + 5.0L/252.0L) - 5.0L/84.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*((61793.0L/60480.0L)*x - 217103.0L/60480.0L) + 85517.0L/20160.0L) - 2599.0L/1728.0L) - 4369.0L/15120.0L) - 5.0L/42.0L) + 5.0L/21.0L);
poly_val[4] = x*(x*(x*(x*(x*(x*(-12371.0L/6048.0L*x + 108541.0L/15120.0L) - 7081.0L/840.0L) + 44003.0L/15120.0L) + 1669.0L/4320.0L) + 5.0L/6.0L) - 5.0L/6.0L);
poly_val[5] = pow(x, 2)*(pow(x, 2)*(x*(x*((61889.0L/21600.0L)*x - 2891.0L/288.0L) + 16877.0L/1440.0L) - 17641.0L/4320.0L) - 5269.0L/3600.0L) + 1;
poly_val[6] = x*(x*(x*(x*(x*(x*(-61889.0L/21600.0L*x + 108199.0L/10800.0L) - 13993.0L/1200.0L) + 9131.0L/2160.0L) - 1669.0L/4320.0L) + 5.0L/6.0L) + 5.0L/6.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*((12371.0L/6048.0L)*x - 215903.0L/30240.0L) + 27931.0L/3360.0L) - 95269.0L/30240.0L) + 4369.0L/15120.0L) - 5.0L/42.0L) - 5.0L/21.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*(-61793.0L/60480.0L*x + 8977.0L/2520.0L) - 4659.0L/1120.0L) + 175.0L/108.0L) - 541.0L/6720.0L) + 5.0L/252.0L) + 5.0L/84.0L);
poly_val[9] = x*(x*(x*(x*(x*(x*((12343.0L/36288.0L)*x - 30731.0L/25920.0L) + 84037.0L/60480.0L) - 98981.0L/181440.0L) + 1261.0L/90720.0L) - 5.0L/2016.0L) - 5.0L/504.0L);
poly_val[10] = x*(x*(x*(x*(x*(x*(-61639.0L/907200.0L*x + 10747.0L/45360.0L) - 1403.0L/5040.0L) + 71.0L/648.0L) - 41.0L/36288.0L) + 1.0L/6300.0L) + 1.0L/1260.0L);
poly_val[11] = pow(x, 4)*(x*(x*((5599.0L/907200.0L)*x - 6511.0L/302400.0L) + 7663.0L/302400.0L) - 1811.0L/181440.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*(-5599.0L/129600.0L*x + 983.0L/7560.0L) - 779.0L/6048.0L) + 443.0L/11340.0L) + 41.0L/12096.0L) + 1.0L/3150.0L) - 1.0L/1260.0L;
poly_val[1] = x*(x*(x*(x*(x*((61639.0L/129600.0L)*x - 216533.0L/151200.0L) + 28591.0L/20160.0L) - 2759.0L/6480.0L) - 1261.0L/30240.0L) - 5.0L/1008.0L) + 5.0L/504.0L;
poly_val[2] = x*(x*(x*(x*(x*(-12343.0L/5184.0L*x + 1291.0L/180.0L) - 5363.0L/756.0L) + 23711.0L/11340.0L) + 541.0L/2240.0L) + 5.0L/126.0L) - 5.0L/84.0L;
poly_val[3] = x*(x*(x*(x*(x*((61793.0L/8640.0L)*x - 217103.0L/10080.0L) + 85517.0L/4032.0L) - 2599.0L/432.0L) - 4369.0L/5040.0L) - 5.0L/21.0L) + 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(-12371.0L/864.0L*x + 108541.0L/2520.0L) - 7081.0L/168.0L) + 44003.0L/3780.0L) + 1669.0L/1440.0L) + 5.0L/3.0L) - 5.0L/6.0L;
poly_val[5] = x*(pow(x, 2)*(x*(x*((433223.0L/21600.0L)*x - 2891.0L/48.0L) + 16877.0L/288.0L) - 17641.0L/1080.0L) - 5269.0L/1800.0L);
poly_val[6] = x*(x*(x*(x*(x*(-433223.0L/21600.0L*x + 108199.0L/1800.0L) - 13993.0L/240.0L) + 9131.0L/540.0L) - 1669.0L/1440.0L) + 5.0L/3.0L) + 5.0L/6.0L;
poly_val[7] = x*(x*(x*(x*(x*((12371.0L/864.0L)*x - 215903.0L/5040.0L) + 27931.0L/672.0L) - 95269.0L/7560.0L) + 4369.0L/5040.0L) - 5.0L/21.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(-61793.0L/8640.0L*x + 8977.0L/420.0L) - 4659.0L/224.0L) + 175.0L/27.0L) - 541.0L/2240.0L) + 5.0L/126.0L) + 5.0L/84.0L;
poly_val[9] = x*(x*(x*(x*(x*((12343.0L/5184.0L)*x - 30731.0L/4320.0L) + 84037.0L/12096.0L) - 98981.0L/45360.0L) + 1261.0L/30240.0L) - 5.0L/1008.0L) - 5.0L/504.0L;
poly_val[10] = x*(x*(x*(x*(x*(-61639.0L/129600.0L*x + 10747.0L/7560.0L) - 1403.0L/1008.0L) + 71.0L/162.0L) - 41.0L/12096.0L) + 1.0L/3150.0L) + 1.0L/1260.0L;
poly_val[11] = pow(x, 3)*(x*(x*((5599.0L/129600.0L)*x - 6511.0L/50400.0L) + 7663.0L/60480.0L) - 1811.0L/45360.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*(-5599.0L/21600.0L*x + 983.0L/1512.0L) - 779.0L/1512.0L) + 443.0L/3780.0L) + 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[1] = x*(x*(x*(x*((61639.0L/21600.0L)*x - 216533.0L/30240.0L) + 28591.0L/5040.0L) - 2759.0L/2160.0L) - 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[2] = x*(x*(x*(x*(-12343.0L/864.0L*x + 1291.0L/36.0L) - 5363.0L/189.0L) + 23711.0L/3780.0L) + 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[3] = x*(x*(x*(x*((61793.0L/1440.0L)*x - 217103.0L/2016.0L) + 85517.0L/1008.0L) - 2599.0L/144.0L) - 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(-12371.0L/144.0L*x + 108541.0L/504.0L) - 7081.0L/42.0L) + 44003.0L/1260.0L) + 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[5] = pow(x, 2)*(x*(x*((433223.0L/3600.0L)*x - 14455.0L/48.0L) + 16877.0L/72.0L) - 17641.0L/360.0L) - 5269.0L/1800.0L;
poly_val[6] = x*(x*(x*(x*(-433223.0L/3600.0L*x + 108199.0L/360.0L) - 13993.0L/60.0L) + 9131.0L/180.0L) - 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[7] = x*(x*(x*(x*((12371.0L/144.0L)*x - 215903.0L/1008.0L) + 27931.0L/168.0L) - 95269.0L/2520.0L) + 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(-61793.0L/1440.0L*x + 8977.0L/84.0L) - 4659.0L/56.0L) + 175.0L/9.0L) - 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[9] = x*(x*(x*(x*((12343.0L/864.0L)*x - 30731.0L/864.0L) + 84037.0L/3024.0L) - 98981.0L/15120.0L) + 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[10] = x*(x*(x*(x*(-61639.0L/21600.0L*x + 10747.0L/1512.0L) - 1403.0L/252.0L) + 71.0L/54.0L) - 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[11] = pow(x, 2)*(x*(x*((5599.0L/21600.0L)*x - 6511.0L/10080.0L) + 7663.0L/15120.0L) - 1811.0L/15120.0L);
break;
}
}
void beta_n5_m4(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*((151.0L/7560.0L)*x - 16309.0L/181440.0L) + 139381.0L/907200.0L) - 10721.0L/90720.0L) + 443.0L/12960.0L) - 41.0L/181440.0L) + 41.0L/36288.0L) + 1.0L/6300.0L) - 1.0L/1260.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(-79729.0L/362880.0L*x + 13289.0L/13440.0L) - 766583.0L/453600.0L) + 589531.0L/453600.0L) - 227249.0L/604800.0L) + 1261.0L/362880.0L) - 1261.0L/90720.0L) - 5.0L/2016.0L) + 5.0L/504.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*((132883.0L/120960.0L)*x - 897011.0L/181440.0L) + 18251.0L/2160.0L) - 877.0L/135.0L) + 136301.0L/72576.0L) - 541.0L/20160.0L) + 541.0L/6720.0L) + 5.0L/252.0L) - 5.0L/84.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(-33221.0L/10080.0L*x + 897007.0L/60480.0L) - 306595.0L/12096.0L) + 1178419.0L/60480.0L) - 341587.0L/60480.0L) + 4369.0L/30240.0L) - 4369.0L/15120.0L) - 5.0L/42.0L) + 5.0L/21.0L);
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*((199327.0L/30240.0L)*x - 298999.0L/10080.0L) + 1532863.0L/30240.0L) - 29459.0L/756.0L) + 114389.0L/10080.0L) - 1669.0L/4320.0L) + 1669.0L/4320.0L) + 5.0L/6.0L) - 5.0L/6.0L);
poly_val[5] = pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(-2953.0L/320.0L*x + 358793.0L/8640.0L) - 255461.0L/3600.0L) + 9821.0L/180.0L) - 27589.0L/1728.0L) + 1529.0L/2880.0L) - 5269.0L/3600.0L) + 1;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*((2953.0L/320.0L)*x - 179393.0L/4320.0L) + 191587.0L/2700.0L) - 589421.0L/10800.0L) + 692147.0L/43200.0L) - 1669.0L/4320.0L) - 1669.0L/4320.0L) + 5.0L/6.0L) + 5.0L/6.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(-199327.0L/30240.0L*x + 149491.0L/5040.0L) - 1532659.0L/30240.0L) + 1179233.0L/30240.0L) - 275.0L/24.0L) + 4369.0L/30240.0L) + 4369.0L/15120.0L) - 5.0L/42.0L) - 5.0L/21.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*((33221.0L/10080.0L)*x - 896927.0L/60480.0L) + 11353.0L/448.0L) - 65533.0L/3360.0L) + 43279.0L/7560.0L) - 541.0L/20160.0L) - 541.0L/6720.0L) + 5.0L/252.0L) + 5.0L/84.0L);
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(-132883.0L/120960.0L*x + 1793819.0L/362880.0L) - 109477.0L/12960.0L) + 16855.0L/2592.0L) - 691319.0L/362880.0L) + 1261.0L/362880.0L) + 1261.0L/90720.0L) - 5.0L/2016.0L) - 5.0L/504.0L);
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*((79729.0L/362880.0L)*x - 19931.0L/20160.0L) + 383179.0L/226800.0L) - 58999.0L/45360.0L) + 46027.0L/120960.0L) - 41.0L/181440.0L) - 41.0L/36288.0L) + 1.0L/6300.0L) + 1.0L/1260.0L);
poly_val[11] = pow(x, 5)*(x*(x*(x*(-151.0L/7560.0L*x + 16307.0L/181440.0L) - 46447.0L/302400.0L) + 35759.0L/302400.0L) - 31351.0L/907200.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*((151.0L/840.0L)*x - 16309.0L/22680.0L) + 139381.0L/129600.0L) - 10721.0L/15120.0L) + 443.0L/2592.0L) - 41.0L/45360.0L) + 41.0L/12096.0L) + 1.0L/3150.0L) - 1.0L/1260.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(-79729.0L/40320.0L*x + 13289.0L/1680.0L) - 766583.0L/64800.0L) + 589531.0L/75600.0L) - 227249.0L/120960.0L) + 1261.0L/90720.0L) - 1261.0L/30240.0L) - 5.0L/1008.0L) + 5.0L/504.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*((132883.0L/13440.0L)*x - 897011.0L/22680.0L) + 127757.0L/2160.0L) - 1754.0L/45.0L) + 681505.0L/72576.0L) - 541.0L/5040.0L) + 541.0L/2240.0L) + 5.0L/126.0L) - 5.0L/84.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(-33221.0L/1120.0L*x + 897007.0L/7560.0L) - 306595.0L/1728.0L) + 1178419.0L/10080.0L) - 341587.0L/12096.0L) + 4369.0L/7560.0L) - 4369.0L/5040.0L) - 5.0L/21.0L) + 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*(x*((199327.0L/3360.0L)*x - 298999.0L/1260.0L) + 1532863.0L/4320.0L) - 29459.0L/126.0L) + 114389.0L/2016.0L) - 1669.0L/1080.0L) + 1669.0L/1440.0L) + 5.0L/3.0L) - 5.0L/6.0L;
poly_val[5] = x*(pow(x, 2)*(x*(x*(x*(x*(-26577.0L/320.0L*x + 358793.0L/1080.0L) - 1788227.0L/3600.0L) + 9821.0L/30.0L) - 137945.0L/1728.0L) + 1529.0L/720.0L) - 5269.0L/1800.0L);
poly_val[6] = x*(x*(x*(x*(x*(x*(x*((26577.0L/320.0L)*x - 179393.0L/540.0L) + 1341109.0L/2700.0L) - 589421.0L/1800.0L) + 692147.0L/8640.0L) - 1669.0L/1080.0L) - 1669.0L/1440.0L) + 5.0L/3.0L) + 5.0L/6.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(-199327.0L/3360.0L*x + 149491.0L/630.0L) - 1532659.0L/4320.0L) + 1179233.0L/5040.0L) - 1375.0L/24.0L) + 4369.0L/7560.0L) + 4369.0L/5040.0L) - 5.0L/21.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*((33221.0L/1120.0L)*x - 896927.0L/7560.0L) + 11353.0L/64.0L) - 65533.0L/560.0L) + 43279.0L/1512.0L) - 541.0L/5040.0L) - 541.0L/2240.0L) + 5.0L/126.0L) + 5.0L/84.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(-132883.0L/13440.0L*x + 1793819.0L/45360.0L) - 766339.0L/12960.0L) + 16855.0L/432.0L) - 691319.0L/72576.0L) + 1261.0L/90720.0L) + 1261.0L/30240.0L) - 5.0L/1008.0L) - 5.0L/504.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*(x*((79729.0L/40320.0L)*x - 19931.0L/2520.0L) + 383179.0L/32400.0L) - 58999.0L/7560.0L) + 46027.0L/24192.0L) - 41.0L/45360.0L) - 41.0L/12096.0L) + 1.0L/3150.0L) + 1.0L/1260.0L;
poly_val[11] = pow(x, 4)*(x*(x*(x*(-151.0L/840.0L*x + 16307.0L/22680.0L) - 46447.0L/43200.0L) + 35759.0L/50400.0L) - 31351.0L/181440.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*(x*(x*((151.0L/105.0L)*x - 16309.0L/3240.0L) + 139381.0L/21600.0L) - 10721.0L/3024.0L) + 443.0L/648.0L) - 41.0L/15120.0L) + 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(-79729.0L/5040.0L*x + 13289.0L/240.0L) - 766583.0L/10800.0L) + 589531.0L/15120.0L) - 227249.0L/30240.0L) + 1261.0L/30240.0L) - 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*((132883.0L/1680.0L)*x - 897011.0L/3240.0L) + 127757.0L/360.0L) - 1754.0L/9.0L) + 681505.0L/18144.0L) - 541.0L/1680.0L) + 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(-33221.0L/140.0L*x + 897007.0L/1080.0L) - 306595.0L/288.0L) + 1178419.0L/2016.0L) - 341587.0L/3024.0L) + 4369.0L/2520.0L) - 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*((199327.0L/420.0L)*x - 298999.0L/180.0L) + 1532863.0L/720.0L) - 147295.0L/126.0L) + 114389.0L/504.0L) - 1669.0L/360.0L) + 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[5] = pow(x, 2)*(x*(x*(x*(x*(-26577.0L/40.0L*x + 2511551.0L/1080.0L) - 1788227.0L/600.0L) + 9821.0L/6.0L) - 137945.0L/432.0L) + 1529.0L/240.0L) - 5269.0L/1800.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*((26577.0L/40.0L)*x - 1255751.0L/540.0L) + 1341109.0L/450.0L) - 589421.0L/360.0L) + 692147.0L/2160.0L) - 1669.0L/360.0L) - 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(-199327.0L/420.0L*x + 149491.0L/90.0L) - 1532659.0L/720.0L) + 1179233.0L/1008.0L) - 1375.0L/6.0L) + 4369.0L/2520.0L) + 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*((33221.0L/140.0L)*x - 896927.0L/1080.0L) + 34059.0L/32.0L) - 65533.0L/112.0L) + 43279.0L/378.0L) - 541.0L/1680.0L) - 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(-132883.0L/1680.0L*x + 1793819.0L/6480.0L) - 766339.0L/2160.0L) + 84275.0L/432.0L) - 691319.0L/18144.0L) + 1261.0L/30240.0L) + 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*((79729.0L/5040.0L)*x - 19931.0L/360.0L) + 383179.0L/5400.0L) - 58999.0L/1512.0L) + 46027.0L/6048.0L) - 41.0L/15120.0L) - 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[11] = pow(x, 3)*(x*(x*(x*(-151.0L/105.0L*x + 16307.0L/3240.0L) - 46447.0L/7200.0L) + 35759.0L/10080.0L) - 31351.0L/45360.0L);
break;
}
}
void beta_n5_m5(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-83603.0L/1209600.0L*x + 27589.0L/72576.0L) - 612527.0L/725760.0L) + 28633.0L/30240.0L) - 278653.0L/518400.0L) + 32071.0L/259200.0L) - 13.0L/34560.0L) - 41.0L/181440.0L) + 41.0L/36288.0L) + 1.0L/6300.0L) - 1.0L/1260.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((919633.0L/1209600.0L)*x - 722569.0L/172800.0L) + 481271.0L/51840.0L) - 41995.0L/4032.0L) + 21456371.0L/3628800.0L) - 705703.0L/518400.0L) + 19.0L/4320.0L) + 1261.0L/362880.0L) - 1261.0L/90720.0L) - 5.0L/2016.0L) + 5.0L/504.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-919633.0L/241920.0L*x + 3793487.0L/181440.0L) - 33688957.0L/725760.0L) + 3149623.0L/60480.0L) - 21456689.0L/725760.0L) + 176479.0L/25920.0L) - 29.0L/1280.0L) - 541.0L/20160.0L) + 541.0L/6720.0L) + 5.0L/252.0L) - 5.0L/84.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((919633.0L/80640.0L)*x - 15173947.0L/241920.0L) + 16844473.0L/120960.0L) - 2099749.0L/13440.0L) + 4291423.0L/48384.0L) - 706069.0L/34560.0L) + 13.0L/240.0L) + 4369.0L/30240.0L) - 4369.0L/15120.0L) - 5.0L/42.0L) + 5.0L/21.0L);
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-919633.0L/40320.0L*x + 280999.0L/2240.0L) - 33688937.0L/120960.0L) + 1574813.0L/5040.0L) - 21457553.0L/120960.0L) + 353051.0L/8640.0L) - 323.0L/5760.0L) - 1669.0L/4320.0L) + 1669.0L/4320.0L) + 5.0L/6.0L) - 5.0L/6.0L);
poly_val[5] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*((919633.0L/28800.0L)*x - 3034789.0L/17280.0L) + 3368893.0L/8640.0L) - 314963.0L/720.0L) + 21457931.0L/86400.0L) - 4942069.0L/86400.0L) + 1529.0L/2880.0L) - 5269.0L/3600.0L) + 1;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-919633.0L/28800.0L*x + 1896743.0L/10800.0L) - 1347557.0L/3456.0L) + 629927.0L/1440.0L) - 21458201.0L/86400.0L) + 617597.0L/10800.0L) + 323.0L/5760.0L) - 1669.0L/4320.0L) - 1669.0L/4320.0L) + 5.0L/6.0L) + 5.0L/6.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((919633.0L/40320.0L)*x - 5057981.0L/40320.0L) + 16844461.0L/60480.0L) - 6299281.0L/20160.0L) + 3065477.0L/17280.0L) - 705601.0L/17280.0L) - 13.0L/240.0L) + 4369.0L/30240.0L) + 4369.0L/15120.0L) - 5.0L/42.0L) - 5.0L/21.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-919633.0L/80640.0L*x + 1083853.0L/17280.0L) - 4812703.0L/34560.0L) + 524941.0L/3360.0L) - 4291669.0L/48384.0L) + 352697.0L/17280.0L) + 29.0L/1280.0L) - 541.0L/20160.0L) - 541.0L/6720.0L) + 5.0L/252.0L) + 5.0L/84.0L);
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((919633.0L/241920.0L)*x - 15173941.0L/725760.0L) + 16844461.0L/362880.0L) - 3149651.0L/60480.0L) + 21458243.0L/725760.0L) - 705247.0L/103680.0L) - 19.0L/4320.0L) + 1261.0L/362880.0L) + 1261.0L/90720.0L) - 5.0L/2016.0L) - 5.0L/504.0L);
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-919633.0L/1209600.0L*x + 252899.0L/60480.0L) - 1347557.0L/145152.0L) + 209977.0L/20160.0L) - 21458081.0L/3628800.0L) + 176293.0L/129600.0L) + 13.0L/34560.0L) - 41.0L/181440.0L) - 41.0L/36288.0L) + 1.0L/6300.0L) + 1.0L/1260.0L);
poly_val[11] = pow(x, 6)*(x*(x*(x*(x*((83603.0L/1209600.0L)*x - 1379449.0L/3628800.0L) + 306263.0L/362880.0L) - 114533.0L/120960.0L) + 1950721.0L/3628800.0L) - 64103.0L/518400.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(-919633.0L/1209600.0L*x + 137945.0L/36288.0L) - 612527.0L/80640.0L) + 28633.0L/3780.0L) - 1950571.0L/518400.0L) + 32071.0L/43200.0L) - 13.0L/6912.0L) - 41.0L/45360.0L) + 41.0L/12096.0L) + 1.0L/3150.0L) - 1.0L/1260.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*((10115963.0L/1209600.0L)*x - 722569.0L/17280.0L) + 481271.0L/5760.0L) - 41995.0L/504.0L) + 21456371.0L/518400.0L) - 705703.0L/86400.0L) + 19.0L/864.0L) + 1261.0L/90720.0L) - 1261.0L/30240.0L) - 5.0L/1008.0L) + 5.0L/504.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(-10115963.0L/241920.0L*x + 3793487.0L/18144.0L) - 33688957.0L/80640.0L) + 3149623.0L/7560.0L) - 21456689.0L/103680.0L) + 176479.0L/4320.0L) - 29.0L/256.0L) - 541.0L/5040.0L) + 541.0L/2240.0L) + 5.0L/126.0L) - 5.0L/84.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*((10115963.0L/80640.0L)*x - 15173947.0L/24192.0L) + 16844473.0L/13440.0L) - 2099749.0L/1680.0L) + 4291423.0L/6912.0L) - 706069.0L/5760.0L) + 13.0L/48.0L) + 4369.0L/7560.0L) - 4369.0L/5040.0L) - 5.0L/21.0L) + 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(-10115963.0L/40320.0L*x + 280999.0L/224.0L) - 33688937.0L/13440.0L) + 1574813.0L/630.0L) - 21457553.0L/17280.0L) + 353051.0L/1440.0L) - 323.0L/1152.0L) - 1669.0L/1080.0L) + 1669.0L/1440.0L) + 5.0L/3.0L) - 5.0L/6.0L;
poly_val[5] = x*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*((10115963.0L/28800.0L)*x - 3034789.0L/1728.0L) + 3368893.0L/960.0L) - 314963.0L/90.0L) + 150205517.0L/86400.0L) - 4942069.0L/14400.0L) + 1529.0L/720.0L) - 5269.0L/1800.0L);
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(-10115963.0L/28800.0L*x + 1896743.0L/1080.0L) - 1347557.0L/384.0L) + 629927.0L/180.0L) - 150207407.0L/86400.0L) + 617597.0L/1800.0L) + 323.0L/1152.0L) - 1669.0L/1080.0L) - 1669.0L/1440.0L) + 5.0L/3.0L) + 5.0L/6.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*((10115963.0L/40320.0L)*x - 5057981.0L/4032.0L) + 16844461.0L/6720.0L) - 6299281.0L/2520.0L) + 21458339.0L/17280.0L) - 705601.0L/2880.0L) - 13.0L/48.0L) + 4369.0L/7560.0L) + 4369.0L/5040.0L) - 5.0L/21.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(-10115963.0L/80640.0L*x + 1083853.0L/1728.0L) - 4812703.0L/3840.0L) + 524941.0L/420.0L) - 4291669.0L/6912.0L) + 352697.0L/2880.0L) + 29.0L/256.0L) - 541.0L/5040.0L) - 541.0L/2240.0L) + 5.0L/126.0L) + 5.0L/84.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*((10115963.0L/241920.0L)*x - 15173941.0L/72576.0L) + 16844461.0L/40320.0L) - 3149651.0L/7560.0L) + 21458243.0L/103680.0L) - 705247.0L/17280.0L) - 19.0L/864.0L) + 1261.0L/90720.0L) + 1261.0L/30240.0L) - 5.0L/1008.0L) - 5.0L/504.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(-10115963.0L/1209600.0L*x + 252899.0L/6048.0L) - 1347557.0L/16128.0L) + 209977.0L/2520.0L) - 21458081.0L/518400.0L) + 176293.0L/21600.0L) + 13.0L/6912.0L) - 41.0L/45360.0L) - 41.0L/12096.0L) + 1.0L/3150.0L) + 1.0L/1260.0L;
poly_val[11] = pow(x, 5)*(x*(x*(x*(x*((919633.0L/1209600.0L)*x - 1379449.0L/362880.0L) + 306263.0L/40320.0L) - 114533.0L/15120.0L) + 1950721.0L/518400.0L) - 64103.0L/86400.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(-919633.0L/120960.0L*x + 137945.0L/4032.0L) - 612527.0L/10080.0L) + 28633.0L/540.0L) - 1950571.0L/86400.0L) + 32071.0L/8640.0L) - 13.0L/1728.0L) - 41.0L/15120.0L) + 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*((10115963.0L/120960.0L)*x - 722569.0L/1920.0L) + 481271.0L/720.0L) - 41995.0L/72.0L) + 21456371.0L/86400.0L) - 705703.0L/17280.0L) + 19.0L/216.0L) + 1261.0L/30240.0L) - 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(-10115963.0L/24192.0L*x + 3793487.0L/2016.0L) - 33688957.0L/10080.0L) + 3149623.0L/1080.0L) - 21456689.0L/17280.0L) + 176479.0L/864.0L) - 29.0L/64.0L) - 541.0L/1680.0L) + 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*((10115963.0L/8064.0L)*x - 15173947.0L/2688.0L) + 16844473.0L/1680.0L) - 2099749.0L/240.0L) + 4291423.0L/1152.0L) - 706069.0L/1152.0L) + 13.0L/12.0L) + 4369.0L/2520.0L) - 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(-10115963.0L/4032.0L*x + 2528991.0L/224.0L) - 33688937.0L/1680.0L) + 1574813.0L/90.0L) - 21457553.0L/2880.0L) + 353051.0L/288.0L) - 323.0L/288.0L) - 1669.0L/360.0L) + 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[5] = pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*((10115963.0L/2880.0L)*x - 3034789.0L/192.0L) + 3368893.0L/120.0L) - 2204741.0L/90.0L) + 150205517.0L/14400.0L) - 4942069.0L/2880.0L) + 1529.0L/240.0L) - 5269.0L/1800.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(-10115963.0L/2880.0L*x + 1896743.0L/120.0L) - 1347557.0L/48.0L) + 4409489.0L/180.0L) - 150207407.0L/14400.0L) + 617597.0L/360.0L) + 323.0L/288.0L) - 1669.0L/360.0L) - 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*((10115963.0L/4032.0L)*x - 5057981.0L/448.0L) + 16844461.0L/840.0L) - 6299281.0L/360.0L) + 21458339.0L/2880.0L) - 705601.0L/576.0L) - 13.0L/12.0L) + 4369.0L/2520.0L) + 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(-10115963.0L/8064.0L*x + 1083853.0L/192.0L) - 4812703.0L/480.0L) + 524941.0L/60.0L) - 4291669.0L/1152.0L) + 352697.0L/576.0L) + 29.0L/64.0L) - 541.0L/1680.0L) - 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*((10115963.0L/24192.0L)*x - 15173941.0L/8064.0L) + 16844461.0L/5040.0L) - 3149651.0L/1080.0L) + 21458243.0L/17280.0L) - 705247.0L/3456.0L) - 19.0L/216.0L) + 1261.0L/30240.0L) + 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(-10115963.0L/120960.0L*x + 252899.0L/672.0L) - 1347557.0L/2016.0L) + 209977.0L/360.0L) - 21458081.0L/86400.0L) + 176293.0L/4320.0L) + 13.0L/1728.0L) - 41.0L/15120.0L) - 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[11] = pow(x, 4)*(x*(x*(x*(x*((919633.0L/120960.0L)*x - 1379449.0L/40320.0L) + 306263.0L/5040.0L) - 114533.0L/2160.0L) + 1950721.0L/86400.0L) - 64103.0L/17280.0L);
break;
}
}
void beta_n5_m6(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((64103.0L/259200.0L)*x - 833339.0L/518400.0L) + 5301049.0L/1209600.0L) - 1553347.0L/241920.0L) + 1291561.0L/241920.0L) - 2893169.0L/1209600.0L) + 2891.0L/6400.0L) + 13.0L/172800.0L) - 13.0L/34560.0L) - 41.0L/181440.0L) + 41.0L/36288.0L) + 1.0L/6300.0L) - 1.0L/1260.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-705133.0L/259200.0L*x + 9166729.0L/518400.0L) - 58311539.0L/1209600.0L) + 2288413.0L/32400.0L) - 169133.0L/2880.0L) + 10608293.0L/403200.0L) - 2003453.0L/403200.0L) - 19.0L/17280.0L) + 19.0L/4320.0L) + 1261.0L/362880.0L) - 1261.0L/90720.0L) - 5.0L/2016.0L) + 5.0L/504.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((705133.0L/51840.0L)*x - 9166729.0L/103680.0L) + 58311539.0L/241920.0L) - 256302257.0L/725760.0L) + 213107593.0L/725760.0L) - 31824887.0L/241920.0L) + 6010253.0L/241920.0L) + 29.0L/3840.0L) - 29.0L/1280.0L) - 541.0L/20160.0L) + 541.0L/6720.0L) + 5.0L/252.0L) - 5.0L/84.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-705133.0L/17280.0L*x + 9166729.0L/34560.0L) - 58311539.0L/80640.0L) + 42717043.0L/40320.0L) - 17758967.0L/20160.0L) + 2121659.0L/5376.0L) - 6010111.0L/80640.0L) - 13.0L/480.0L) + 13.0L/240.0L) + 4369.0L/30240.0L) - 4369.0L/15120.0L) - 5.0L/42.0L) + 5.0L/21.0L);
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((705133.0L/8640.0L)*x - 9166729.0L/17280.0L) + 58311539.0L/40320.0L) - 256302259.0L/120960.0L) + 71035871.0L/40320.0L) - 6364975.0L/8064.0L) + 1201993.0L/8064.0L) + 323.0L/5760.0L) - 323.0L/5760.0L) - 1669.0L/4320.0L) + 1669.0L/4320.0L) + 5.0L/6.0L) - 5.0L/6.0L);
poly_val[5] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(-4935931.0L/43200.0L*x + 64167103.0L/86400.0L) - 58311539.0L/28800.0L) + 12815113.0L/4320.0L) - 10655381.0L/4320.0L) + 31824859.0L/28800.0L) - 6009839.0L/28800.0L) - 341.0L/4800.0L) + 1529.0L/2880.0L) - 5269.0L/3600.0L) + 1;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((4935931.0L/43200.0L)*x - 64167103.0L/86400.0L) + 58311539.0L/28800.0L) - 28478029.0L/9600.0L) + 315715.0L/128.0L) - 31824839.0L/28800.0L) + 6009749.0L/28800.0L) + 323.0L/5760.0L) + 323.0L/5760.0L) - 1669.0L/4320.0L) - 1669.0L/4320.0L) + 5.0L/6.0L) + 5.0L/6.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-705133.0L/8640.0L*x + 9166729.0L/17280.0L) - 58311539.0L/40320.0L) + 128151131.0L/60480.0L) - 17758969.0L/10080.0L) + 31824817.0L/40320.0L) - 858529.0L/5760.0L) - 13.0L/480.0L) - 13.0L/240.0L) + 4369.0L/30240.0L) + 4369.0L/15120.0L) - 5.0L/42.0L) - 5.0L/21.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((705133.0L/17280.0L)*x - 9166729.0L/34560.0L) + 58311539.0L/80640.0L) - 36614609.0L/34560.0L) + 30443947.0L/34560.0L) - 2121653.0L/5376.0L) + 6009701.0L/80640.0L) + 29.0L/3840.0L) + 29.0L/1280.0L) - 541.0L/20160.0L) - 541.0L/6720.0L) + 5.0L/252.0L) + 5.0L/84.0L);
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-705133.0L/51840.0L*x + 9166729.0L/103680.0L) - 58311539.0L/241920.0L) + 10679261.0L/30240.0L) - 17758969.0L/60480.0L) + 6364955.0L/48384.0L) - 400649.0L/16128.0L) - 19.0L/17280.0L) - 19.0L/4320.0L) + 1261.0L/362880.0L) + 1261.0L/90720.0L) - 5.0L/2016.0L) - 5.0L/504.0L);
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((705133.0L/259200.0L)*x - 9166729.0L/518400.0L) + 58311539.0L/1209600.0L) - 51260453.0L/725760.0L) + 315715.0L/5376.0L) - 10608253.0L/403200.0L) + 2003263.0L/403200.0L) + 13.0L/172800.0L) + 13.0L/34560.0L) - 41.0L/181440.0L) - 41.0L/36288.0L) + 1.0L/6300.0L) + 1.0L/1260.0L);
poly_val[11] = pow(x, 7)*(x*(x*(x*(x*(x*(-64103.0L/259200.0L*x + 833339.0L/518400.0L) - 5301049.0L/1209600.0L) + 11650103.0L/1814400.0L) - 968671.0L/181440.0L) + 2893159.0L/1209600.0L) - 546349.0L/1209600.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((833339.0L/259200.0L)*x - 833339.0L/43200.0L) + 58311539.0L/1209600.0L) - 1553347.0L/24192.0L) + 1291561.0L/26880.0L) - 2893169.0L/151200.0L) + 20237.0L/6400.0L) + 13.0L/28800.0L) - 13.0L/6912.0L) - 41.0L/45360.0L) + 41.0L/12096.0L) + 1.0L/3150.0L) - 1.0L/1260.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-9166729.0L/259200.0L*x + 9166729.0L/43200.0L) - 641426929.0L/1209600.0L) + 2288413.0L/3240.0L) - 169133.0L/320.0L) + 10608293.0L/50400.0L) - 2003453.0L/57600.0L) - 19.0L/2880.0L) + 19.0L/864.0L) + 1261.0L/90720.0L) - 1261.0L/30240.0L) - 5.0L/1008.0L) + 5.0L/504.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((9166729.0L/51840.0L)*x - 9166729.0L/8640.0L) + 641426929.0L/241920.0L) - 256302257.0L/72576.0L) + 213107593.0L/80640.0L) - 31824887.0L/30240.0L) + 6010253.0L/34560.0L) + 29.0L/640.0L) - 29.0L/256.0L) - 541.0L/5040.0L) + 541.0L/2240.0L) + 5.0L/126.0L) - 5.0L/84.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-9166729.0L/17280.0L*x + 9166729.0L/2880.0L) - 641426929.0L/80640.0L) + 42717043.0L/4032.0L) - 17758967.0L/2240.0L) + 2121659.0L/672.0L) - 6010111.0L/11520.0L) - 13.0L/80.0L) + 13.0L/48.0L) + 4369.0L/7560.0L) - 4369.0L/5040.0L) - 5.0L/21.0L) + 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((9166729.0L/8640.0L)*x - 9166729.0L/1440.0L) + 641426929.0L/40320.0L) - 256302259.0L/12096.0L) + 71035871.0L/4480.0L) - 6364975.0L/1008.0L) + 1201993.0L/1152.0L) + 323.0L/960.0L) - 323.0L/1152.0L) - 1669.0L/1080.0L) + 1669.0L/1440.0L) + 5.0L/3.0L) - 5.0L/6.0L;
poly_val[5] = x*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(-64167103.0L/43200.0L*x + 64167103.0L/7200.0L) - 641426929.0L/28800.0L) + 12815113.0L/432.0L) - 10655381.0L/480.0L) + 31824859.0L/3600.0L) - 42068873.0L/28800.0L) - 341.0L/800.0L) + 1529.0L/720.0L) - 5269.0L/1800.0L);
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((64167103.0L/43200.0L)*x - 64167103.0L/7200.0L) + 641426929.0L/28800.0L) - 28478029.0L/960.0L) + 2841435.0L/128.0L) - 31824839.0L/3600.0L) + 42068243.0L/28800.0L) + 323.0L/960.0L) + 323.0L/1152.0L) - 1669.0L/1080.0L) - 1669.0L/1440.0L) + 5.0L/3.0L) + 5.0L/6.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-9166729.0L/8640.0L*x + 9166729.0L/1440.0L) - 641426929.0L/40320.0L) + 128151131.0L/6048.0L) - 17758969.0L/1120.0L) + 31824817.0L/5040.0L) - 6009703.0L/5760.0L) - 13.0L/80.0L) - 13.0L/48.0L) + 4369.0L/7560.0L) + 4369.0L/5040.0L) - 5.0L/21.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((9166729.0L/17280.0L)*x - 9166729.0L/2880.0L) + 641426929.0L/80640.0L) - 36614609.0L/3456.0L) + 30443947.0L/3840.0L) - 2121653.0L/672.0L) + 6009701.0L/11520.0L) + 29.0L/640.0L) + 29.0L/256.0L) - 541.0L/5040.0L) - 541.0L/2240.0L) + 5.0L/126.0L) + 5.0L/84.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-9166729.0L/51840.0L*x + 9166729.0L/8640.0L) - 641426929.0L/241920.0L) + 10679261.0L/3024.0L) - 17758969.0L/6720.0L) + 6364955.0L/6048.0L) - 400649.0L/2304.0L) - 19.0L/2880.0L) - 19.0L/864.0L) + 1261.0L/90720.0L) + 1261.0L/30240.0L) - 5.0L/1008.0L) - 5.0L/504.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((9166729.0L/259200.0L)*x - 9166729.0L/43200.0L) + 641426929.0L/1209600.0L) - 51260453.0L/72576.0L) + 947145.0L/1792.0L) - 10608253.0L/50400.0L) + 2003263.0L/57600.0L) + 13.0L/28800.0L) + 13.0L/6912.0L) - 41.0L/45360.0L) - 41.0L/12096.0L) + 1.0L/3150.0L) + 1.0L/1260.0L;
poly_val[11] = pow(x, 6)*(x*(x*(x*(x*(x*(-833339.0L/259200.0L*x + 833339.0L/43200.0L) - 58311539.0L/1209600.0L) + 11650103.0L/181440.0L) - 968671.0L/20160.0L) + 2893159.0L/151200.0L) - 546349.0L/172800.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((833339.0L/21600.0L)*x - 9166729.0L/43200.0L) + 58311539.0L/120960.0L) - 1553347.0L/2688.0L) + 1291561.0L/3360.0L) - 2893169.0L/21600.0L) + 60711.0L/3200.0L) + 13.0L/5760.0L) - 13.0L/1728.0L) - 41.0L/15120.0L) + 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-9166729.0L/21600.0L*x + 100834019.0L/43200.0L) - 641426929.0L/120960.0L) + 2288413.0L/360.0L) - 169133.0L/40.0L) + 10608293.0L/7200.0L) - 2003453.0L/9600.0L) - 19.0L/576.0L) + 19.0L/216.0L) + 1261.0L/30240.0L) - 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((9166729.0L/4320.0L)*x - 100834019.0L/8640.0L) + 641426929.0L/24192.0L) - 256302257.0L/8064.0L) + 213107593.0L/10080.0L) - 31824887.0L/4320.0L) + 6010253.0L/5760.0L) + 29.0L/128.0L) - 29.0L/64.0L) - 541.0L/1680.0L) + 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-9166729.0L/1440.0L*x + 100834019.0L/2880.0L) - 641426929.0L/8064.0L) + 42717043.0L/448.0L) - 17758967.0L/280.0L) + 2121659.0L/96.0L) - 6010111.0L/1920.0L) - 13.0L/16.0L) + 13.0L/12.0L) + 4369.0L/2520.0L) - 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((9166729.0L/720.0L)*x - 100834019.0L/1440.0L) + 641426929.0L/4032.0L) - 256302259.0L/1344.0L) + 71035871.0L/560.0L) - 6364975.0L/144.0L) + 1201993.0L/192.0L) + 323.0L/192.0L) - 323.0L/288.0L) - 1669.0L/360.0L) + 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[5] = pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(-64167103.0L/3600.0L*x + 705838133.0L/7200.0L) - 641426929.0L/2880.0L) + 12815113.0L/48.0L) - 10655381.0L/60.0L) + 222774013.0L/3600.0L) - 42068873.0L/4800.0L) - 341.0L/160.0L) + 1529.0L/240.0L) - 5269.0L/1800.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((64167103.0L/3600.0L)*x - 705838133.0L/7200.0L) + 641426929.0L/2880.0L) - 85434087.0L/320.0L) + 2841435.0L/16.0L) - 222773873.0L/3600.0L) + 42068243.0L/4800.0L) + 323.0L/192.0L) + 323.0L/288.0L) - 1669.0L/360.0L) - 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-9166729.0L/720.0L*x + 100834019.0L/1440.0L) - 641426929.0L/4032.0L) + 128151131.0L/672.0L) - 17758969.0L/140.0L) + 31824817.0L/720.0L) - 6009703.0L/960.0L) - 13.0L/16.0L) - 13.0L/12.0L) + 4369.0L/2520.0L) + 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((9166729.0L/1440.0L)*x - 100834019.0L/2880.0L) + 641426929.0L/8064.0L) - 36614609.0L/384.0L) + 30443947.0L/480.0L) - 2121653.0L/96.0L) + 6009701.0L/1920.0L) + 29.0L/128.0L) + 29.0L/64.0L) - 541.0L/1680.0L) - 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-9166729.0L/4320.0L*x + 100834019.0L/8640.0L) - 641426929.0L/24192.0L) + 10679261.0L/336.0L) - 17758969.0L/840.0L) + 6364955.0L/864.0L) - 400649.0L/384.0L) - 19.0L/576.0L) - 19.0L/216.0L) + 1261.0L/30240.0L) + 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((9166729.0L/21600.0L)*x - 100834019.0L/43200.0L) + 641426929.0L/120960.0L) - 51260453.0L/8064.0L) + 947145.0L/224.0L) - 10608253.0L/7200.0L) + 2003263.0L/9600.0L) + 13.0L/5760.0L) + 13.0L/1728.0L) - 41.0L/15120.0L) - 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[11] = pow(x, 5)*(x*(x*(x*(x*(x*(-833339.0L/21600.0L*x + 9166729.0L/43200.0L) - 58311539.0L/120960.0L) + 11650103.0L/20160.0L) - 968671.0L/2520.0L) + 2893159.0L/21600.0L) - 546349.0L/28800.0L);
break;
}
}
void beta_n5_m7(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-546349.0L/604800.0L*x + 546349.0L/80640.0L) - 11345123.0L/518400.0L) + 639821.0L/16200.0L) - 13016399.0L/302400.0L) + 5717023.0L/201600.0L) - 422147.0L/40320.0L) + 505993.0L/302400.0L) + 1.0L/24192.0L) + 13.0L/172800.0L) - 13.0L/34560.0L) - 41.0L/181440.0L) + 41.0L/36288.0L) + 1.0L/6300.0L) - 1.0L/1260.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((6009839.0L/604800.0L)*x - 6009839.0L/80640.0L) + 124796353.0L/518400.0L) - 7038031.0L/16200.0L) + 143180389.0L/302400.0L) - 161710079.0L/518400.0L) + 3980243.0L/34560.0L) - 927653.0L/50400.0L) - 13.0L/30240.0L) - 19.0L/17280.0L) + 19.0L/4320.0L) + 1261.0L/362880.0L) - 1261.0L/90720.0L) - 5.0L/2016.0L) + 5.0L/504.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/120960.0L*x + 6009839.0L/16128.0L) - 124796353.0L/103680.0L) + 7038031.0L/3240.0L) - 143180389.0L/60480.0L) + 141496319.0L/90720.0L) - 208962751.0L/362880.0L) + 1391479.0L/15120.0L) + 23.0L/13440.0L) + 29.0L/3840.0L) - 29.0L/1280.0L) - 541.0L/20160.0L) + 541.0L/6720.0L) + 5.0L/252.0L) - 5.0L/84.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((6009839.0L/40320.0L)*x - 6009839.0L/5376.0L) + 124796353.0L/34560.0L) - 7038031.0L/1080.0L) + 143180389.0L/20160.0L) - 377323517.0L/80640.0L) + 139308497.0L/80640.0L) - 3710611.0L/13440.0L) - 17.0L/5040.0L) - 13.0L/480.0L) + 13.0L/240.0L) + 4369.0L/30240.0L) - 4369.0L/15120.0L) - 5.0L/42.0L) + 5.0L/21.0L);
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/20160.0L*x + 6009839.0L/2688.0L) - 124796353.0L/17280.0L) + 7038031.0L/540.0L) - 143180389.0L/10080.0L) + 113197055.0L/12096.0L) - 69654247.0L/20160.0L) + 5565919.0L/10080.0L) + 1.0L/320.0L) + 323.0L/5760.0L) - 323.0L/5760.0L) - 1669.0L/4320.0L) + 1669.0L/4320.0L) + 5.0L/6.0L) - 5.0L/6.0L);
poly_val[5] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*((6009839.0L/14400.0L)*x - 6009839.0L/1920.0L) + 873574471.0L/86400.0L) - 49266217.0L/2700.0L) + 143180389.0L/7200.0L) - 1131970549.0L/86400.0L) + 16717019.0L/3456.0L) - 5565923.0L/7200.0L) - 341.0L/4800.0L) + 1529.0L/2880.0L) - 5269.0L/3600.0L) + 1;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/14400.0L*x + 6009839.0L/1920.0L) - 873574471.0L/86400.0L) + 49266217.0L/2700.0L) - 143180389.0L/7200.0L) + 94330879.0L/7200.0L) - 13930849.0L/2880.0L) + 695741.0L/900.0L) - 1.0L/320.0L) + 323.0L/5760.0L) + 323.0L/5760.0L) - 1669.0L/4320.0L) - 1669.0L/4320.0L) + 5.0L/6.0L) + 5.0L/6.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((6009839.0L/20160.0L)*x - 6009839.0L/2688.0L) + 124796353.0L/17280.0L) - 7038031.0L/540.0L) + 143180389.0L/10080.0L) - 1131970547.0L/120960.0L) + 15478721.0L/4480.0L) - 11131867.0L/20160.0L) + 17.0L/5040.0L) - 13.0L/480.0L) - 13.0L/240.0L) + 4369.0L/30240.0L) + 4369.0L/15120.0L) - 5.0L/42.0L) - 5.0L/21.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/40320.0L*x + 6009839.0L/5376.0L) - 124796353.0L/34560.0L) + 7038031.0L/1080.0L) - 143180389.0L/20160.0L) + 80855039.0L/17280.0L) - 29851819.0L/17280.0L) + 1855313.0L/6720.0L) - 23.0L/13440.0L) + 29.0L/3840.0L) + 29.0L/1280.0L) - 541.0L/20160.0L) - 541.0L/6720.0L) + 5.0L/252.0L) + 5.0L/84.0L);
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((6009839.0L/120960.0L)*x - 6009839.0L/16128.0L) + 124796353.0L/103680.0L) - 7038031.0L/3240.0L) + 143180389.0L/60480.0L) - 2794989.0L/1792.0L) + 15478721.0L/26880.0L) - 695743.0L/7560.0L) + 13.0L/30240.0L) - 19.0L/17280.0L) - 19.0L/4320.0L) + 1261.0L/362880.0L) + 1261.0L/90720.0L) - 5.0L/2016.0L) - 5.0L/504.0L);
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/604800.0L*x + 6009839.0L/80640.0L) - 124796353.0L/518400.0L) + 7038031.0L/16200.0L) - 143180389.0L/302400.0L) + 70748159.0L/226800.0L) - 13930849.0L/120960.0L) + 463829.0L/25200.0L) - 1.0L/24192.0L) + 13.0L/172800.0L) + 13.0L/34560.0L) - 41.0L/181440.0L) - 41.0L/36288.0L) + 1.0L/6300.0L) + 1.0L/1260.0L);
poly_val[11] = pow(x, 8)*(x*(x*(x*(x*(x*(x*((546349.0L/604800.0L)*x - 546349.0L/80640.0L) + 11345123.0L/518400.0L) - 639821.0L/16200.0L) + 13016399.0L/302400.0L) - 102906413.0L/3628800.0L) + 1519729.0L/145152.0L) - 1011991.0L/604800.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-546349.0L/40320.0L*x + 546349.0L/5760.0L) - 147486599.0L/518400.0L) + 639821.0L/1350.0L) - 143180389.0L/302400.0L) + 5717023.0L/20160.0L) - 422147.0L/4480.0L) + 505993.0L/37800.0L) + 1.0L/3456.0L) + 13.0L/28800.0L) - 13.0L/6912.0L) - 41.0L/45360.0L) + 41.0L/12096.0L) + 1.0L/3150.0L) - 1.0L/1260.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((6009839.0L/40320.0L)*x - 6009839.0L/5760.0L) + 1622352589.0L/518400.0L) - 7038031.0L/1350.0L) + 1574984279.0L/302400.0L) - 161710079.0L/51840.0L) + 3980243.0L/3840.0L) - 927653.0L/6300.0L) - 13.0L/4320.0L) - 19.0L/2880.0L) + 19.0L/864.0L) + 1261.0L/90720.0L) - 1261.0L/30240.0L) - 5.0L/1008.0L) + 5.0L/504.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/8064.0L*x + 6009839.0L/1152.0L) - 1622352589.0L/103680.0L) + 7038031.0L/270.0L) - 1574984279.0L/60480.0L) + 141496319.0L/9072.0L) - 208962751.0L/40320.0L) + 1391479.0L/1890.0L) + 23.0L/1920.0L) + 29.0L/640.0L) - 29.0L/256.0L) - 541.0L/5040.0L) + 541.0L/2240.0L) + 5.0L/126.0L) - 5.0L/84.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((6009839.0L/2688.0L)*x - 6009839.0L/384.0L) + 1622352589.0L/34560.0L) - 7038031.0L/90.0L) + 1574984279.0L/20160.0L) - 377323517.0L/8064.0L) + 139308497.0L/8960.0L) - 3710611.0L/1680.0L) - 17.0L/720.0L) - 13.0L/80.0L) + 13.0L/48.0L) + 4369.0L/7560.0L) - 4369.0L/5040.0L) - 5.0L/21.0L) + 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/1344.0L*x + 6009839.0L/192.0L) - 1622352589.0L/17280.0L) + 7038031.0L/45.0L) - 1574984279.0L/10080.0L) + 565985275.0L/6048.0L) - 69654247.0L/2240.0L) + 5565919.0L/1260.0L) + 7.0L/320.0L) + 323.0L/960.0L) - 323.0L/1152.0L) - 1669.0L/1080.0L) + 1669.0L/1440.0L) + 5.0L/3.0L) - 5.0L/6.0L;
poly_val[5] = x*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*((6009839.0L/960.0L)*x - 42068873.0L/960.0L) + 11356468123.0L/86400.0L) - 49266217.0L/225.0L) + 1574984279.0L/7200.0L) - 1131970549.0L/8640.0L) + 16717019.0L/384.0L) - 5565923.0L/900.0L) - 341.0L/800.0L) + 1529.0L/720.0L) - 5269.0L/1800.0L);
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/960.0L*x + 42068873.0L/960.0L) - 11356468123.0L/86400.0L) + 49266217.0L/225.0L) - 1574984279.0L/7200.0L) + 94330879.0L/720.0L) - 13930849.0L/320.0L) + 1391482.0L/225.0L) - 7.0L/320.0L) + 323.0L/960.0L) + 323.0L/1152.0L) - 1669.0L/1080.0L) - 1669.0L/1440.0L) + 5.0L/3.0L) + 5.0L/6.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((6009839.0L/1344.0L)*x - 6009839.0L/192.0L) + 1622352589.0L/17280.0L) - 7038031.0L/45.0L) + 1574984279.0L/10080.0L) - 1131970547.0L/12096.0L) + 139308489.0L/4480.0L) - 11131867.0L/2520.0L) + 17.0L/720.0L) - 13.0L/80.0L) - 13.0L/48.0L) + 4369.0L/7560.0L) + 4369.0L/5040.0L) - 5.0L/21.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/2688.0L*x + 6009839.0L/384.0L) - 1622352589.0L/34560.0L) + 7038031.0L/90.0L) - 1574984279.0L/20160.0L) + 80855039.0L/1728.0L) - 29851819.0L/1920.0L) + 1855313.0L/840.0L) - 23.0L/1920.0L) + 29.0L/640.0L) + 29.0L/256.0L) - 541.0L/5040.0L) - 541.0L/2240.0L) + 5.0L/126.0L) + 5.0L/84.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((6009839.0L/8064.0L)*x - 6009839.0L/1152.0L) + 1622352589.0L/103680.0L) - 7038031.0L/270.0L) + 1574984279.0L/60480.0L) - 13974945.0L/896.0L) + 46436163.0L/8960.0L) - 695743.0L/945.0L) + 13.0L/4320.0L) - 19.0L/2880.0L) - 19.0L/864.0L) + 1261.0L/90720.0L) + 1261.0L/30240.0L) - 5.0L/1008.0L) - 5.0L/504.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/40320.0L*x + 6009839.0L/5760.0L) - 1622352589.0L/518400.0L) + 7038031.0L/1350.0L) - 1574984279.0L/302400.0L) + 70748159.0L/22680.0L) - 13930849.0L/13440.0L) + 463829.0L/3150.0L) - 1.0L/3456.0L) + 13.0L/28800.0L) + 13.0L/6912.0L) - 41.0L/45360.0L) - 41.0L/12096.0L) + 1.0L/3150.0L) + 1.0L/1260.0L;
poly_val[11] = pow(x, 7)*(x*(x*(x*(x*(x*(x*((546349.0L/40320.0L)*x - 546349.0L/5760.0L) + 147486599.0L/518400.0L) - 639821.0L/1350.0L) + 143180389.0L/302400.0L) - 102906413.0L/362880.0L) + 1519729.0L/16128.0L) - 1011991.0L/75600.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-546349.0L/2880.0L*x + 7102537.0L/5760.0L) - 147486599.0L/43200.0L) + 7038031.0L/1350.0L) - 143180389.0L/30240.0L) + 5717023.0L/2240.0L) - 422147.0L/560.0L) + 505993.0L/5400.0L) + 1.0L/576.0L) + 13.0L/5760.0L) - 13.0L/1728.0L) - 41.0L/15120.0L) + 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((6009839.0L/2880.0L)*x - 78127907.0L/5760.0L) + 1622352589.0L/43200.0L) - 77418341.0L/1350.0L) + 1574984279.0L/30240.0L) - 161710079.0L/5760.0L) + 3980243.0L/480.0L) - 927653.0L/900.0L) - 13.0L/720.0L) - 19.0L/576.0L) + 19.0L/216.0L) + 1261.0L/30240.0L) - 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/576.0L*x + 78127907.0L/1152.0L) - 1622352589.0L/8640.0L) + 77418341.0L/270.0L) - 1574984279.0L/6048.0L) + 141496319.0L/1008.0L) - 208962751.0L/5040.0L) + 1391479.0L/270.0L) + 23.0L/320.0L) + 29.0L/128.0L) - 29.0L/64.0L) - 541.0L/1680.0L) + 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((6009839.0L/192.0L)*x - 78127907.0L/384.0L) + 1622352589.0L/2880.0L) - 77418341.0L/90.0L) + 1574984279.0L/2016.0L) - 377323517.0L/896.0L) + 139308497.0L/1120.0L) - 3710611.0L/240.0L) - 17.0L/120.0L) - 13.0L/16.0L) + 13.0L/12.0L) + 4369.0L/2520.0L) - 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/96.0L*x + 78127907.0L/192.0L) - 1622352589.0L/1440.0L) + 77418341.0L/45.0L) - 1574984279.0L/1008.0L) + 565985275.0L/672.0L) - 69654247.0L/280.0L) + 5565919.0L/180.0L) + 21.0L/160.0L) + 323.0L/192.0L) - 323.0L/288.0L) - 1669.0L/360.0L) + 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[5] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*((42068873.0L/480.0L)*x - 546895349.0L/960.0L) + 11356468123.0L/7200.0L) - 541928387.0L/225.0L) + 1574984279.0L/720.0L) - 1131970549.0L/960.0L) + 16717019.0L/48.0L) - 38961461.0L/900.0L) - 341.0L/160.0L) + 1529.0L/240.0L) - 5269.0L/1800.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-42068873.0L/480.0L*x + 546895349.0L/960.0L) - 11356468123.0L/7200.0L) + 541928387.0L/225.0L) - 1574984279.0L/720.0L) + 94330879.0L/80.0L) - 13930849.0L/40.0L) + 9740374.0L/225.0L) - 21.0L/160.0L) + 323.0L/192.0L) + 323.0L/288.0L) - 1669.0L/360.0L) - 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((6009839.0L/96.0L)*x - 78127907.0L/192.0L) + 1622352589.0L/1440.0L) - 77418341.0L/45.0L) + 1574984279.0L/1008.0L) - 1131970547.0L/1344.0L) + 139308489.0L/560.0L) - 11131867.0L/360.0L) + 17.0L/120.0L) - 13.0L/16.0L) - 13.0L/12.0L) + 4369.0L/2520.0L) + 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/192.0L*x + 78127907.0L/384.0L) - 1622352589.0L/2880.0L) + 77418341.0L/90.0L) - 1574984279.0L/2016.0L) + 80855039.0L/192.0L) - 29851819.0L/240.0L) + 1855313.0L/120.0L) - 23.0L/320.0L) + 29.0L/128.0L) + 29.0L/64.0L) - 541.0L/1680.0L) - 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((6009839.0L/576.0L)*x - 78127907.0L/1152.0L) + 1622352589.0L/8640.0L) - 77418341.0L/270.0L) + 1574984279.0L/6048.0L) - 125774505.0L/896.0L) + 46436163.0L/1120.0L) - 695743.0L/135.0L) + 13.0L/720.0L) - 19.0L/576.0L) - 19.0L/216.0L) + 1261.0L/30240.0L) + 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-6009839.0L/2880.0L*x + 78127907.0L/5760.0L) - 1622352589.0L/43200.0L) + 77418341.0L/1350.0L) - 1574984279.0L/30240.0L) + 70748159.0L/2520.0L) - 13930849.0L/1680.0L) + 463829.0L/450.0L) - 1.0L/576.0L) + 13.0L/5760.0L) + 13.0L/1728.0L) - 41.0L/15120.0L) - 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[11] = pow(x, 6)*(x*(x*(x*(x*(x*(x*((546349.0L/2880.0L)*x - 7102537.0L/5760.0L) + 147486599.0L/43200.0L) - 7038031.0L/1350.0L) + 143180389.0L/30240.0L) - 102906413.0L/40320.0L) + 1519729.0L/2016.0L) - 1011991.0L/10800.0L);
break;
}
}
void beta_n5_m8(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((1011991.0L/302400.0L)*x - 17203847.0L/604800.0L) + 285427.0L/2688.0L) - 55032449.0L/241920.0L) + 31733873.0L/103680.0L) - 34349081.0L/129600.0L) + 14551699.0L/100800.0L) - 5475307.0L/120960.0L) + 757541.0L/120960.0L) - 1.0L/120960.0L) + 1.0L/24192.0L) + 13.0L/172800.0L) - 13.0L/34560.0L) - 41.0L/181440.0L) + 41.0L/36288.0L) + 1.0L/6300.0L) - 1.0L/1260.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-11131901.0L/302400.0L*x + 189242317.0L/604800.0L) - 3139697.0L/2688.0L) + 605356939.0L/241920.0L) - 349072603.0L/103680.0L) + 377839891.0L/129600.0L) - 160068689.0L/100800.0L) + 1806851311.0L/3628800.0L) - 1851767.0L/26880.0L) + 13.0L/120960.0L) - 13.0L/30240.0L) - 19.0L/17280.0L) + 19.0L/4320.0L) + 1261.0L/362880.0L) - 1261.0L/90720.0L) - 5.0L/2016.0L) + 5.0L/504.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((11131901.0L/60480.0L)*x - 189242317.0L/120960.0L) + 15698485.0L/2688.0L) - 605356939.0L/48384.0L) + 349072603.0L/20736.0L) - 377839891.0L/25920.0L) + 160068689.0L/20160.0L) - 16132601.0L/6480.0L) + 124994279.0L/362880.0L) - 23.0L/40320.0L) + 23.0L/13440.0L) + 29.0L/3840.0L) - 29.0L/1280.0L) - 541.0L/20160.0L) + 541.0L/6720.0L) + 5.0L/252.0L) - 5.0L/84.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-11131901.0L/20160.0L*x + 189242317.0L/40320.0L) - 15698485.0L/896.0L) + 605356939.0L/16128.0L) - 349072603.0L/6912.0L) + 377839891.0L/8640.0L) - 160068689.0L/6720.0L) + 66920419.0L/8960.0L) - 83329523.0L/80640.0L) + 17.0L/10080.0L) - 17.0L/5040.0L) - 13.0L/480.0L) + 13.0L/240.0L) + 4369.0L/30240.0L) - 4369.0L/15120.0L) - 5.0L/42.0L) + 5.0L/21.0L);
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((11131901.0L/10080.0L)*x - 189242317.0L/20160.0L) + 15698485.0L/448.0L) - 605356939.0L/8064.0L) + 349072603.0L/3456.0L) - 377839891.0L/4320.0L) + 160068689.0L/3360.0L) - 903425657.0L/60480.0L) + 5952109.0L/2880.0L) - 1.0L/320.0L) + 1.0L/320.0L) + 323.0L/5760.0L) - 323.0L/5760.0L) - 1669.0L/4320.0L) + 1669.0L/4320.0L) + 5.0L/6.0L) - 5.0L/6.0L);
poly_val[5] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(x*(x*(-11131901.0L/7200.0L*x + 189242317.0L/14400.0L) - 3139697.0L/64.0L) + 605356939.0L/5760.0L) - 2443508221.0L/17280.0L) + 2644879237.0L/21600.0L) - 160068689.0L/2400.0L) + 361370263.0L/17280.0L) - 49997717.0L/17280.0L) + 11.0L/2880.0L) - 341.0L/4800.0L) + 1529.0L/2880.0L) - 5269.0L/3600.0L) + 1;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((11131901.0L/7200.0L)*x - 189242317.0L/14400.0L) + 3139697.0L/64.0L) - 605356939.0L/5760.0L) + 2443508221.0L/17280.0L) - 2644879237.0L/21600.0L) + 160068689.0L/2400.0L) - 150570943.0L/7200.0L) + 2777651.0L/960.0L) - 1.0L/320.0L) - 1.0L/320.0L) + 323.0L/5760.0L) + 323.0L/5760.0L) - 1669.0L/4320.0L) - 1669.0L/4320.0L) + 5.0L/6.0L) + 5.0L/6.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-11131901.0L/10080.0L*x + 189242317.0L/20160.0L) - 15698485.0L/448.0L) + 605356939.0L/8064.0L) - 349072603.0L/3456.0L) + 377839891.0L/4320.0L) - 160068689.0L/3360.0L) + 1806851317.0L/120960.0L) - 83329531.0L/40320.0L) + 17.0L/10080.0L) + 17.0L/5040.0L) - 13.0L/480.0L) - 13.0L/240.0L) + 4369.0L/30240.0L) + 4369.0L/15120.0L) - 5.0L/42.0L) - 5.0L/21.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((11131901.0L/20160.0L)*x - 189242317.0L/40320.0L) + 15698485.0L/896.0L) - 605356939.0L/16128.0L) + 349072603.0L/6912.0L) - 377839891.0L/8640.0L) + 160068689.0L/6720.0L) - 903425659.0L/120960.0L) + 124994297.0L/120960.0L) - 23.0L/40320.0L) - 23.0L/13440.0L) + 29.0L/3840.0L) + 29.0L/1280.0L) - 541.0L/20160.0L) - 541.0L/6720.0L) + 5.0L/252.0L) + 5.0L/84.0L);
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-11131901.0L/60480.0L*x + 189242317.0L/120960.0L) - 15698485.0L/2688.0L) + 605356939.0L/48384.0L) - 349072603.0L/20736.0L) + 377839891.0L/25920.0L) - 160068689.0L/20160.0L) + 86040539.0L/34560.0L) - 83329531.0L/241920.0L) + 13.0L/120960.0L) + 13.0L/30240.0L) - 19.0L/17280.0L) - 19.0L/4320.0L) + 1261.0L/362880.0L) + 1261.0L/90720.0L) - 5.0L/2016.0L) - 5.0L/504.0L);
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((11131901.0L/302400.0L)*x - 189242317.0L/604800.0L) + 3139697.0L/2688.0L) - 605356939.0L/241920.0L) + 349072603.0L/103680.0L) - 377839891.0L/129600.0L) + 160068689.0L/100800.0L) - 45171283.0L/90720.0L) + 2777651.0L/40320.0L) - 1.0L/120960.0L) - 1.0L/24192.0L) + 13.0L/172800.0L) + 13.0L/34560.0L) - 41.0L/181440.0L) - 41.0L/36288.0L) + 1.0L/6300.0L) + 1.0L/1260.0L);
poly_val[11] = pow(x, 9)*(x*(x*(x*(x*(x*(x*(x*(-1011991.0L/302400.0L*x + 17203847.0L/604800.0L) - 285427.0L/2688.0L) + 55032449.0L/241920.0L) - 31733873.0L/103680.0L) + 34349081.0L/129600.0L) - 14551699.0L/100800.0L) + 164259211.0L/3628800.0L) - 649321.0L/103680.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((17203847.0L/302400.0L)*x - 17203847.0L/37800.0L) + 1427135.0L/896.0L) - 55032449.0L/17280.0L) + 412540349.0L/103680.0L) - 34349081.0L/10800.0L) + 160068689.0L/100800.0L) - 5475307.0L/12096.0L) + 757541.0L/13440.0L) - 1.0L/15120.0L) + 1.0L/3456.0L) + 13.0L/28800.0L) - 13.0L/6912.0L) - 41.0L/45360.0L) + 41.0L/12096.0L) + 1.0L/3150.0L) - 1.0L/1260.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-189242317.0L/302400.0L*x + 189242317.0L/37800.0L) - 15698485.0L/896.0L) + 605356939.0L/17280.0L) - 4537943839.0L/103680.0L) + 377839891.0L/10800.0L) - 1760755579.0L/100800.0L) + 1806851311.0L/362880.0L) - 5555301.0L/8960.0L) + 13.0L/15120.0L) - 13.0L/4320.0L) - 19.0L/2880.0L) + 19.0L/864.0L) + 1261.0L/90720.0L) - 1261.0L/30240.0L) - 5.0L/1008.0L) + 5.0L/504.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((189242317.0L/60480.0L)*x - 189242317.0L/7560.0L) + 78492425.0L/896.0L) - 605356939.0L/3456.0L) + 4537943839.0L/20736.0L) - 377839891.0L/2160.0L) + 1760755579.0L/20160.0L) - 16132601.0L/648.0L) + 124994279.0L/40320.0L) - 23.0L/5040.0L) + 23.0L/1920.0L) + 29.0L/640.0L) - 29.0L/256.0L) - 541.0L/5040.0L) + 541.0L/2240.0L) + 5.0L/126.0L) - 5.0L/84.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-189242317.0L/20160.0L*x + 189242317.0L/2520.0L) - 235477275.0L/896.0L) + 605356939.0L/1152.0L) - 4537943839.0L/6912.0L) + 377839891.0L/720.0L) - 1760755579.0L/6720.0L) + 66920419.0L/896.0L) - 83329523.0L/8960.0L) + 17.0L/1260.0L) - 17.0L/720.0L) - 13.0L/80.0L) + 13.0L/48.0L) + 4369.0L/7560.0L) - 4369.0L/5040.0L) - 5.0L/21.0L) + 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((189242317.0L/10080.0L)*x - 189242317.0L/1260.0L) + 235477275.0L/448.0L) - 605356939.0L/576.0L) + 4537943839.0L/3456.0L) - 377839891.0L/360.0L) + 1760755579.0L/3360.0L) - 903425657.0L/6048.0L) + 5952109.0L/320.0L) - 1.0L/40.0L) + 7.0L/320.0L) + 323.0L/960.0L) - 323.0L/1152.0L) - 1669.0L/1080.0L) + 1669.0L/1440.0L) + 5.0L/3.0L) - 5.0L/6.0L;
poly_val[5] = x*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(x*(x*(-189242317.0L/7200.0L*x + 189242317.0L/900.0L) - 47095455.0L/64.0L) + 4237498573.0L/2880.0L) - 31765606873.0L/17280.0L) + 2644879237.0L/1800.0L) - 1760755579.0L/2400.0L) + 361370263.0L/1728.0L) - 49997717.0L/1920.0L) + 11.0L/360.0L) - 341.0L/800.0L) + 1529.0L/720.0L) - 5269.0L/1800.0L);
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((189242317.0L/7200.0L)*x - 189242317.0L/900.0L) + 47095455.0L/64.0L) - 4237498573.0L/2880.0L) + 31765606873.0L/17280.0L) - 2644879237.0L/1800.0L) + 1760755579.0L/2400.0L) - 150570943.0L/720.0L) + 8332953.0L/320.0L) - 1.0L/40.0L) - 7.0L/320.0L) + 323.0L/960.0L) + 323.0L/1152.0L) - 1669.0L/1080.0L) - 1669.0L/1440.0L) + 5.0L/3.0L) + 5.0L/6.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-189242317.0L/10080.0L*x + 189242317.0L/1260.0L) - 235477275.0L/448.0L) + 605356939.0L/576.0L) - 4537943839.0L/3456.0L) + 377839891.0L/360.0L) - 1760755579.0L/3360.0L) + 1806851317.0L/12096.0L) - 83329531.0L/4480.0L) + 17.0L/1260.0L) + 17.0L/720.0L) - 13.0L/80.0L) - 13.0L/48.0L) + 4369.0L/7560.0L) + 4369.0L/5040.0L) - 5.0L/21.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((189242317.0L/20160.0L)*x - 189242317.0L/2520.0L) + 235477275.0L/896.0L) - 605356939.0L/1152.0L) + 4537943839.0L/6912.0L) - 377839891.0L/720.0L) + 1760755579.0L/6720.0L) - 903425659.0L/12096.0L) + 124994297.0L/13440.0L) - 23.0L/5040.0L) - 23.0L/1920.0L) + 29.0L/640.0L) + 29.0L/256.0L) - 541.0L/5040.0L) - 541.0L/2240.0L) + 5.0L/126.0L) + 5.0L/84.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-189242317.0L/60480.0L*x + 189242317.0L/7560.0L) - 78492425.0L/896.0L) + 605356939.0L/3456.0L) - 4537943839.0L/20736.0L) + 377839891.0L/2160.0L) - 1760755579.0L/20160.0L) + 86040539.0L/3456.0L) - 83329531.0L/26880.0L) + 13.0L/15120.0L) + 13.0L/4320.0L) - 19.0L/2880.0L) - 19.0L/864.0L) + 1261.0L/90720.0L) + 1261.0L/30240.0L) - 5.0L/1008.0L) - 5.0L/504.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((189242317.0L/302400.0L)*x - 189242317.0L/37800.0L) + 15698485.0L/896.0L) - 605356939.0L/17280.0L) + 4537943839.0L/103680.0L) - 377839891.0L/10800.0L) + 1760755579.0L/100800.0L) - 45171283.0L/9072.0L) + 2777651.0L/4480.0L) - 1.0L/15120.0L) - 1.0L/3456.0L) + 13.0L/28800.0L) + 13.0L/6912.0L) - 41.0L/45360.0L) - 41.0L/12096.0L) + 1.0L/3150.0L) + 1.0L/1260.0L;
poly_val[11] = pow(x, 8)*(x*(x*(x*(x*(x*(x*(x*(-17203847.0L/302400.0L*x + 17203847.0L/37800.0L) - 1427135.0L/896.0L) + 55032449.0L/17280.0L) - 412540349.0L/103680.0L) + 34349081.0L/10800.0L) - 160068689.0L/100800.0L) + 164259211.0L/362880.0L) - 649321.0L/11520.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((17203847.0L/18900.0L)*x - 17203847.0L/2520.0L) + 1427135.0L/64.0L) - 715421837.0L/17280.0L) + 412540349.0L/8640.0L) - 377839891.0L/10800.0L) + 160068689.0L/10080.0L) - 5475307.0L/1344.0L) + 757541.0L/1680.0L) - 1.0L/2160.0L) + 1.0L/576.0L) + 13.0L/5760.0L) - 13.0L/1728.0L) - 41.0L/15120.0L) + 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-189242317.0L/18900.0L*x + 189242317.0L/2520.0L) - 15698485.0L/64.0L) + 7869640207.0L/17280.0L) - 4537943839.0L/8640.0L) + 4156238801.0L/10800.0L) - 1760755579.0L/10080.0L) + 1806851311.0L/40320.0L) - 5555301.0L/1120.0L) + 13.0L/2160.0L) - 13.0L/720.0L) - 19.0L/576.0L) + 19.0L/216.0L) + 1261.0L/30240.0L) - 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((189242317.0L/3780.0L)*x - 189242317.0L/504.0L) + 78492425.0L/64.0L) - 7869640207.0L/3456.0L) + 4537943839.0L/1728.0L) - 4156238801.0L/2160.0L) + 1760755579.0L/2016.0L) - 16132601.0L/72.0L) + 124994279.0L/5040.0L) - 23.0L/720.0L) + 23.0L/320.0L) + 29.0L/128.0L) - 29.0L/64.0L) - 541.0L/1680.0L) + 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-189242317.0L/1260.0L*x + 189242317.0L/168.0L) - 235477275.0L/64.0L) + 7869640207.0L/1152.0L) - 4537943839.0L/576.0L) + 4156238801.0L/720.0L) - 1760755579.0L/672.0L) + 602283771.0L/896.0L) - 83329523.0L/1120.0L) + 17.0L/180.0L) - 17.0L/120.0L) - 13.0L/16.0L) + 13.0L/12.0L) + 4369.0L/2520.0L) - 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((189242317.0L/630.0L)*x - 189242317.0L/84.0L) + 235477275.0L/32.0L) - 7869640207.0L/576.0L) + 4537943839.0L/288.0L) - 4156238801.0L/360.0L) + 1760755579.0L/336.0L) - 903425657.0L/672.0L) + 5952109.0L/40.0L) - 7.0L/40.0L) + 21.0L/160.0L) + 323.0L/192.0L) - 323.0L/288.0L) - 1669.0L/360.0L) + 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[5] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(x*(x*(-189242317.0L/450.0L*x + 189242317.0L/60.0L) - 329668185.0L/32.0L) + 55087481449.0L/2880.0L) - 31765606873.0L/1440.0L) + 29093671607.0L/1800.0L) - 1760755579.0L/240.0L) + 361370263.0L/192.0L) - 49997717.0L/240.0L) + 77.0L/360.0L) - 341.0L/160.0L) + 1529.0L/240.0L) - 5269.0L/1800.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((189242317.0L/450.0L)*x - 189242317.0L/60.0L) + 329668185.0L/32.0L) - 55087481449.0L/2880.0L) + 31765606873.0L/1440.0L) - 29093671607.0L/1800.0L) + 1760755579.0L/240.0L) - 150570943.0L/80.0L) + 8332953.0L/40.0L) - 7.0L/40.0L) - 21.0L/160.0L) + 323.0L/192.0L) + 323.0L/288.0L) - 1669.0L/360.0L) - 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-189242317.0L/630.0L*x + 189242317.0L/84.0L) - 235477275.0L/32.0L) + 7869640207.0L/576.0L) - 4537943839.0L/288.0L) + 4156238801.0L/360.0L) - 1760755579.0L/336.0L) + 1806851317.0L/1344.0L) - 83329531.0L/560.0L) + 17.0L/180.0L) + 17.0L/120.0L) - 13.0L/16.0L) - 13.0L/12.0L) + 4369.0L/2520.0L) + 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((189242317.0L/1260.0L)*x - 189242317.0L/168.0L) + 235477275.0L/64.0L) - 7869640207.0L/1152.0L) + 4537943839.0L/576.0L) - 4156238801.0L/720.0L) + 1760755579.0L/672.0L) - 903425659.0L/1344.0L) + 124994297.0L/1680.0L) - 23.0L/720.0L) - 23.0L/320.0L) + 29.0L/128.0L) + 29.0L/64.0L) - 541.0L/1680.0L) - 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-189242317.0L/3780.0L*x + 189242317.0L/504.0L) - 78492425.0L/64.0L) + 7869640207.0L/3456.0L) - 4537943839.0L/1728.0L) + 4156238801.0L/2160.0L) - 1760755579.0L/2016.0L) + 86040539.0L/384.0L) - 83329531.0L/3360.0L) + 13.0L/2160.0L) + 13.0L/720.0L) - 19.0L/576.0L) - 19.0L/216.0L) + 1261.0L/30240.0L) + 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((189242317.0L/18900.0L)*x - 189242317.0L/2520.0L) + 15698485.0L/64.0L) - 7869640207.0L/17280.0L) + 4537943839.0L/8640.0L) - 4156238801.0L/10800.0L) + 1760755579.0L/10080.0L) - 45171283.0L/1008.0L) + 2777651.0L/560.0L) - 1.0L/2160.0L) - 1.0L/576.0L) + 13.0L/5760.0L) + 13.0L/1728.0L) - 41.0L/15120.0L) - 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[11] = pow(x, 7)*(x*(x*(x*(x*(x*(x*(x*(-17203847.0L/18900.0L*x + 17203847.0L/2520.0L) - 1427135.0L/64.0L) + 715421837.0L/17280.0L) - 412540349.0L/8640.0L) + 377839891.0L/10800.0L) - 160068689.0L/10080.0L) + 164259211.0L/40320.0L) - 649321.0L/1440.0L);
break;
}
}
void beta_n5_m9(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-649321.0L/51840.0L*x + 12337099.0L/103680.0L) - 609560381.0L/1209600.0L) + 83943127.0L/67200.0L) - 241689617.0L/120960.0L) + 517668673.0L/241920.0L) - 159166501.0L/103680.0L) + 46134257.0L/64800.0L) - 39075307.0L/201600.0L) + 3429175.0L/145152.0L) - 1.0L/725760.0L) - 1.0L/120960.0L) + 1.0L/24192.0L) + 13.0L/172800.0L) - 13.0L/34560.0L) - 41.0L/181440.0L) + 41.0L/36288.0L) + 1.0L/6300.0L) - 1.0L/1260.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((7142531.0L/51840.0L)*x - 135708089.0L/103680.0L) + 6705164191.0L/1209600.0L) - 923374397.0L/67200.0L) + 2658585787.0L/120960.0L) - 5694355403.0L/241920.0L) + 1750831511.0L/103680.0L) - 507476827.0L/64800.0L) + 429828377.0L/201600.0L) - 235755781.0L/907200.0L) + 1.0L/90720.0L) + 13.0L/120960.0L) - 13.0L/30240.0L) - 19.0L/17280.0L) + 19.0L/4320.0L) + 1261.0L/362880.0L) - 1261.0L/90720.0L) - 5.0L/2016.0L) + 5.0L/504.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-7142531.0L/10368.0L*x + 135708089.0L/20736.0L) - 6705164191.0L/241920.0L) + 923374397.0L/13440.0L) - 2658585787.0L/24192.0L) + 5694355403.0L/48384.0L) - 1750831511.0L/20736.0L) + 507476827.0L/12960.0L) - 429828377.0L/40320.0L) + 14968621.0L/11520.0L) - 1.0L/26880.0L) - 23.0L/40320.0L) + 23.0L/13440.0L) + 29.0L/3840.0L) - 29.0L/1280.0L) - 541.0L/20160.0L) + 541.0L/6720.0L) + 5.0L/252.0L) - 5.0L/84.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((7142531.0L/3456.0L)*x - 135708089.0L/6912.0L) + 6705164191.0L/80640.0L) - 923374397.0L/4480.0L) + 2658585787.0L/8064.0L) - 5694355403.0L/16128.0L) + 1750831511.0L/6912.0L) - 507476827.0L/4320.0L) + 429828377.0L/13440.0L) - 471511561.0L/120960.0L) + 1.0L/15120.0L) + 17.0L/10080.0L) - 17.0L/5040.0L) - 13.0L/480.0L) + 13.0L/240.0L) + 4369.0L/30240.0L) - 4369.0L/15120.0L) - 5.0L/42.0L) + 5.0L/21.0L);
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-7142531.0L/1728.0L*x + 135708089.0L/3456.0L) - 6705164191.0L/40320.0L) + 923374397.0L/2240.0L) - 2658585787.0L/4032.0L) + 5694355403.0L/8064.0L) - 1750831511.0L/3456.0L) + 507476827.0L/2160.0L) - 429828377.0L/6720.0L) + 943023121.0L/120960.0L) - 1.0L/17280.0L) - 1.0L/320.0L) + 1.0L/320.0L) + 323.0L/5760.0L) - 323.0L/5760.0L) - 1669.0L/4320.0L) + 1669.0L/4320.0L) + 5.0L/6.0L) - 5.0L/6.0L);
poly_val[5] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(x*(x*((49997717.0L/8640.0L)*x - 949956623.0L/17280.0L) + 6705164191.0L/28800.0L) - 923374397.0L/1600.0L) + 2658585787.0L/2880.0L) - 5694355403.0L/5760.0L) + 12255820577.0L/17280.0L) - 3552337789.0L/10800.0L) + 429828377.0L/4800.0L) - 3929263.0L/360.0L) + 11.0L/2880.0L) - 341.0L/4800.0L) + 1529.0L/2880.0L) - 5269.0L/3600.0L) + 1;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-49997717.0L/8640.0L*x + 949956623.0L/17280.0L) - 6705164191.0L/28800.0L) + 923374397.0L/1600.0L) - 2658585787.0L/2880.0L) + 5694355403.0L/5760.0L) - 12255820577.0L/17280.0L) + 3552337789.0L/10800.0L) - 429828377.0L/4800.0L) + 943023119.0L/86400.0L) + 1.0L/17280.0L) - 1.0L/320.0L) - 1.0L/320.0L) + 323.0L/5760.0L) + 323.0L/5760.0L) - 1669.0L/4320.0L) - 1669.0L/4320.0L) + 5.0L/6.0L) + 5.0L/6.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((7142531.0L/1728.0L)*x - 135708089.0L/3456.0L) + 6705164191.0L/40320.0L) - 923374397.0L/2240.0L) + 2658585787.0L/4032.0L) - 5694355403.0L/8064.0L) + 1750831511.0L/3456.0L) - 507476827.0L/2160.0L) + 429828377.0L/6720.0L) - 471511559.0L/60480.0L) - 1.0L/15120.0L) + 17.0L/10080.0L) + 17.0L/5040.0L) - 13.0L/480.0L) - 13.0L/240.0L) + 4369.0L/30240.0L) + 4369.0L/15120.0L) - 5.0L/42.0L) - 5.0L/21.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-7142531.0L/3456.0L*x + 135708089.0L/6912.0L) - 6705164191.0L/80640.0L) + 923374397.0L/4480.0L) - 2658585787.0L/8064.0L) + 5694355403.0L/16128.0L) - 1750831511.0L/6912.0L) + 507476827.0L/4320.0L) - 429828377.0L/13440.0L) + 314341039.0L/80640.0L) + 1.0L/26880.0L) - 23.0L/40320.0L) - 23.0L/13440.0L) + 29.0L/3840.0L) + 29.0L/1280.0L) - 541.0L/20160.0L) - 541.0L/6720.0L) + 5.0L/252.0L) + 5.0L/84.0L);
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((7142531.0L/10368.0L)*x - 135708089.0L/20736.0L) + 6705164191.0L/241920.0L) - 923374397.0L/13440.0L) + 2658585787.0L/24192.0L) - 5694355403.0L/48384.0L) + 1750831511.0L/20736.0L) - 507476827.0L/12960.0L) + 429828377.0L/40320.0L) - 33679397.0L/25920.0L) - 1.0L/90720.0L) + 13.0L/120960.0L) + 13.0L/30240.0L) - 19.0L/17280.0L) - 19.0L/4320.0L) + 1261.0L/362880.0L) + 1261.0L/90720.0L) - 5.0L/2016.0L) - 5.0L/504.0L);
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-7142531.0L/51840.0L*x + 135708089.0L/103680.0L) - 6705164191.0L/1209600.0L) + 923374397.0L/67200.0L) - 2658585787.0L/120960.0L) + 5694355403.0L/241920.0L) - 1750831511.0L/103680.0L) + 507476827.0L/64800.0L) - 429828377.0L/201600.0L) + 188604623.0L/725760.0L) + 1.0L/725760.0L) - 1.0L/120960.0L) - 1.0L/24192.0L) + 13.0L/172800.0L) + 13.0L/34560.0L) - 41.0L/181440.0L) - 41.0L/36288.0L) + 1.0L/6300.0L) + 1.0L/1260.0L);
poly_val[11] = pow(x, 10)*(x*(x*(x*(x*(x*(x*(x*(x*((649321.0L/51840.0L)*x - 12337099.0L/103680.0L) + 609560381.0L/1209600.0L) - 83943127.0L/67200.0L) + 241689617.0L/120960.0L) - 517668673.0L/241920.0L) + 159166501.0L/103680.0L) - 46134257.0L/64800.0L) + 39075307.0L/201600.0L) - 1587581.0L/67200.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-12337099.0L/51840.0L*x + 12337099.0L/5760.0L) - 10362526477.0L/1209600.0L) + 83943127.0L/4200.0L) - 241689617.0L/8064.0L) + 517668673.0L/17280.0L) - 2069164513.0L/103680.0L) + 46134257.0L/5400.0L) - 429828377.0L/201600.0L) + 17145875.0L/72576.0L) - 1.0L/80640.0L) - 1.0L/15120.0L) + 1.0L/3456.0L) + 13.0L/28800.0L) - 13.0L/6912.0L) - 41.0L/45360.0L) + 41.0L/12096.0L) + 1.0L/3150.0L) - 1.0L/1260.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((135708089.0L/51840.0L)*x - 135708089.0L/5760.0L) + 113987791247.0L/1209600.0L) - 923374397.0L/4200.0L) + 2658585787.0L/8064.0L) - 5694355403.0L/17280.0L) + 22760809643.0L/103680.0L) - 507476827.0L/5400.0L) + 4728112147.0L/201600.0L) - 235755781.0L/90720.0L) + 1.0L/10080.0L) + 13.0L/15120.0L) - 13.0L/4320.0L) - 19.0L/2880.0L) + 19.0L/864.0L) + 1261.0L/90720.0L) - 1261.0L/30240.0L) - 5.0L/1008.0L) + 5.0L/504.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-135708089.0L/10368.0L*x + 135708089.0L/1152.0L) - 113987791247.0L/241920.0L) + 923374397.0L/840.0L) - 13292928935.0L/8064.0L) + 5694355403.0L/3456.0L) - 22760809643.0L/20736.0L) + 507476827.0L/1080.0L) - 4728112147.0L/40320.0L) + 14968621.0L/1152.0L) - 3.0L/8960.0L) - 23.0L/5040.0L) + 23.0L/1920.0L) + 29.0L/640.0L) - 29.0L/256.0L) - 541.0L/5040.0L) + 541.0L/2240.0L) + 5.0L/126.0L) - 5.0L/84.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((135708089.0L/3456.0L)*x - 135708089.0L/384.0L) + 113987791247.0L/80640.0L) - 923374397.0L/280.0L) + 13292928935.0L/2688.0L) - 5694355403.0L/1152.0L) + 22760809643.0L/6912.0L) - 507476827.0L/360.0L) + 4728112147.0L/13440.0L) - 471511561.0L/12096.0L) + 1.0L/1680.0L) + 17.0L/1260.0L) - 17.0L/720.0L) - 13.0L/80.0L) + 13.0L/48.0L) + 4369.0L/7560.0L) - 4369.0L/5040.0L) - 5.0L/21.0L) + 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-135708089.0L/1728.0L*x + 135708089.0L/192.0L) - 113987791247.0L/40320.0L) + 923374397.0L/140.0L) - 13292928935.0L/1344.0L) + 5694355403.0L/576.0L) - 22760809643.0L/3456.0L) + 507476827.0L/180.0L) - 4728112147.0L/6720.0L) + 943023121.0L/12096.0L) - 1.0L/1920.0L) - 1.0L/40.0L) + 7.0L/320.0L) + 323.0L/960.0L) - 323.0L/1152.0L) - 1669.0L/1080.0L) + 1669.0L/1440.0L) + 5.0L/3.0L) - 5.0L/6.0L;
poly_val[5] = x*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(x*(x*((949956623.0L/8640.0L)*x - 949956623.0L/960.0L) + 113987791247.0L/28800.0L) - 923374397.0L/100.0L) + 2658585787.0L/192.0L) - 39860487821.0L/2880.0L) + 159325667501.0L/17280.0L) - 3552337789.0L/900.0L) + 4728112147.0L/4800.0L) - 3929263.0L/36.0L) + 11.0L/360.0L) - 341.0L/800.0L) + 1529.0L/720.0L) - 5269.0L/1800.0L);
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-949956623.0L/8640.0L*x + 949956623.0L/960.0L) - 113987791247.0L/28800.0L) + 923374397.0L/100.0L) - 2658585787.0L/192.0L) + 39860487821.0L/2880.0L) - 159325667501.0L/17280.0L) + 3552337789.0L/900.0L) - 4728112147.0L/4800.0L) + 943023119.0L/8640.0L) + 1.0L/1920.0L) - 1.0L/40.0L) - 7.0L/320.0L) + 323.0L/960.0L) + 323.0L/1152.0L) - 1669.0L/1080.0L) - 1669.0L/1440.0L) + 5.0L/3.0L) + 5.0L/6.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((135708089.0L/1728.0L)*x - 135708089.0L/192.0L) + 113987791247.0L/40320.0L) - 923374397.0L/140.0L) + 13292928935.0L/1344.0L) - 5694355403.0L/576.0L) + 22760809643.0L/3456.0L) - 507476827.0L/180.0L) + 4728112147.0L/6720.0L) - 471511559.0L/6048.0L) - 1.0L/1680.0L) + 17.0L/1260.0L) + 17.0L/720.0L) - 13.0L/80.0L) - 13.0L/48.0L) + 4369.0L/7560.0L) + 4369.0L/5040.0L) - 5.0L/21.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-135708089.0L/3456.0L*x + 135708089.0L/384.0L) - 113987791247.0L/80640.0L) + 923374397.0L/280.0L) - 13292928935.0L/2688.0L) + 5694355403.0L/1152.0L) - 22760809643.0L/6912.0L) + 507476827.0L/360.0L) - 4728112147.0L/13440.0L) + 314341039.0L/8064.0L) + 3.0L/8960.0L) - 23.0L/5040.0L) - 23.0L/1920.0L) + 29.0L/640.0L) + 29.0L/256.0L) - 541.0L/5040.0L) - 541.0L/2240.0L) + 5.0L/126.0L) + 5.0L/84.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((135708089.0L/10368.0L)*x - 135708089.0L/1152.0L) + 113987791247.0L/241920.0L) - 923374397.0L/840.0L) + 13292928935.0L/8064.0L) - 5694355403.0L/3456.0L) + 22760809643.0L/20736.0L) - 507476827.0L/1080.0L) + 4728112147.0L/40320.0L) - 33679397.0L/2592.0L) - 1.0L/10080.0L) + 13.0L/15120.0L) + 13.0L/4320.0L) - 19.0L/2880.0L) - 19.0L/864.0L) + 1261.0L/90720.0L) + 1261.0L/30240.0L) - 5.0L/1008.0L) - 5.0L/504.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-135708089.0L/51840.0L*x + 135708089.0L/5760.0L) - 113987791247.0L/1209600.0L) + 923374397.0L/4200.0L) - 2658585787.0L/8064.0L) + 5694355403.0L/17280.0L) - 22760809643.0L/103680.0L) + 507476827.0L/5400.0L) - 4728112147.0L/201600.0L) + 188604623.0L/72576.0L) + 1.0L/80640.0L) - 1.0L/15120.0L) - 1.0L/3456.0L) + 13.0L/28800.0L) + 13.0L/6912.0L) - 41.0L/45360.0L) - 41.0L/12096.0L) + 1.0L/3150.0L) + 1.0L/1260.0L;
poly_val[11] = pow(x, 9)*(x*(x*(x*(x*(x*(x*(x*(x*((12337099.0L/51840.0L)*x - 12337099.0L/5760.0L) + 10362526477.0L/1209600.0L) - 83943127.0L/4200.0L) + 241689617.0L/8064.0L) - 517668673.0L/17280.0L) + 2069164513.0L/103680.0L) - 46134257.0L/5400.0L) + 429828377.0L/201600.0L) - 1587581.0L/6720.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-12337099.0L/2880.0L*x + 209730683.0L/5760.0L) - 10362526477.0L/75600.0L) + 83943127.0L/280.0L) - 241689617.0L/576.0L) + 6729692749.0L/17280.0L) - 2069164513.0L/8640.0L) + 507476827.0L/5400.0L) - 429828377.0L/20160.0L) + 17145875.0L/8064.0L) - 1.0L/10080.0L) - 1.0L/2160.0L) + 1.0L/576.0L) + 13.0L/5760.0L) - 13.0L/1728.0L) - 41.0L/15120.0L) + 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((135708089.0L/2880.0L)*x - 2307037513.0L/5760.0L) + 113987791247.0L/75600.0L) - 923374397.0L/280.0L) + 2658585787.0L/576.0L) - 74026620239.0L/17280.0L) + 22760809643.0L/8640.0L) - 5582245097.0L/5400.0L) + 4728112147.0L/20160.0L) - 235755781.0L/10080.0L) + 1.0L/1260.0L) + 13.0L/2160.0L) - 13.0L/720.0L) - 19.0L/576.0L) + 19.0L/216.0L) + 1261.0L/30240.0L) - 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-135708089.0L/576.0L*x + 2307037513.0L/1152.0L) - 113987791247.0L/15120.0L) + 923374397.0L/56.0L) - 13292928935.0L/576.0L) + 74026620239.0L/3456.0L) - 22760809643.0L/1728.0L) + 5582245097.0L/1080.0L) - 4728112147.0L/4032.0L) + 14968621.0L/128.0L) - 3.0L/1120.0L) - 23.0L/720.0L) + 23.0L/320.0L) + 29.0L/128.0L) - 29.0L/64.0L) - 541.0L/1680.0L) + 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((135708089.0L/192.0L)*x - 2307037513.0L/384.0L) + 113987791247.0L/5040.0L) - 2770123191.0L/56.0L) + 13292928935.0L/192.0L) - 74026620239.0L/1152.0L) + 22760809643.0L/576.0L) - 5582245097.0L/360.0L) + 4728112147.0L/1344.0L) - 471511561.0L/1344.0L) + 1.0L/210.0L) + 17.0L/180.0L) - 17.0L/120.0L) - 13.0L/16.0L) + 13.0L/12.0L) + 4369.0L/2520.0L) - 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-135708089.0L/96.0L*x + 2307037513.0L/192.0L) - 113987791247.0L/2520.0L) + 2770123191.0L/28.0L) - 13292928935.0L/96.0L) + 74026620239.0L/576.0L) - 22760809643.0L/288.0L) + 5582245097.0L/180.0L) - 4728112147.0L/672.0L) + 943023121.0L/1344.0L) - 1.0L/240.0L) - 7.0L/40.0L) + 21.0L/160.0L) + 323.0L/192.0L) - 323.0L/288.0L) - 1669.0L/360.0L) + 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[5] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(x*(x*((949956623.0L/480.0L)*x - 16149262591.0L/960.0L) + 113987791247.0L/1800.0L) - 2770123191.0L/20.0L) + 18610100509.0L/96.0L) - 518186341673.0L/2880.0L) + 159325667501.0L/1440.0L) - 39075715679.0L/900.0L) + 4728112147.0L/480.0L) - 3929263.0L/4.0L) + 77.0L/360.0L) - 341.0L/160.0L) + 1529.0L/240.0L) - 5269.0L/1800.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-949956623.0L/480.0L*x + 16149262591.0L/960.0L) - 113987791247.0L/1800.0L) + 2770123191.0L/20.0L) - 18610100509.0L/96.0L) + 518186341673.0L/2880.0L) - 159325667501.0L/1440.0L) + 39075715679.0L/900.0L) - 4728112147.0L/480.0L) + 943023119.0L/960.0L) + 1.0L/240.0L) - 7.0L/40.0L) - 21.0L/160.0L) + 323.0L/192.0L) + 323.0L/288.0L) - 1669.0L/360.0L) - 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((135708089.0L/96.0L)*x - 2307037513.0L/192.0L) + 113987791247.0L/2520.0L) - 2770123191.0L/28.0L) + 13292928935.0L/96.0L) - 74026620239.0L/576.0L) + 22760809643.0L/288.0L) - 5582245097.0L/180.0L) + 4728112147.0L/672.0L) - 471511559.0L/672.0L) - 1.0L/210.0L) + 17.0L/180.0L) + 17.0L/120.0L) - 13.0L/16.0L) - 13.0L/12.0L) + 4369.0L/2520.0L) + 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-135708089.0L/192.0L*x + 2307037513.0L/384.0L) - 113987791247.0L/5040.0L) + 2770123191.0L/56.0L) - 13292928935.0L/192.0L) + 74026620239.0L/1152.0L) - 22760809643.0L/576.0L) + 5582245097.0L/360.0L) - 4728112147.0L/1344.0L) + 314341039.0L/896.0L) + 3.0L/1120.0L) - 23.0L/720.0L) - 23.0L/320.0L) + 29.0L/128.0L) + 29.0L/64.0L) - 541.0L/1680.0L) - 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((135708089.0L/576.0L)*x - 2307037513.0L/1152.0L) + 113987791247.0L/15120.0L) - 923374397.0L/56.0L) + 13292928935.0L/576.0L) - 74026620239.0L/3456.0L) + 22760809643.0L/1728.0L) - 5582245097.0L/1080.0L) + 4728112147.0L/4032.0L) - 33679397.0L/288.0L) - 1.0L/1260.0L) + 13.0L/2160.0L) + 13.0L/720.0L) - 19.0L/576.0L) - 19.0L/216.0L) + 1261.0L/30240.0L) + 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-135708089.0L/2880.0L*x + 2307037513.0L/5760.0L) - 113987791247.0L/75600.0L) + 923374397.0L/280.0L) - 2658585787.0L/576.0L) + 74026620239.0L/17280.0L) - 22760809643.0L/8640.0L) + 5582245097.0L/5400.0L) - 4728112147.0L/20160.0L) + 188604623.0L/8064.0L) + 1.0L/10080.0L) - 1.0L/2160.0L) - 1.0L/576.0L) + 13.0L/5760.0L) + 13.0L/1728.0L) - 41.0L/15120.0L) - 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[11] = pow(x, 8)*(x*(x*(x*(x*(x*(x*(x*(x*((12337099.0L/2880.0L)*x - 209730683.0L/5760.0L) + 10362526477.0L/75600.0L) - 83943127.0L/280.0L) + 241689617.0L/576.0L) - 6729692749.0L/17280.0L) + 2069164513.0L/8640.0L) - 507476827.0L/5400.0L) + 429828377.0L/20160.0L) - 4762743.0L/2240.0L);
break;
}
}
void beta_n5_m10(const int deriv, const double x, double *__restrict__ poly_val){
switch(deriv)
{
case 0:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((1587581.0L/33600.0L)*x - 1587581.0L/3200.0L) + 852748493.0L/362880.0L) - 960042925.0L/145152.0L) + 14821726939.0L/1209600.0L) - 1049589707.0L/67200.0L) + 8393241803.0L/604800.0L) - 2054212547.0L/241920.0L) + 355209743.0L/103680.0L) - 1494445459.0L/1814400.0L) + 18077609.0L/201600.0L) + 1.0L/3628800.0L) - 1.0L/725760.0L) - 1.0L/120960.0L) + 1.0L/24192.0L) + 13.0L/172800.0L) - 13.0L/34560.0L) - 41.0L/181440.0L) + 41.0L/36288.0L) + 1.0L/6300.0L) - 1.0L/1260.0L);
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-17463391.0L/33600.0L*x + 17463391.0L/3200.0L) - 9380233423.0L/362880.0L) + 10560472175.0L/145152.0L) - 163038996329.0L/1209600.0L) + 11545486777.0L/67200.0L) - 92325659833.0L/604800.0L) + 22596338017.0L/241920.0L) - 3907307173.0L/103680.0L) + 16438900049.0L/1814400.0L) - 198853699.0L/201600.0L) - 1.0L/362880.0L) + 1.0L/90720.0L) + 13.0L/120960.0L) - 13.0L/30240.0L) - 19.0L/17280.0L) + 19.0L/4320.0L) + 1261.0L/362880.0L) - 1261.0L/90720.0L) - 5.0L/2016.0L) + 5.0L/504.0L);
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((17463391.0L/6720.0L)*x - 17463391.0L/640.0L) + 9380233423.0L/72576.0L) - 52802360875.0L/145152.0L) + 163038996329.0L/241920.0L) - 11545486777.0L/13440.0L) + 92325659833.0L/120960.0L) - 22596338017.0L/48384.0L) + 3907307173.0L/20736.0L) - 16438900049.0L/362880.0L) + 198853699.0L/40320.0L) + 1.0L/80640.0L) - 1.0L/26880.0L) - 23.0L/40320.0L) + 23.0L/13440.0L) + 29.0L/3840.0L) - 29.0L/1280.0L) - 541.0L/20160.0L) + 541.0L/6720.0L) + 5.0L/252.0L) - 5.0L/84.0L);
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-17463391.0L/2240.0L*x + 52390173.0L/640.0L) - 9380233423.0L/24192.0L) + 52802360875.0L/48384.0L) - 163038996329.0L/80640.0L) + 11545486777.0L/4480.0L) - 92325659833.0L/40320.0L) + 22596338017.0L/16128.0L) - 3907307173.0L/6912.0L) + 16438900049.0L/120960.0L) - 198853699.0L/13440.0L) - 1.0L/30240.0L) + 1.0L/15120.0L) + 17.0L/10080.0L) - 17.0L/5040.0L) - 13.0L/480.0L) + 13.0L/240.0L) + 4369.0L/30240.0L) - 4369.0L/15120.0L) - 5.0L/42.0L) + 5.0L/21.0L);
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((17463391.0L/1120.0L)*x - 52390173.0L/320.0L) + 9380233423.0L/12096.0L) - 52802360875.0L/24192.0L) + 163038996329.0L/40320.0L) - 11545486777.0L/2240.0L) + 92325659833.0L/20160.0L) - 22596338017.0L/8064.0L) + 3907307173.0L/3456.0L) - 16438900049.0L/60480.0L) + 198853699.0L/6720.0L) + 1.0L/17280.0L) - 1.0L/17280.0L) - 1.0L/320.0L) + 1.0L/320.0L) + 323.0L/5760.0L) - 323.0L/5760.0L) - 1669.0L/4320.0L) + 1669.0L/4320.0L) + 5.0L/6.0L) - 5.0L/6.0L);
poly_val[5] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-17463391.0L/800.0L*x + 366731211.0L/1600.0L) - 9380233423.0L/8640.0L) + 10560472175.0L/3456.0L) - 163038996329.0L/28800.0L) + 11545486777.0L/1600.0L) - 92325659833.0L/14400.0L) + 22596338017.0L/5760.0L) - 27351150211.0L/17280.0L) + 16438900049.0L/43200.0L) - 198853699.0L/4800.0L) - 1.0L/14400.0L) + 11.0L/2880.0L) - 341.0L/4800.0L) + 1529.0L/2880.0L) - 5269.0L/3600.0L) + 1;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((17463391.0L/800.0L)*x - 366731211.0L/1600.0L) + 9380233423.0L/8640.0L) - 10560472175.0L/3456.0L) + 163038996329.0L/28800.0L) - 11545486777.0L/1600.0L) + 92325659833.0L/14400.0L) - 22596338017.0L/5760.0L) + 27351150211.0L/17280.0L) - 16438900049.0L/43200.0L) + 198853699.0L/4800.0L) + 1.0L/17280.0L) + 1.0L/17280.0L) - 1.0L/320.0L) - 1.0L/320.0L) + 323.0L/5760.0L) + 323.0L/5760.0L) - 1669.0L/4320.0L) - 1669.0L/4320.0L) + 5.0L/6.0L) + 5.0L/6.0L);
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-17463391.0L/1120.0L*x + 52390173.0L/320.0L) - 9380233423.0L/12096.0L) + 52802360875.0L/24192.0L) - 163038996329.0L/40320.0L) + 11545486777.0L/2240.0L) - 92325659833.0L/20160.0L) + 22596338017.0L/8064.0L) - 3907307173.0L/3456.0L) + 16438900049.0L/60480.0L) - 198853699.0L/6720.0L) - 1.0L/30240.0L) - 1.0L/15120.0L) + 17.0L/10080.0L) + 17.0L/5040.0L) - 13.0L/480.0L) - 13.0L/240.0L) + 4369.0L/30240.0L) + 4369.0L/15120.0L) - 5.0L/42.0L) - 5.0L/21.0L);
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((17463391.0L/2240.0L)*x - 52390173.0L/640.0L) + 9380233423.0L/24192.0L) - 52802360875.0L/48384.0L) + 163038996329.0L/80640.0L) - 11545486777.0L/4480.0L) + 92325659833.0L/40320.0L) - 22596338017.0L/16128.0L) + 3907307173.0L/6912.0L) - 16438900049.0L/120960.0L) + 198853699.0L/13440.0L) + 1.0L/80640.0L) + 1.0L/26880.0L) - 23.0L/40320.0L) - 23.0L/13440.0L) + 29.0L/3840.0L) + 29.0L/1280.0L) - 541.0L/20160.0L) - 541.0L/6720.0L) + 5.0L/252.0L) + 5.0L/84.0L);
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-17463391.0L/6720.0L*x + 17463391.0L/640.0L) - 9380233423.0L/72576.0L) + 52802360875.0L/145152.0L) - 163038996329.0L/241920.0L) + 11545486777.0L/13440.0L) - 92325659833.0L/120960.0L) + 22596338017.0L/48384.0L) - 3907307173.0L/20736.0L) + 16438900049.0L/362880.0L) - 198853699.0L/40320.0L) - 1.0L/362880.0L) - 1.0L/90720.0L) + 13.0L/120960.0L) + 13.0L/30240.0L) - 19.0L/17280.0L) - 19.0L/4320.0L) + 1261.0L/362880.0L) + 1261.0L/90720.0L) - 5.0L/2016.0L) - 5.0L/504.0L);
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((17463391.0L/33600.0L)*x - 17463391.0L/3200.0L) + 9380233423.0L/362880.0L) - 10560472175.0L/145152.0L) + 163038996329.0L/1209600.0L) - 11545486777.0L/67200.0L) + 92325659833.0L/604800.0L) - 22596338017.0L/241920.0L) + 3907307173.0L/103680.0L) - 16438900049.0L/1814400.0L) + 198853699.0L/201600.0L) + 1.0L/3628800.0L) + 1.0L/725760.0L) - 1.0L/120960.0L) - 1.0L/24192.0L) + 13.0L/172800.0L) + 13.0L/34560.0L) - 41.0L/181440.0L) - 41.0L/36288.0L) + 1.0L/6300.0L) + 1.0L/1260.0L);
poly_val[11] = pow(x, 11)*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-1587581.0L/33600.0L*x + 1587581.0L/3200.0L) - 852748493.0L/362880.0L) + 960042925.0L/145152.0L) - 14821726939.0L/1209600.0L) + 1049589707.0L/67200.0L) - 8393241803.0L/604800.0L) + 2054212547.0L/241920.0L) - 355209743.0L/103680.0L) + 1494445459.0L/1814400.0L) - 18077609.0L/201600.0L);
break;
case 1:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((1587581.0L/1600.0L)*x - 1587581.0L/160.0L) + 16202221367.0L/362880.0L) - 960042925.0L/8064.0L) + 251969357963.0L/1209600.0L) - 1049589707.0L/4200.0L) + 8393241803.0L/40320.0L) - 2054212547.0L/17280.0L) + 4617726659.0L/103680.0L) - 1494445459.0L/151200.0L) + 198853699.0L/201600.0L) + 1.0L/362880.0L) - 1.0L/80640.0L) - 1.0L/15120.0L) + 1.0L/3456.0L) + 13.0L/28800.0L) - 13.0L/6912.0L) - 41.0L/45360.0L) + 41.0L/12096.0L) + 1.0L/3150.0L) - 1.0L/1260.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-17463391.0L/1600.0L*x + 17463391.0L/160.0L) - 178224435037.0L/362880.0L) + 10560472175.0L/8064.0L) - 2771662937593.0L/1209600.0L) + 11545486777.0L/4200.0L) - 92325659833.0L/40320.0L) + 22596338017.0L/17280.0L) - 50794993249.0L/103680.0L) + 16438900049.0L/151200.0L) - 2187390689.0L/201600.0L) - 1.0L/36288.0L) + 1.0L/10080.0L) + 13.0L/15120.0L) - 13.0L/4320.0L) - 19.0L/2880.0L) + 19.0L/864.0L) + 1261.0L/90720.0L) - 1261.0L/30240.0L) - 5.0L/1008.0L) + 5.0L/504.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((17463391.0L/320.0L)*x - 17463391.0L/32.0L) + 178224435037.0L/72576.0L) - 52802360875.0L/8064.0L) + 2771662937593.0L/241920.0L) - 11545486777.0L/840.0L) + 92325659833.0L/8064.0L) - 22596338017.0L/3456.0L) + 50794993249.0L/20736.0L) - 16438900049.0L/30240.0L) + 2187390689.0L/40320.0L) + 1.0L/8064.0L) - 3.0L/8960.0L) - 23.0L/5040.0L) + 23.0L/1920.0L) + 29.0L/640.0L) - 29.0L/256.0L) - 541.0L/5040.0L) + 541.0L/2240.0L) + 5.0L/126.0L) - 5.0L/84.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-52390173.0L/320.0L*x + 52390173.0L/32.0L) - 178224435037.0L/24192.0L) + 52802360875.0L/2688.0L) - 2771662937593.0L/80640.0L) + 11545486777.0L/280.0L) - 92325659833.0L/2688.0L) + 22596338017.0L/1152.0L) - 50794993249.0L/6912.0L) + 16438900049.0L/10080.0L) - 2187390689.0L/13440.0L) - 1.0L/3024.0L) + 1.0L/1680.0L) + 17.0L/1260.0L) - 17.0L/720.0L) - 13.0L/80.0L) + 13.0L/48.0L) + 4369.0L/7560.0L) - 4369.0L/5040.0L) - 5.0L/21.0L) + 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((52390173.0L/160.0L)*x - 52390173.0L/16.0L) + 178224435037.0L/12096.0L) - 52802360875.0L/1344.0L) + 2771662937593.0L/40320.0L) - 11545486777.0L/140.0L) + 92325659833.0L/1344.0L) - 22596338017.0L/576.0L) + 50794993249.0L/3456.0L) - 16438900049.0L/5040.0L) + 2187390689.0L/6720.0L) + 1.0L/1728.0L) - 1.0L/1920.0L) - 1.0L/40.0L) + 7.0L/320.0L) + 323.0L/960.0L) - 323.0L/1152.0L) - 1669.0L/1080.0L) + 1669.0L/1440.0L) + 5.0L/3.0L) - 5.0L/6.0L;
poly_val[5] = x*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-366731211.0L/800.0L*x + 366731211.0L/80.0L) - 178224435037.0L/8640.0L) + 10560472175.0L/192.0L) - 2771662937593.0L/28800.0L) + 11545486777.0L/100.0L) - 92325659833.0L/960.0L) + 158174366119.0L/2880.0L) - 355564952743.0L/17280.0L) + 16438900049.0L/3600.0L) - 2187390689.0L/4800.0L) - 1.0L/1440.0L) + 11.0L/360.0L) - 341.0L/800.0L) + 1529.0L/720.0L) - 5269.0L/1800.0L);
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((366731211.0L/800.0L)*x - 366731211.0L/80.0L) + 178224435037.0L/8640.0L) - 10560472175.0L/192.0L) + 2771662937593.0L/28800.0L) - 11545486777.0L/100.0L) + 92325659833.0L/960.0L) - 158174366119.0L/2880.0L) + 355564952743.0L/17280.0L) - 16438900049.0L/3600.0L) + 2187390689.0L/4800.0L) + 1.0L/1728.0L) + 1.0L/1920.0L) - 1.0L/40.0L) - 7.0L/320.0L) + 323.0L/960.0L) + 323.0L/1152.0L) - 1669.0L/1080.0L) - 1669.0L/1440.0L) + 5.0L/3.0L) + 5.0L/6.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-52390173.0L/160.0L*x + 52390173.0L/16.0L) - 178224435037.0L/12096.0L) + 52802360875.0L/1344.0L) - 2771662937593.0L/40320.0L) + 11545486777.0L/140.0L) - 92325659833.0L/1344.0L) + 22596338017.0L/576.0L) - 50794993249.0L/3456.0L) + 16438900049.0L/5040.0L) - 2187390689.0L/6720.0L) - 1.0L/3024.0L) - 1.0L/1680.0L) + 17.0L/1260.0L) + 17.0L/720.0L) - 13.0L/80.0L) - 13.0L/48.0L) + 4369.0L/7560.0L) + 4369.0L/5040.0L) - 5.0L/21.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((52390173.0L/320.0L)*x - 52390173.0L/32.0L) + 178224435037.0L/24192.0L) - 52802360875.0L/2688.0L) + 2771662937593.0L/80640.0L) - 11545486777.0L/280.0L) + 92325659833.0L/2688.0L) - 22596338017.0L/1152.0L) + 50794993249.0L/6912.0L) - 16438900049.0L/10080.0L) + 2187390689.0L/13440.0L) + 1.0L/8064.0L) + 3.0L/8960.0L) - 23.0L/5040.0L) - 23.0L/1920.0L) + 29.0L/640.0L) + 29.0L/256.0L) - 541.0L/5040.0L) - 541.0L/2240.0L) + 5.0L/126.0L) + 5.0L/84.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-17463391.0L/320.0L*x + 17463391.0L/32.0L) - 178224435037.0L/72576.0L) + 52802360875.0L/8064.0L) - 2771662937593.0L/241920.0L) + 11545486777.0L/840.0L) - 92325659833.0L/8064.0L) + 22596338017.0L/3456.0L) - 50794993249.0L/20736.0L) + 16438900049.0L/30240.0L) - 2187390689.0L/40320.0L) - 1.0L/36288.0L) - 1.0L/10080.0L) + 13.0L/15120.0L) + 13.0L/4320.0L) - 19.0L/2880.0L) - 19.0L/864.0L) + 1261.0L/90720.0L) + 1261.0L/30240.0L) - 5.0L/1008.0L) - 5.0L/504.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((17463391.0L/1600.0L)*x - 17463391.0L/160.0L) + 178224435037.0L/362880.0L) - 10560472175.0L/8064.0L) + 2771662937593.0L/1209600.0L) - 11545486777.0L/4200.0L) + 92325659833.0L/40320.0L) - 22596338017.0L/17280.0L) + 50794993249.0L/103680.0L) - 16438900049.0L/151200.0L) + 2187390689.0L/201600.0L) + 1.0L/362880.0L) + 1.0L/80640.0L) - 1.0L/15120.0L) - 1.0L/3456.0L) + 13.0L/28800.0L) + 13.0L/6912.0L) - 41.0L/45360.0L) - 41.0L/12096.0L) + 1.0L/3150.0L) + 1.0L/1260.0L;
poly_val[11] = pow(x, 10)*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-1587581.0L/1600.0L*x + 1587581.0L/160.0L) - 16202221367.0L/362880.0L) + 960042925.0L/8064.0L) - 251969357963.0L/1209600.0L) + 1049589707.0L/4200.0L) - 8393241803.0L/40320.0L) + 2054212547.0L/17280.0L) - 4617726659.0L/103680.0L) + 1494445459.0L/151200.0L) - 198853699.0L/201600.0L);
break;
case 2:
poly_val[0] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((1587581.0L/80.0L)*x - 30164039.0L/160.0L) + 16202221367.0L/20160.0L) - 16320729725.0L/8064.0L) + 251969357963.0L/75600.0L) - 1049589707.0L/280.0L) + 8393241803.0L/2880.0L) - 26704763111.0L/17280.0L) + 4617726659.0L/8640.0L) - 16438900049.0L/151200.0L) + 198853699.0L/20160.0L) + 1.0L/40320.0L) - 1.0L/10080.0L) - 1.0L/2160.0L) + 1.0L/576.0L) + 13.0L/5760.0L) - 13.0L/1728.0L) - 41.0L/15120.0L) + 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[1] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-17463391.0L/80.0L*x + 331804429.0L/160.0L) - 178224435037.0L/20160.0L) + 179528026975.0L/8064.0L) - 2771662937593.0L/75600.0L) + 11545486777.0L/280.0L) - 92325659833.0L/2880.0L) + 293752394221.0L/17280.0L) - 50794993249.0L/8640.0L) + 180827900539.0L/151200.0L) - 2187390689.0L/20160.0L) - 1.0L/4032.0L) + 1.0L/1260.0L) + 13.0L/2160.0L) - 13.0L/720.0L) - 19.0L/576.0L) + 19.0L/216.0L) + 1261.0L/30240.0L) - 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[2] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((17463391.0L/16.0L)*x - 331804429.0L/32.0L) + 178224435037.0L/4032.0L) - 897640134875.0L/8064.0L) + 2771662937593.0L/15120.0L) - 11545486777.0L/56.0L) + 92325659833.0L/576.0L) - 293752394221.0L/3456.0L) + 50794993249.0L/1728.0L) - 180827900539.0L/30240.0L) + 2187390689.0L/4032.0L) + 1.0L/896.0L) - 3.0L/1120.0L) - 23.0L/720.0L) + 23.0L/320.0L) + 29.0L/128.0L) - 29.0L/64.0L) - 541.0L/1680.0L) + 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[3] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-52390173.0L/16.0L*x + 995413287.0L/32.0L) - 178224435037.0L/1344.0L) + 897640134875.0L/2688.0L) - 2771662937593.0L/5040.0L) + 34636460331.0L/56.0L) - 92325659833.0L/192.0L) + 293752394221.0L/1152.0L) - 50794993249.0L/576.0L) + 180827900539.0L/10080.0L) - 2187390689.0L/1344.0L) - 1.0L/336.0L) + 1.0L/210.0L) + 17.0L/180.0L) - 17.0L/120.0L) - 13.0L/16.0L) + 13.0L/12.0L) + 4369.0L/2520.0L) - 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[4] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((52390173.0L/8.0L)*x - 995413287.0L/16.0L) + 178224435037.0L/672.0L) - 897640134875.0L/1344.0L) + 2771662937593.0L/2520.0L) - 34636460331.0L/28.0L) + 92325659833.0L/96.0L) - 293752394221.0L/576.0L) + 50794993249.0L/288.0L) - 180827900539.0L/5040.0L) + 2187390689.0L/672.0L) + 1.0L/192.0L) - 1.0L/240.0L) - 7.0L/40.0L) + 21.0L/160.0L) + 323.0L/192.0L) - 323.0L/288.0L) - 1669.0L/360.0L) + 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[5] = pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(pow(x, 2)*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-366731211.0L/40.0L*x + 6967893009.0L/80.0L) - 178224435037.0L/480.0L) + 179528026975.0L/192.0L) - 2771662937593.0L/1800.0L) + 34636460331.0L/20.0L) - 646279618831.0L/480.0L) + 2056266759547.0L/2880.0L) - 355564952743.0L/1440.0L) + 180827900539.0L/3600.0L) - 2187390689.0L/480.0L) - 1.0L/160.0L) + 77.0L/360.0L) - 341.0L/160.0L) + 1529.0L/240.0L) - 5269.0L/1800.0L;
poly_val[6] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((366731211.0L/40.0L)*x - 6967893009.0L/80.0L) + 178224435037.0L/480.0L) - 179528026975.0L/192.0L) + 2771662937593.0L/1800.0L) - 34636460331.0L/20.0L) + 646279618831.0L/480.0L) - 2056266759547.0L/2880.0L) + 355564952743.0L/1440.0L) - 180827900539.0L/3600.0L) + 2187390689.0L/480.0L) + 1.0L/192.0L) + 1.0L/240.0L) - 7.0L/40.0L) - 21.0L/160.0L) + 323.0L/192.0L) + 323.0L/288.0L) - 1669.0L/360.0L) - 1669.0L/720.0L) + 5.0L/3.0L;
poly_val[7] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-52390173.0L/8.0L*x + 995413287.0L/16.0L) - 178224435037.0L/672.0L) + 897640134875.0L/1344.0L) - 2771662937593.0L/2520.0L) + 34636460331.0L/28.0L) - 92325659833.0L/96.0L) + 293752394221.0L/576.0L) - 50794993249.0L/288.0L) + 180827900539.0L/5040.0L) - 2187390689.0L/672.0L) - 1.0L/336.0L) - 1.0L/210.0L) + 17.0L/180.0L) + 17.0L/120.0L) - 13.0L/16.0L) - 13.0L/12.0L) + 4369.0L/2520.0L) + 4369.0L/2520.0L) - 5.0L/21.0L;
poly_val[8] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((52390173.0L/16.0L)*x - 995413287.0L/32.0L) + 178224435037.0L/1344.0L) - 897640134875.0L/2688.0L) + 2771662937593.0L/5040.0L) - 34636460331.0L/56.0L) + 92325659833.0L/192.0L) - 293752394221.0L/1152.0L) + 50794993249.0L/576.0L) - 180827900539.0L/10080.0L) + 2187390689.0L/1344.0L) + 1.0L/896.0L) + 3.0L/1120.0L) - 23.0L/720.0L) - 23.0L/320.0L) + 29.0L/128.0L) + 29.0L/64.0L) - 541.0L/1680.0L) - 541.0L/1120.0L) + 5.0L/126.0L;
poly_val[9] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-17463391.0L/16.0L*x + 331804429.0L/32.0L) - 178224435037.0L/4032.0L) + 897640134875.0L/8064.0L) - 2771662937593.0L/15120.0L) + 11545486777.0L/56.0L) - 92325659833.0L/576.0L) + 293752394221.0L/3456.0L) - 50794993249.0L/1728.0L) + 180827900539.0L/30240.0L) - 2187390689.0L/4032.0L) - 1.0L/4032.0L) - 1.0L/1260.0L) + 13.0L/2160.0L) + 13.0L/720.0L) - 19.0L/576.0L) - 19.0L/216.0L) + 1261.0L/30240.0L) + 1261.0L/15120.0L) - 5.0L/1008.0L;
poly_val[10] = x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*(x*((17463391.0L/80.0L)*x - 331804429.0L/160.0L) + 178224435037.0L/20160.0L) - 179528026975.0L/8064.0L) + 2771662937593.0L/75600.0L) - 11545486777.0L/280.0L) + 92325659833.0L/2880.0L) - 293752394221.0L/17280.0L) + 50794993249.0L/8640.0L) - 180827900539.0L/151200.0L) + 2187390689.0L/20160.0L) + 1.0L/40320.0L) + 1.0L/10080.0L) - 1.0L/2160.0L) - 1.0L/576.0L) + 13.0L/5760.0L) + 13.0L/1728.0L) - 41.0L/15120.0L) - 41.0L/6048.0L) + 1.0L/3150.0L;
poly_val[11] = pow(x, 9)*(x*(x*(x*(x*(x*(x*(x*(x*(x*(-1587581.0L/80.0L*x + 30164039.0L/160.0L) - 16202221367.0L/20160.0L) + 16320729725.0L/8064.0L) - 251969357963.0L/75600.0L) + 1049589707.0L/280.0L) - 8393241803.0L/2880.0L) + 26704763111.0L/17280.0L) - 4617726659.0L/8640.0L) + 16438900049.0L/151200.0L) - 198853699.0L/20160.0L);
break;
}
}
